#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_ucscsdk
----------------------------------

Tests for `ucscsdk` module.
"""


class TestUcscsdk():

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_000_something(self):
        pass
