# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

""" This is auto-generated module containing Constants information. """

class NamingId:
    METHOD = "method"
    METHOD_SET = "methodSet"
    AAA_AUTH_REALM = "aaaAuthRealm"
    AAA_AUTH_REALM_FSM = "aaaAuthRealmFsm"
    AAA_AUTH_REALM_FSM_STAGE = "aaaAuthRealmFsmStage"
    AAA_CHANGE_SELF_PASSWORD = "aaaChangeSelfPassword"
    AAA_CHECK_COMPUTE_AUTH_TOKEN = "aaaCheckComputeAuthToken"
    AAA_CHECK_COMPUTE_EXT_ACCESS = "aaaCheckComputeExtAccess"
    AAA_CONSOLE_AUTH = "aaaConsoleAuth"
    AAA_DEFAULT_AUTH = "aaaDefaultAuth"
    AAA_DOMAIN = "aaaDomain"
    AAA_DOMAIN_AUTH = "aaaDomainAuth"
    AAA_DOMAIN_GROUP = "aaaDomainGroup"
    AAA_EP_AUTH_PROFILE = "aaaEpAuthProfile"
    AAA_EP_FSM = "aaaEpFsm"
    AAA_EP_FSM_STAGE = "aaaEpFsmStage"
    AAA_EP_FSM_TASK = "aaaEpFsmTask"
    AAA_EP_LOGIN = "aaaEpLogin"
    AAA_EP_USER = "aaaEpUser"
    AAA_EXT_MGMT_CUT_THRU_TKN = "aaaExtMgmtCutThruTkn"
    AAA_GET_AUTH_TOKEN_CLIENT = "aaaGetAuthTokenClient"
    AAA_GET_AUTH_TOKEN_INTERNAL = "aaaGetAuthTokenInternal"
    AAA_GET_COMPUTE_AUTH_TOKEN = "aaaGetComputeAuthToken"
    AAA_GET_KVMLAUNCH_URL_INTERNAL = "aaaGetKVMLaunchUrlInternal"
    AAA_GET_NCOMPUTE_AUTH_TOKEN_BY_DN = "aaaGetNComputeAuthTokenByDn"
    AAA_GET_NCOMPUTE_AUTH_TOKEN_INTERNAL_BY_DN = "aaaGetNComputeAuthTokenInternalByDn"
    AAA_GET_REMOTE_USER_ROLES = "aaaGetRemoteUserRoles"
    AAA_GET_USER_LOCALES = "aaaGetUserLocales"
    AAA_KEEP_ALIVE = "aaaKeepAlive"
    AAA_LDAP_EP = "aaaLdapEp"
    AAA_LDAP_EP_FSM = "aaaLdapEpFsm"
    AAA_LDAP_EP_FSM_STAGE = "aaaLdapEpFsmStage"
    AAA_LDAP_GROUP = "aaaLdapGroup"
    AAA_LDAP_GROUP_RULE = "aaaLdapGroupRule"
    AAA_LDAP_PROVIDER = "aaaLdapProvider"
    AAA_LOCALE = "aaaLocale"
    AAA_LOG = "aaaLog"
    AAA_LOGIN = "aaaLogin"
    AAA_LOGIN_BY_TOKEN = "aaaLoginByToken"
    AAA_LOGOUT = "aaaLogout"
    AAA_MOD_LR = "aaaModLR"
    AAA_ORG = "aaaOrg"
    AAA_PROVIDER_GROUP = "aaaProviderGroup"
    AAA_PROVIDER_REF = "aaaProviderRef"
    AAA_PWD_PROFILE = "aaaPwdProfile"
    AAA_RADIUS_EP = "aaaRadiusEp"
    AAA_RADIUS_EP_FSM = "aaaRadiusEpFsm"
    AAA_RADIUS_EP_FSM_STAGE = "aaaRadiusEpFsmStage"
    AAA_RADIUS_PROVIDER = "aaaRadiusProvider"
    AAA_REALM_FSM = "aaaRealmFsm"
    AAA_REALM_FSM_STAGE = "aaaRealmFsmStage"
    AAA_REALM_FSM_TASK = "aaaRealmFsmTask"
    AAA_REFRESH = "aaaRefresh"
    AAA_REMOTE_USER = "aaaRemoteUser"
    AAA_ROLE = "aaaRole"
    AAA_SESSION = "aaaSession"
    AAA_SESSION_LR = "aaaSessionLR"
    AAA_SHELL_LOGIN = "aaaShellLogin"
    AAA_SSH_AUTH = "aaaSshAuth"
    AAA_TACACS_PLUS_EP = "aaaTacacsPlusEp"
    AAA_TACACS_PLUS_EP_FSM = "aaaTacacsPlusEpFsm"
    AAA_TACACS_PLUS_EP_FSM_STAGE = "aaaTacacsPlusEpFsmStage"
    AAA_TACACS_PLUS_PROVIDER = "aaaTacacsPlusProvider"
    AAA_TOKEN_LOGIN = "aaaTokenLogin"
    AAA_TOKEN_REFRESH = "aaaTokenRefresh"
    AAA_USER = "aaaUser"
    AAA_USER_DATA = "aaaUserData"
    AAA_USER_EP = "aaaUserEp"
    AAA_USER_EP_FSM = "aaaUserEpFsm"
    AAA_USER_EP_FSM_STAGE = "aaaUserEpFsmStage"
    AAA_USER_EP_FSM_TASK = "aaaUserEpFsmTask"
    AAA_USER_LOCALE = "aaaUserLocale"
    AAA_USER_PREFERENCES = "aaaUserPreferences"
    AAA_USER_ROLE = "aaaUserRole"
    AAA_WEB_LOGIN = "aaaWebLogin"
    ADAPTOR_CAP_QUAL = "adaptorCapQual"
    ADAPTOR_CAP_SPEC = "adaptorCapSpec"
    ADAPTOR_ETH_ADV_FILTER_PROFILE = "adaptorEthAdvFilterProfile"
    ADAPTOR_ETH_ARFS_PROFILE = "adaptorEthArfsProfile"
    ADAPTOR_ETH_COMP_QUEUE_PROFILE = "adaptorEthCompQueueProfile"
    ADAPTOR_ETH_FAILOVER_PROFILE = "adaptorEthFailoverProfile"
    ADAPTOR_ETH_GENEVEPROFILE = "adaptorEthGENEVEProfile"
    ADAPTOR_ETH_INTERRUPT_PROFILE = "adaptorEthInterruptProfile"
    ADAPTOR_ETH_INTERRUPT_SCALING_PROFILE = "adaptorEthInterruptScalingProfile"
    ADAPTOR_ETH_NVGREPROFILE = "adaptorEthNVGREProfile"
    ADAPTOR_ETH_OFFLOAD_PROFILE = "adaptorEthOffloadProfile"
    ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS = "adaptorEthPortBySizeLargeStats"
    ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS_HIST = "adaptorEthPortBySizeLargeStatsHist"
    ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS = "adaptorEthPortBySizeSmallStats"
    ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS_HIST = "adaptorEthPortBySizeSmallStatsHist"
    ADAPTOR_ETH_PORT_ERR_STATS = "adaptorEthPortErrStats"
    ADAPTOR_ETH_PORT_ERR_STATS_HIST = "adaptorEthPortErrStatsHist"
    ADAPTOR_ETH_PORT_MCAST_STATS = "adaptorEthPortMcastStats"
    ADAPTOR_ETH_PORT_MCAST_STATS_HIST = "adaptorEthPortMcastStatsHist"
    ADAPTOR_ETH_PORT_OUTSIZED_STATS = "adaptorEthPortOutsizedStats"
    ADAPTOR_ETH_PORT_OUTSIZED_STATS_HIST = "adaptorEthPortOutsizedStatsHist"
    ADAPTOR_ETH_PORT_STATS = "adaptorEthPortStats"
    ADAPTOR_ETH_PORT_STATS_HIST = "adaptorEthPortStatsHist"
    ADAPTOR_ETH_RECV_QUEUE_PROFILE = "adaptorEthRecvQueueProfile"
    ADAPTOR_ETH_RO_CEPROFILE = "adaptorEthRoCEProfile"
    ADAPTOR_ETH_VX_LANPROFILE = "adaptorEthVxLANProfile"
    ADAPTOR_ETH_WORK_QUEUE_PROFILE = "adaptorEthWorkQueueProfile"
    ADAPTOR_ETHER_IF_STATS = "adaptorEtherIfStats"
    ADAPTOR_ETHER_IF_STATS_HIST = "adaptorEtherIfStatsHist"
    ADAPTOR_EXT_ETH_IF = "adaptorExtEthIf"
    ADAPTOR_EXT_ETH_IF_OPERATION = "adaptorExtEthIfOperation"
    ADAPTOR_EXT_IP_V6_RSS_HASH_PROFILE = "adaptorExtIpV6RssHashProfile"
    ADAPTOR_FC_CDB_WORK_QUEUE_PROFILE = "adaptorFcCdbWorkQueueProfile"
    ADAPTOR_FC_ERROR_RECOVERY_PROFILE = "adaptorFcErrorRecoveryProfile"
    ADAPTOR_FC_FNIC_PROFILE = "adaptorFcFnicProfile"
    ADAPTOR_FC_IF_EVENT_STATS = "adaptorFcIfEventStats"
    ADAPTOR_FC_IF_EVENT_STATS_HIST = "adaptorFcIfEventStatsHist"
    ADAPTOR_FC_IF_FC4_STATS = "adaptorFcIfFC4Stats"
    ADAPTOR_FC_IF_FC4_STATS_HIST = "adaptorFcIfFC4StatsHist"
    ADAPTOR_FC_IF_FRAME_STATS = "adaptorFcIfFrameStats"
    ADAPTOR_FC_IF_FRAME_STATS_HIST = "adaptorFcIfFrameStatsHist"
    ADAPTOR_FC_INTERRUPT_PROFILE = "adaptorFcInterruptProfile"
    ADAPTOR_FC_PORT_FLOGI_PROFILE = "adaptorFcPortFLogiProfile"
    ADAPTOR_FC_PORT_PLOGI_PROFILE = "adaptorFcPortPLogiProfile"
    ADAPTOR_FC_PORT_PROFILE = "adaptorFcPortProfile"
    ADAPTOR_FC_PORT_STATS = "adaptorFcPortStats"
    ADAPTOR_FC_PORT_STATS_HIST = "adaptorFcPortStatsHist"
    ADAPTOR_FC_RECV_QUEUE_PROFILE = "adaptorFcRecvQueueProfile"
    ADAPTOR_FC_WORK_QUEUE_PROFILE = "adaptorFcWorkQueueProfile"
    ADAPTOR_FRU_CAP_PROVIDER = "adaptorFruCapProvider"
    ADAPTOR_HBAVNIC_STATS = "adaptorHBAVnicStats"
    ADAPTOR_HBAVNIC_STATS_HIST = "adaptorHBAVnicStatsHist"
    ADAPTOR_HOST_ETH_IF = "adaptorHostEthIf"
    ADAPTOR_HOST_ETH_IF_OPERATION = "adaptorHostEthIfOperation"
    ADAPTOR_HOST_ETH_IF_PROFILE = "adaptorHostEthIfProfile"
    ADAPTOR_HOST_FC_IF = "adaptorHostFcIf"
    ADAPTOR_HOST_FC_IF_OPERATION = "adaptorHostFcIfOperation"
    ADAPTOR_HOST_FC_IF_PROFILE = "adaptorHostFcIfProfile"
    ADAPTOR_HOST_IF_CONFIG = "adaptorHostIfConfig"
    ADAPTOR_HOST_ISCSI_IF = "adaptorHostIscsiIf"
    ADAPTOR_HOST_ISCSI_IF_OPERATION = "adaptorHostIscsiIfOperation"
    ADAPTOR_HOST_ISCSI_IF_PROFILE = "adaptorHostIscsiIfProfile"
    ADAPTOR_HOST_SCSI_IF = "adaptorHostScsiIf"
    ADAPTOR_HOST_SCSI_LUN_REF = "adaptorHostScsiLunRef"
    ADAPTOR_ISCSI_CAP = "adaptorIScsiCap"
    ADAPTOR_IP_V4_RSS_HASH_PROFILE = "adaptorIpV4RssHashProfile"
    ADAPTOR_IP_V6_RSS_HASH_PROFILE = "adaptorIpV6RssHashProfile"
    ADAPTOR_MENLO_BASE_ERROR_STATS = "adaptorMenloBaseErrorStats"
    ADAPTOR_MENLO_BASE_ERROR_STATS_HIST = "adaptorMenloBaseErrorStatsHist"
    ADAPTOR_MENLO_DCE_PORT_STATS = "adaptorMenloDcePortStats"
    ADAPTOR_MENLO_DCE_PORT_STATS_HIST = "adaptorMenloDcePortStatsHist"
    ADAPTOR_MENLO_ETH_ERROR_STATS = "adaptorMenloEthErrorStats"
    ADAPTOR_MENLO_ETH_ERROR_STATS_HIST = "adaptorMenloEthErrorStatsHist"
    ADAPTOR_MENLO_ETH_STATS = "adaptorMenloEthStats"
    ADAPTOR_MENLO_ETH_STATS_HIST = "adaptorMenloEthStatsHist"
    ADAPTOR_MENLO_FC_ERROR_STATS = "adaptorMenloFcErrorStats"
    ADAPTOR_MENLO_FC_ERROR_STATS_HIST = "adaptorMenloFcErrorStatsHist"
    ADAPTOR_MENLO_FC_STATS = "adaptorMenloFcStats"
    ADAPTOR_MENLO_FC_STATS_HIST = "adaptorMenloFcStatsHist"
    ADAPTOR_MENLO_HOST_PORT_STATS = "adaptorMenloHostPortStats"
    ADAPTOR_MENLO_HOST_PORT_STATS_HIST = "adaptorMenloHostPortStatsHist"
    ADAPTOR_MENLO_MCPU_ERROR_STATS = "adaptorMenloMcpuErrorStats"
    ADAPTOR_MENLO_MCPU_ERROR_STATS_HIST = "adaptorMenloMcpuErrorStatsHist"
    ADAPTOR_MENLO_MCPU_STATS = "adaptorMenloMcpuStats"
    ADAPTOR_MENLO_MCPU_STATS_HIST = "adaptorMenloMcpuStatsHist"
    ADAPTOR_MENLO_NET_EG_STATS = "adaptorMenloNetEgStats"
    ADAPTOR_MENLO_NET_EG_STATS_HIST = "adaptorMenloNetEgStatsHist"
    ADAPTOR_MENLO_NET_IN_STATS = "adaptorMenloNetInStats"
    ADAPTOR_MENLO_NET_IN_STATS_HIST = "adaptorMenloNetInStatsHist"
    ADAPTOR_MENLO_QERROR_STATS = "adaptorMenloQErrorStats"
    ADAPTOR_MENLO_QERROR_STATS_HIST = "adaptorMenloQErrorStatsHist"
    ADAPTOR_MENLO_QSTATS = "adaptorMenloQStats"
    ADAPTOR_MENLO_QSTATS_HIST = "adaptorMenloQStatsHist"
    ADAPTOR_NICVNIC_STATS = "adaptorNICVnicStats"
    ADAPTOR_NICVNIC_STATS_HIST = "adaptorNICVnicStatsHist"
    ADAPTOR_PROTOCOL_PROFILE = "adaptorProtocolProfile"
    ADAPTOR_QUAL = "adaptorQual"
    ADAPTOR_RNIC_CAP_SPEC = "adaptorRnicCapSpec"
    ADAPTOR_RSS_PROFILE = "adaptorRssProfile"
    ADAPTOR_UNIT = "adaptorUnit"
    ADAPTOR_UNIT_ASSOC_CTX = "adaptorUnitAssocCtx"
    ADAPTOR_UNIT_EXTN = "adaptorUnitExtn"
    ADAPTOR_USNIC_CONN_DEF = "adaptorUsnicConnDef"
    ADAPTOR_VLAN = "adaptorVlan"
    ADAPTOR_VMMQ_CONN_DEF = "adaptorVmmqConnDef"
    ADAPTOR_VNIC_STATS = "adaptorVnicStats"
    ADAPTOR_VNIC_STATS_HIST = "adaptorVnicStatsHist"
    ALLBITS_FILTER = "allbitsFilter"
    AND_FILTER = "andFilter"
    ANYBIT_FILTER = "anybitFilter"
    BIOS_BOT = "biosBOT"
    BIOS_BOOT_DEV = "biosBootDev"
    BIOS_BOOT_DEV_GRP = "biosBootDevGrp"
    BIOS_TOKEN_FEATURE_GROUP = "biosTokenFeatureGroup"
    BIOS_TOKEN_PARAM = "biosTokenParam"
    BIOS_TOKEN_SETTINGS = "biosTokenSettings"
    BIOS_UNIT = "biosUnit"
    BIOS_VPROFILE = "biosVProfile"
    BIOS_VF_ACPI10_SUPPORT = "biosVfACPI10Support"
    BIOS_VF_ASPMSUPPORT = "biosVfASPMSupport"
    BIOS_VF_ALL_USBDEVICES = "biosVfAllUSBDevices"
    BIOS_VF_ALTITUDE = "biosVfAltitude"
    BIOS_VF_ASSERT_NMION_PERR = "biosVfAssertNMIOnPERR"
    BIOS_VF_ASSERT_NMION_SERR = "biosVfAssertNMIOnSERR"
    BIOS_VF_BOOT_OPTION_RETRY = "biosVfBootOptionRetry"
    BIOS_VF_CPUHARDWARE_POWER_MANAGEMENT = "biosVfCPUHardwarePowerManagement"
    BIOS_VF_CPUPERFORMANCE = "biosVfCPUPerformance"
    BIOS_VF_CPUPOWER_MANAGEMENT = "biosVfCPUPowerManagement"
    BIOS_VF_CONSISTENT_DEVICE_NAME_CONTROL = "biosVfConsistentDeviceNameControl"
    BIOS_VF_CONSOLE_REDIRECTION = "biosVfConsoleRedirection"
    BIOS_VF_CORE_MULTI_PROCESSING = "biosVfCoreMultiProcessing"
    BIOS_VF_DDR3_VOLTAGE_SELECTION = "biosVfDDR3VoltageSelection"
    BIOS_VF_DRAMCLOCK_THROTTLING = "biosVfDRAMClockThrottling"
    BIOS_VF_DIRECT_CACHE_ACCESS = "biosVfDirectCacheAccess"
    BIOS_VF_DRAM_REFRESH_RATE = "biosVfDramRefreshRate"
    BIOS_VF_ENERGY_PERFORMANCE_TUNING = "biosVfEnergyPerformanceTuning"
    BIOS_VF_ENHANCED_INTEL_SPEED_STEP_TECH = "biosVfEnhancedIntelSpeedStepTech"
    BIOS_VF_ENHANCED_POWER_CAPPING_SUPPORT = "biosVfEnhancedPowerCappingSupport"
    BIOS_VF_EXECUTE_DISABLE_BIT = "biosVfExecuteDisableBit"
    BIOS_VF_FRB2_TIMER = "biosVfFRB2Timer"
    BIOS_VF_FREQUENCY_FLOOR_OVERRIDE = "biosVfFrequencyFloorOverride"
    BIOS_VF_FRONT_PANEL_LOCKOUT = "biosVfFrontPanelLockout"
    BIOS_VF_IOEMEZZ1_OPTION_ROM = "biosVfIOEMezz1OptionROM"
    BIOS_VF_IOENVME1_OPTION_ROM = "biosVfIOENVMe1OptionROM"
    BIOS_VF_IOENVME2_OPTION_ROM = "biosVfIOENVMe2OptionROM"
    BIOS_VF_IOESLOT1_OPTION_ROM = "biosVfIOESlot1OptionROM"
    BIOS_VF_IOESLOT2_OPTION_ROM = "biosVfIOESlot2OptionROM"
    BIOS_VF_INTEGRATED_GRAPHICS = "biosVfIntegratedGraphics"
    BIOS_VF_INTEGRATED_GRAPHICS_APERTURE_SIZE = "biosVfIntegratedGraphicsApertureSize"
    BIOS_VF_INTEL_ENTRY_SASRAIDMODULE = "biosVfIntelEntrySASRAIDModule"
    BIOS_VF_INTEL_HYPER_THREADING_TECH = "biosVfIntelHyperThreadingTech"
    BIOS_VF_INTEL_TRUSTED_EXECUTION_TECHNOLOGY = "biosVfIntelTrustedExecutionTechnology"
    BIOS_VF_INTEL_TURBO_BOOST_TECH = "biosVfIntelTurboBoostTech"
    BIOS_VF_INTEL_VTFOR_DIRECTED_IO = "biosVfIntelVTForDirectedIO"
    BIOS_VF_INTEL_VIRTUALIZATION_TECHNOLOGY = "biosVfIntelVirtualizationTechnology"
    BIOS_VF_INTERLEAVE_CONFIGURATION = "biosVfInterleaveConfiguration"
    BIOS_VF_LOCAL_X2_APIC = "biosVfLocalX2Apic"
    BIOS_VF_LV_DIMMSUPPORT = "biosVfLvDIMMSupport"
    BIOS_VF_MAX_VARIABLE_MTRRSETTING = "biosVfMaxVariableMTRRSetting"
    BIOS_VF_MAXIMUM_MEMORY_BELOW4_GB = "biosVfMaximumMemoryBelow4GB"
    BIOS_VF_MEMORY_MAPPED_IOABOVE4_GB = "biosVfMemoryMappedIOAbove4GB"
    BIOS_VF_MIRRORING_MODE = "biosVfMirroringMode"
    BIOS_VF_NUMAOPTIMIZED = "biosVfNUMAOptimized"
    BIOS_VF_OSBOOT_WATCHDOG_TIMER = "biosVfOSBootWatchdogTimer"
    BIOS_VF_OSBOOT_WATCHDOG_TIMER_POLICY = "biosVfOSBootWatchdogTimerPolicy"
    BIOS_VF_OSBOOT_WATCHDOG_TIMER_TIMEOUT = "biosVfOSBootWatchdogTimerTimeout"
    BIOS_VF_ONBOARD_GRAPHICS = "biosVfOnboardGraphics"
    BIOS_VF_ONBOARD_SATACONTROLLER = "biosVfOnboardSATAController"
    BIOS_VF_ONBOARD_STORAGE = "biosVfOnboardStorage"
    BIOS_VF_OPTION_ROMENABLE = "biosVfOptionROMEnable"
    BIOS_VF_OPTION_ROMLOAD = "biosVfOptionROMLoad"
    BIOS_VF_OUT_OF_BAND_MANAGEMENT = "biosVfOutOfBandManagement"
    BIOS_VF_PCHSATAMODE = "biosVfPCHSATAMode"
    BIOS_VF_PCILOMPORTS_CONFIGURATION = "biosVfPCILOMPortsConfiguration"
    BIOS_VF_PCIROMCLP = "biosVfPCIROMCLP"
    BIOS_VF_PCISLOT_LINK_SPEED = "biosVfPCISlotLinkSpeed"
    BIOS_VF_PCISLOT_OPTION_ROMENABLE = "biosVfPCISlotOptionROMEnable"
    BIOS_VF_POSTERROR_PAUSE = "biosVfPOSTErrorPause"
    BIOS_VF_PSTATECOORDINATION = "biosVfPSTATECoordination"
    BIOS_VF_PACKAGE_CSTATE_LIMIT = "biosVfPackageCStateLimit"
    BIOS_VF_PROCESSOR_C1_E = "biosVfProcessorC1E"
    BIOS_VF_PROCESSOR_C3_REPORT = "biosVfProcessorC3Report"
    BIOS_VF_PROCESSOR_C6_REPORT = "biosVfProcessorC6Report"
    BIOS_VF_PROCESSOR_C7_REPORT = "biosVfProcessorC7Report"
    BIOS_VF_PROCESSOR_CMCI = "biosVfProcessorCMCI"
    BIOS_VF_PROCESSOR_CSTATE = "biosVfProcessorCState"
    BIOS_VF_PROCESSOR_ENERGY_CONFIGURATION = "biosVfProcessorEnergyConfiguration"
    BIOS_VF_PROCESSOR_PREFETCH_CONFIG = "biosVfProcessorPrefetchConfig"
    BIOS_VF_QPILINK_FREQUENCY_SELECT = "biosVfQPILinkFrequencySelect"
    BIOS_VF_QPISNOOP_MODE = "biosVfQPISnoopMode"
    BIOS_VF_QUIET_BOOT = "biosVfQuietBoot"
    BIOS_VF_REDIRECTION_AFTER_BIOSPOST = "biosVfRedirectionAfterBIOSPOST"
    BIOS_VF_RESUME_ON_ACPOWER_LOSS = "biosVfResumeOnACPowerLoss"
    BIOS_VF_SBMEZZ1_OPTION_ROM = "biosVfSBMezz1OptionROM"
    BIOS_VF_SBNVME1_OPTION_ROM = "biosVfSBNVMe1OptionROM"
    BIOS_VF_SIOC1_OPTION_ROM = "biosVfSIOC1OptionROM"
    BIOS_VF_SIOC2_OPTION_ROM = "biosVfSIOC2OptionROM"
    BIOS_VF_SCRUB_POLICIES = "biosVfScrubPolicies"
    BIOS_VF_SELECT_MEMORY_RASCONFIGURATION = "biosVfSelectMemoryRASConfiguration"
    BIOS_VF_SERIAL_PORT_AENABLE = "biosVfSerialPortAEnable"
    BIOS_VF_SPARING_MODE = "biosVfSparingMode"
    BIOS_VF_SRIOV_CONFIG = "biosVfSriovConfig"
    BIOS_VF_TPMPENDING_OPERATION = "biosVfTPMPendingOperation"
    BIOS_VF_TPMSUPPORT = "biosVfTPMSupport"
    BIOS_VF_TRUSTED_PLATFORM_MODULE = "biosVfTrustedPlatformModule"
    BIOS_VF_UCSMBOOT_MODE_CONTROL = "biosVfUCSMBootModeControl"
    BIOS_VF_UCSMBOOT_ORDER_RULE_CONTROL = "biosVfUCSMBootOrderRuleControl"
    BIOS_VF_UEFIOSUSE_LEGACY_VIDEO = "biosVfUEFIOSUseLegacyVideo"
    BIOS_VF_USBBOOT_CONFIG = "biosVfUSBBootConfig"
    BIOS_VF_USBCONFIGURATION = "biosVfUSBConfiguration"
    BIOS_VF_USBFRONT_PANEL_ACCESS_LOCK = "biosVfUSBFrontPanelAccessLock"
    BIOS_VF_USBPORT_CONFIGURATION = "biosVfUSBPortConfiguration"
    BIOS_VF_USBSYSTEM_IDLE_POWER_OPTIMIZING_SETTING = "biosVfUSBSystemIdlePowerOptimizingSetting"
    BIOS_VF_VGAPRIORITY = "biosVfVGAPriority"
    BIOS_VF_WORKLOAD_CONFIGURATION = "biosVfWorkloadConfiguration"
    BW_FILTER = "bwFilter"
    CALLHOME_DEST = "callhomeDest"
    CALLHOME_EP = "callhomeEp"
    CALLHOME_FAULT_INST = "callhomeFaultInst"
    CALLHOME_HOLDER = "callhomeHolder"
    CALLHOME_HOLDER_FSM = "callhomeHolderFsm"
    CALLHOME_HOLDER_FSM_STAGE = "callhomeHolderFsmStage"
    CALLHOME_HOLDER_FSM_TASK = "callhomeHolderFsmTask"
    CALLHOME_HTTP = "callhomeHttp"
    CALLHOME_PERIODIC_SYSTEM_INVENTORY = "callhomePeriodicSystemInventory"
    CALLHOME_POLICY = "callhomePolicy"
    CALLHOME_PROFILE = "callhomeProfile"
    CALLHOME_SMTP = "callhomeSmtp"
    CALLHOME_SOURCE = "callhomeSource"
    CALLHOME_TEST_ALERT = "callhomeTestAlert"
    CAPABILITY_CATALOGUE = "capabilityCatalogue"
    CERT_REPAIR_EP = "certRepairEp"
    CERT_REPAIR_EP_FSM = "certRepairEpFsm"
    CERT_REPAIR_EP_FSM_STAGE = "certRepairEpFsmStage"
    CERT_REPAIR_EP_FSM_TASK = "certRepairEpFsmTask"
    CHANGE_CHANGED_OBJECT_REF = "changeChangedObjectRef"
    CHANGE_EP = "changeEp"
    CHANGE_EP_FSM = "changeEpFsm"
    CHANGE_EP_FSM_STAGE = "changeEpFsmStage"
    CHANGE_EP_FSM_TASK = "changeEpFsmTask"
    CIMCVMEDIA_ACTUAL_MOUNT_ENTRY = "cimcvmediaActualMountEntry"
    CIMCVMEDIA_ACTUAL_MOUNT_LIST = "cimcvmediaActualMountList"
    CIMCVMEDIA_CONFIG_MOUNT_ENTRY = "cimcvmediaConfigMountEntry"
    CIMCVMEDIA_EXT_MGMT_RULE_ENTRY = "cimcvmediaExtMgmtRuleEntry"
    CIMCVMEDIA_MOUNT_CONFIG_DEF = "cimcvmediaMountConfigDef"
    CIMCVMEDIA_MOUNT_CONFIG_POLICY = "cimcvmediaMountConfigPolicy"
    CLASS_ID = "classId"
    CLASS_ID_SET = "classIdSet"
    CLITEST_TYPE_TEST = "clitestTypeTest"
    CLITEST_TYPE_TEST2 = "clitestTypeTest2"
    CLITEST_TYPE_TEST_CHILD = "clitestTypeTestChild"
    CLIVIEW_CONF_MOS = "cliviewConfMos"
    COMM_CIMXML = "commCimxml"
    COMM_CORE_FILE = "commCoreFile"
    COMM_DATE_TIME = "commDateTime"
    COMM_DATE_TIME_FSM = "commDateTimeFsm"
    COMM_DATE_TIME_FSM_STAGE = "commDateTimeFsmStage"
    COMM_DATE_TIME_FSM_TASK = "commDateTimeFsmTask"
    COMM_DNS = "commDns"
    COMM_DNS_PROVIDER = "commDnsProvider"
    COMM_EVT_CHANNEL = "commEvtChannel"
    COMM_HTTP = "commHttp"
    COMM_HTTPS = "commHttps"
    COMM_LOCALE = "commLocale"
    COMM_LOG_COMPONENT = "commLogComponent"
    COMM_NTP = "commNtp"
    COMM_NTP_PROVIDER = "commNtpProvider"
    COMM_SHELL_SVC_LIMITS = "commShellSvcLimits"
    COMM_SMASH_CLP = "commSmashCLP"
    COMM_SNMP = "commSnmp"
    COMM_SNMP_COMMUNITY = "commSnmpCommunity"
    COMM_SNMP_TRAP = "commSnmpTrap"
    COMM_SNMP_TRAP_DATA = "commSnmpTrapData"
    COMM_SNMP_USER = "commSnmpUser"
    COMM_SSH = "commSsh"
    COMM_SVC_EP = "commSvcEp"
    COMM_SVC_EP_FSM = "commSvcEpFsm"
    COMM_SVC_EP_FSM_STAGE = "commSvcEpFsmStage"
    COMM_SVC_EP_FSM_TASK = "commSvcEpFsmTask"
    COMM_SVC_POLICY = "commSvcPolicy"
    COMM_SYSLOG = "commSyslog"
    COMM_SYSLOG_CLIENT = "commSyslogClient"
    COMM_SYSLOG_CONSOLE = "commSyslogConsole"
    COMM_SYSLOG_FILE = "commSyslogFile"
    COMM_SYSLOG_MONITOR = "commSyslogMonitor"
    COMM_SYSLOG_SOURCE = "commSyslogSource"
    COMM_TELNET = "commTelnet"
    COMM_WEB_CHANNEL = "commWebChannel"
    COMM_WEB_SVC_LIMITS = "commWebSvcLimits"
    COMM_WSMAN = "commWsman"
    COMM_XML_CL_CONN_POLICY = "commXmlClConnPolicy"
    COMPUTE_AUTOCONFIG_POLICY = "computeAutoconfigPolicy"
    COMPUTE_BLADE = "computeBlade"
    COMPUTE_BLADE_DISC_POLICY = "computeBladeDiscPolicy"
    COMPUTE_BLADE_EP = "computeBladeEp"
    COMPUTE_BLADE_INHERIT_POLICY = "computeBladeInheritPolicy"
    COMPUTE_BOARD = "computeBoard"
    COMPUTE_BOARD_CONNECTOR = "computeBoardConnector"
    COMPUTE_BOARD_CONTROLLER = "computeBoardController"
    COMPUTE_CARTRIDGE = "computeCartridge"
    COMPUTE_CARTRIDGE_OPERATION = "computeCartridgeOperation"
    COMPUTE_CHASSIS_CONN_POLICY = "computeChassisConnPolicy"
    COMPUTE_CHASSIS_CONN_POLICY_OPERATION = "computeChassisConnPolicyOperation"
    COMPUTE_CHASSIS_DISC_POLICY = "computeChassisDiscPolicy"
    COMPUTE_CHASSIS_FEAT_MASK = "computeChassisFeatMask"
    COMPUTE_CHASSIS_QUAL = "computeChassisQual"
    COMPUTE_DOMAIN_GROUP_QUAL = "computeDomainGroupQual"
    COMPUTE_DOMAIN_HW_CHANGE_DISC_POLICY = "computeDomainHwChangeDiscPolicy"
    COMPUTE_DOMAIN_NAME_QUAL = "computeDomainNameQual"
    COMPUTE_DOMAIN_PORT_DISC_POLICY = "computeDomainPortDiscPolicy"
    COMPUTE_DOMAIN_QUAL = "computeDomainQual"
    COMPUTE_ENV_FEAT_MASK = "computeEnvFeatMask"
    COMPUTE_EXT_BOARD = "computeExtBoard"
    COMPUTE_FABRIC_ETH_MON_SRC_EP = "computeFabricEthMonSrcEp"
    COMPUTE_FABRIC_ETH_MON_SRC_EP_CONT = "computeFabricEthMonSrcEpCont"
    COMPUTE_FABRIC_FC_MON_SRC_EP = "computeFabricFcMonSrcEp"
    COMPUTE_FABRIC_FC_MON_SRC_EP_CONT = "computeFabricFcMonSrcEpCont"
    COMPUTE_FACTORY_RESET_OP = "computeFactoryResetOp"
    COMPUTE_FACTORY_RESET_OPERATION = "computeFactoryResetOperation"
    COMPUTE_FAULT_UPGRADE_FLAG = "computeFaultUpgradeFlag"
    COMPUTE_GET_QUALIFIED_SERVERS = "computeGetQualifiedServers"
    COMPUTE_GET_SERVER_CATALOG = "computeGetServerCatalog"
    COMPUTE_GRAPHICS_CARD_POLICY = "computeGraphicsCardPolicy"
    COMPUTE_GROUP_MEMBERSHIP = "computeGroupMembership"
    COMPUTE_GROUP_MEMBERSHIP_REF = "computeGroupMembershipRef"
    COMPUTE_HW_CHANGE_DISC_POLICY = "computeHwChangeDiscPolicy"
    COMPUTE_IOHUB = "computeIOHub"
    COMPUTE_IOHUB_ENV_STATS = "computeIOHubEnvStats"
    COMPUTE_IOHUB_ENV_STATS_HIST = "computeIOHubEnvStatsHist"
    COMPUTE_INSTANCE = "computeInstance"
    COMPUTE_INSTANCE_ID_QUAL = "computeInstanceIdQual"
    COMPUTE_INSTANCE_MAPPING = "computeInstanceMapping"
    COMPUTE_LOCAL_TEMPL_DEF = "computeLocalTemplDef"
    COMPUTE_MB_POWER_STATS = "computeMbPowerStats"
    COMPUTE_MB_POWER_STATS_HIST = "computeMbPowerStatsHist"
    COMPUTE_MB_TEMP_STATS = "computeMbTempStats"
    COMPUTE_MB_TEMP_STATS_HIST = "computeMbTempStatsHist"
    COMPUTE_NETWORK_FEAT_MASK = "computeNetworkFeatMask"
    COMPUTE_OWNER_QUAL = "computeOwnerQual"
    COMPUTE_PCIE_FATAL_COMPLETION_STATS = "computePCIeFatalCompletionStats"
    COMPUTE_PCIE_FATAL_COMPLETION_STATS_HIST = "computePCIeFatalCompletionStatsHist"
    COMPUTE_PCIE_FATAL_PROTOCOL_STATS = "computePCIeFatalProtocolStats"
    COMPUTE_PCIE_FATAL_PROTOCOL_STATS_HIST = "computePCIeFatalProtocolStatsHist"
    COMPUTE_PCIE_FATAL_RECEIVE_STATS = "computePCIeFatalReceiveStats"
    COMPUTE_PCIE_FATAL_RECEIVE_STATS_HIST = "computePCIeFatalReceiveStatsHist"
    COMPUTE_PCIE_FATAL_STATS = "computePCIeFatalStats"
    COMPUTE_PCIE_FATAL_STATS_HIST = "computePCIeFatalStatsHist"
    COMPUTE_PHYSICAL_ASSOC_CTX = "computePhysicalAssocCtx"
    COMPUTE_PHYSICAL_EXTENSION = "computePhysicalExtension"
    COMPUTE_PHYSICAL_OPERATION = "computePhysicalOperation"
    COMPUTE_PHYSICAL_QUAL = "computePhysicalQual"
    COMPUTE_POOL = "computePool"
    COMPUTE_POOL_POLICY_REF = "computePoolPolicyRef"
    COMPUTE_POOLABLE = "computePoolable"
    COMPUTE_POOLED_ENCLOSURE_COMPUTE_SLOT = "computePooledEnclosureComputeSlot"
    COMPUTE_POOLED_RACK_UNIT = "computePooledRackUnit"
    COMPUTE_POOLED_SLOT = "computePooledSlot"
    COMPUTE_POOLING_POLICY = "computePoolingPolicy"
    COMPUTE_PORT_DISC_POLICY = "computePortDiscPolicy"
    COMPUTE_POWER_SYNC_DEF = "computePowerSyncDef"
    COMPUTE_POWER_SYNC_POLICY = "computePowerSyncPolicy"
    COMPUTE_PRODUCT_FAMILY_QUAL = "computeProductFamilyQual"
    COMPUTE_PROFILE = "computeProfile"
    COMPUTE_PSU_POLICY = "computePsuPolicy"
    COMPUTE_QUAL = "computeQual"
    COMPUTE_RACK_QUAL = "computeRackQual"
    COMPUTE_RACK_UNIT = "computeRackUnit"
    COMPUTE_RACK_UNIT_MB_TEMP_STATS = "computeRackUnitMbTempStats"
    COMPUTE_RACK_UNIT_MB_TEMP_STATS_HIST = "computeRackUnitMbTempStatsHist"
    COMPUTE_RE_QUALIFY_MEMBERSHIP = "computeReQualifyMembership"
    COMPUTE_REBOOT_LOG = "computeRebootLog"
    COMPUTE_REMOTE_OP_STATUS = "computeRemoteOpStatus"
    COMPUTE_REQUIREMENT = "computeRequirement"
    COMPUTE_RESOURCE_AGGR_EP = "computeResourceAggrEp"
    COMPUTE_RESOURCE_SET = "computeResourceSet"
    COMPUTE_RESOURCE_SET_MANAGER = "computeResourceSetManager"
    COMPUTE_RESOURCE_SET_MEMBER = "computeResourceSetMember"
    COMPUTE_SCRUB_POLICY = "computeScrubPolicy"
    COMPUTE_SERVER_DISC_POLICY = "computeServerDiscPolicy"
    COMPUTE_SERVER_FEAT_MASK = "computeServerFeatMask"
    COMPUTE_SERVER_MGMT_POLICY = "computeServerMgmtPolicy"
    COMPUTE_SERVER_UNIT = "computeServerUnit"
    COMPUTE_SESSION = "computeSession"
    COMPUTE_SITE_QUAL = "computeSiteQual"
    COMPUTE_SLOT_QUAL = "computeSlotQual"
    COMPUTE_STORAGE_FEAT_MASK = "computeStorageFeatMask"
    COMPUTE_SYSTEM = "computeSystem"
    COMPUTE_SYSTEM_ADDR_QUAL = "computeSystemAddrQual"
    COMPUTE_SYSTEM_FSM = "computeSystemFsm"
    COMPUTE_SYSTEM_FSM_STAGE = "computeSystemFsmStage"
    COMPUTE_SYSTEM_FSM_TASK = "computeSystemFsmTask"
    COMPUTE_SYSTEM_QUAL = "computeSystemQual"
    COMPUTE_TEMPLATE = "computeTemplate"
    COMPUTE_TEMPLATE_MAPPING = "computeTemplateMapping"
    COMPUTE_USER = "computeUser"
    COMPUTE_USER_EP = "computeUserEp"
    CONFIG_ACK_ITEM = "configAckItem"
    CONFIG_ADAPTOR_ITEM = "configAdaptorItem"
    CONFIG_APP_IMPACT_RESPONSE = "configAppImpactResponse"
    CONFIG_BACKUP = "configBackup"
    CONFIG_BACKUP_FSM = "configBackupFsm"
    CONFIG_BACKUP_FSM_STAGE = "configBackupFsmStage"
    CONFIG_BACKUP_FSM_TASK = "configBackupFsmTask"
    CONFIG_CARTRIDGE_FILTER = "configCartridgeFilter"
    CONFIG_CARTRIDGE_ITEM = "configCartridgeItem"
    CONFIG_CATALOGUE = "configCatalogue"
    CONFIG_CHASSIS_FILTER = "configChassisFilter"
    CONFIG_CHASSIS_ITEM = "configChassisItem"
    CONFIG_CHECK_HARDWARE_COMPATIBILITY = "configCheckHardwareCompatibility"
    CONFIG_CLONE = "configClone"
    CONFIG_COMPONENTS_FILTER = "configComponentsFilter"
    CONFIG_CONF_FILTERED = "configConfFiltered"
    CONFIG_CONF_MO = "configConfMo"
    CONFIG_CONF_MO_GROUP = "configConfMoGroup"
    CONFIG_CONF_MOS = "configConfMos"
    CONFIG_CONF_RENAME = "configConfRename"
    CONFIG_CONFIG = "configConfig"
    CONFIG_CONSUMER_CATALOGUE = "configConsumerCatalogue"
    CONFIG_CONSUMER_CATALOGUE_FSM = "configConsumerCatalogueFsm"
    CONFIG_CONSUMER_CATALOGUE_FSM_STAGE = "configConsumerCatalogueFsmStage"
    CONFIG_CONSUMER_CATALOGUE_FSM_TASK = "configConsumerCatalogueFsmTask"
    CONFIG_CONTROLLER_ITEM = "configControllerItem"
    CONFIG_CPU_INFO = "configCpuInfo"
    CONFIG_CPU_ITEM = "configCpuItem"
    CONFIG_CRYPTO_CARD_ITEM = "configCryptoCardItem"
    CONFIG_DB_CONFIG = "configDbConfig"
    CONFIG_DELETE_MO = "configDeleteMo"
    CONFIG_DOMAIN_FILTER = "configDomainFilter"
    CONFIG_DOMAIN_ITEM = "configDomainItem"
    CONFIG_FABRIC_INTERCONNECT_FILTER = "configFabricInterconnectFilter"
    CONFIG_FABRIC_INTERCONNECT_ITEM = "configFabricInterconnectItem"
    CONFIG_FAN_ITEM = "configFanItem"
    CONFIG_FEX_FILTER = "configFexFilter"
    CONFIG_FEX_ITEM = "configFexItem"
    CONFIG_FILTER_GROUP = "configFilterGroup"
    CONFIG_FILTER_ITEM = "configFilterItem"
    CONFIG_FIND_DEPENDENCIES = "configFindDependencies"
    CONFIG_FIND_DNS_BY_CLASS_ID = "configFindDnsByClassId"
    CONFIG_FIND_POLICY_USAGE = "configFindPolicyUsage"
    CONFIG_FSM = "configFsm"
    CONFIG_FSM_STAGE = "configFsmStage"
    CONFIG_GET_ACKABLES = "configGetAckables"
    CONFIG_GET_CONNECTED_ENDPOINTS = "configGetConnectedEndpoints"
    CONFIG_GET_ESTIMATE_IMPACT = "configGetEstimateImpact"
    CONFIG_GET_ID_UNIVERSE_USAGE = "configGetIdUniverseUsage"
    CONFIG_GET_LAST_BACKED_UP_DOMAINS = "configGetLastBackedUpDomains"
    CONFIG_GET_NET_REFS = "configGetNetRefs"
    CONFIG_GET_POLICY_DOMAIN_GROUP = "configGetPolicyDomainGroup"
    CONFIG_GET_QUALIFIED_DOMAINS = "configGetQualifiedDomains"
    CONFIG_GET_TOKEN_REQUESTORS = "configGetTokenRequestors"
    CONFIG_GRAPHICS_CARD_ITEM = "configGraphicsCardItem"
    CONFIG_IOMITEM = "configIOMItem"
    CONFIG_IMPACT = "configImpact"
    CONFIG_IMPACT_ANALYZER = "configImpactAnalyzer"
    CONFIG_IMPACT_ANALYZER_EP = "configImpactAnalyzerEp"
    CONFIG_INPUT_CONFIG = "configInputConfig"
    CONFIG_INPUT_CONFIG_SET = "configInputConfigSet"
    CONFIG_INSTANTIATE_NNAMED_TEMPLATE = "configInstantiateNNamedTemplate"
    CONFIG_INSTANTIATE_NTEMPLATE = "configInstantiateNTemplate"
    CONFIG_INSTANTIATE_TEMPLATE = "configInstantiateTemplate"
    CONFIG_LOCAL_DISK_ITEM = "configLocalDiskItem"
    CONFIG_LUN_ITEM = "configLunItem"
    CONFIG_MANAGED_EP_IMPACT_RESPONSE = "configManagedEpImpactResponse"
    CONFIG_MAP = "configMap"
    CONFIG_MEMORY_ITEM = "configMemoryItem"
    CONFIG_MO_CHANGE_EVENT = "configMoChangeEvent"
    CONFIG_MOTHERBOARD_ITEM = "configMotherboardItem"
    CONFIG_NET_REF_ITEM = "configNetRefItem"
    CONFIG_ORG_ITEM = "configOrgItem"
    CONFIG_PSUITEM = "configPSUItem"
    CONFIG_POLICY_USAGE_ITEM = "configPolicyUsageItem"
    CONFIG_PORT_ITEM = "configPortItem"
    CONFIG_PUBLISH_VLAN = "configPublishVlan"
    CONFIG_PUBLISH_VSAN = "configPublishVsan"
    CONFIG_REFRESH_IDENTITY = "configRefreshIdentity"
    CONFIG_RELEASE_RESOLVE_CONTEXT = "configReleaseResolveContext"
    CONFIG_REMOTE_SEARCH = "configRemoteSearch"
    CONFIG_RENEW_RESOLVE_CONTEXT = "configRenewResolveContext"
    CONFIG_RESOLVE_ANCESTOR = "configResolveAncestor"
    CONFIG_RESOLVE_CHILDREN = "configResolveChildren"
    CONFIG_RESOLVE_CHILDREN_SORTED = "configResolveChildrenSorted"
    CONFIG_RESOLVE_CLASS = "configResolveClass"
    CONFIG_RESOLVE_CLASS_DB = "configResolveClassDB"
    CONFIG_RESOLVE_CLASS_FILTER_IDX = "configResolveClassFilterIdx"
    CONFIG_RESOLVE_CLASS_IDX = "configResolveClassIdx"
    CONFIG_RESOLVE_CLASS_SORTED = "configResolveClassSorted"
    CONFIG_RESOLVE_CLASSES = "configResolveClasses"
    CONFIG_RESOLVE_CLASSES_SORTED = "configResolveClassesSorted"
    CONFIG_RESOLVE_CONTEXT = "configResolveContext"
    CONFIG_RESOLVE_DN = "configResolveDn"
    CONFIG_RESOLVE_DNS = "configResolveDns"
    CONFIG_RESOLVE_DOMAIN_ELEMENTS = "configResolveDomainElements"
    CONFIG_RESOLVE_PARENT = "configResolveParent"
    CONFIG_RESOLVE_SPOT_LIGHT_IDX = "configResolveSpotLightIdx"
    CONFIG_SCOPE = "configScope"
    CONFIG_SEARCH_OPTIONS = "configSearchOptions"
    CONFIG_SEARCH_RESULT = "configSearchResult"
    CONFIG_SEND_APP_IMPACT_RESPONSE = "configSendAppImpactResponse"
    CONFIG_SERVER_FILTER = "configServerFilter"
    CONFIG_SERVER_ITEM = "configServerItem"
    CONFIG_SERVICE_PROFILE_FILTER = "configServiceProfileFilter"
    CONFIG_SET = "configSet"
    CONFIG_SORTER = "configSorter"
    CONFIG_SPOT_LIGHT_ITEM = "configSpotLightItem"
    CONFIG_STORAGE_ARRAY_PROFILE_FILTER = "configStorageArrayProfileFilter"
    CONFIG_STORAGE_BLADE_FILTER = "configStorageBladeFilter"
    CONFIG_STORAGE_ITEM = "configStorageItem"
    CONFIG_TAGS = "configTags"
    CONFIG_TEMPLATISE = "configTemplatise"
    CONFIG_UCESTIMATE_IMPACT = "configUCEstimateImpact"
    CONFIG_UCIMPACT = "configUCImpact"
    CONSUMER_INST = "consumerInst"
    CONSUMER_INST_FSM = "consumerInstFsm"
    CONSUMER_INST_FSM_STAGE = "consumerInstFsmStage"
    CONSUMER_INST_FSM_TASK = "consumerInstFsmTask"
    CONSUMER_UNIVERSE = "consumerUniverse"
    CONTROLLER_EP = "controllerEp"
    CONTROLLER_EP_FSM = "controllerEpFsm"
    CONTROLLER_EP_FSM_STAGE = "controllerEpFsmStage"
    CONTROLLER_EP_FSM_TASK = "controllerEpFsmTask"
    CPMAINT_ACK = "cpmaintAck"
    CPMAINT_MAINT_POLICY = "cpmaintMaintPolicy"
    DCX_VIF = "dcxVIf"
    DCX_VC = "dcxVc"
    DIAG_LOG_EP = "diagLogEp"
    DIAG_MEMORY_TEST = "diagMemoryTest"
    DIAG_RSLT = "diagRslt"
    DIAG_RUN_POLICY = "diagRunPolicy"
    DIAG_SRV_CAP_PROVIDER = "diagSrvCapProvider"
    DIAG_SRV_CTRL = "diagSrvCtrl"
    DIAG_SRV_CTRL_OPERATION = "diagSrvCtrlOperation"
    DIAG_SRV_CTRL_OPERATION_FSM = "diagSrvCtrlOperationFsm"
    DIAG_SRV_CTRL_OPERATION_FSM_STAGE = "diagSrvCtrlOperationFsmStage"
    DIAG_SRV_CTRL_OPERATION_FSM_TASK = "diagSrvCtrlOperationFsmTask"
    DN = "dn"
    DN_SET = "dnSet"
    DOMAIN_CHASSIS_FEATURE = "domainChassisFeature"
    DOMAIN_CHASSIS_PARAM = "domainChassisParam"
    DOMAIN_CHASSIS_PROFILE_ITEM = "domainChassisProfileItem"
    DOMAIN_ENVIRONMENT_FEATURE = "domainEnvironmentFeature"
    DOMAIN_ENVIRONMENT_PARAM = "domainEnvironmentParam"
    DOMAIN_EP = "domainEp"
    DOMAIN_FAMILY_CAP_PROVIDER = "domainFamilyCapProvider"
    DOMAIN_FEATURE_CATALOG = "domainFeatureCatalog"
    DOMAIN_NETWORK_FEATURE = "domainNetworkFeature"
    DOMAIN_NETWORK_PARAM = "domainNetworkParam"
    DOMAIN_PROFILE = "domainProfile"
    DOMAIN_PROFILE_FSM = "domainProfileFsm"
    DOMAIN_PROFILE_FSM_STAGE = "domainProfileFsmStage"
    DOMAIN_PROFILE_FSM_TASK = "domainProfileFsmTask"
    DOMAIN_SERVER_FEATURE = "domainServerFeature"
    DOMAIN_SERVER_PARAM = "domainServerParam"
    DOMAIN_SERVICE_PROFILE_ITEM = "domainServiceProfileItem"
    DOMAIN_STORAGE_FEATURE = "domainStorageFeature"
    DOMAIN_STORAGE_PARAM = "domainStorageParam"
    DPSEC_MAC = "dpsecMac"
    DUPE_CHANGE_TRACKER = "dupeChangeTracker"
    DUPE_CHANGE_TRACKER_EP = "dupeChangeTrackerEp"
    DUPE_CHANGE_TRACKER_EP_FSM = "dupeChangeTrackerEpFsm"
    DUPE_CHANGE_TRACKER_EP_FSM_STAGE = "dupeChangeTrackerEpFsmStage"
    DUPE_CHANGE_TRACKER_EP_FSM_TASK = "dupeChangeTrackerEpFsmTask"
    DUPE_EP = "dupeEp"
    DUPE_EXT_REQUESTOR = "dupeExtRequestor"
    DUPE_INT_REQUESTOR = "dupeIntRequestor"
    DUPE_SCOPE = "dupeScope"
    DUPE_SCOPE_EP = "dupeScopeEp"
    DUPE_SCOPE_RESULT = "dupeScopeResult"
    EPQOS_DEFINITION = "epqosDefinition"
    EPQOS_EGRESS = "epqosEgress"
    EQ_FILTER = "eqFilter"
    EQUIPMENT_ADVANCED_BOOT_ORDER = "equipmentAdvancedBootOrder"
    EQUIPMENT_BEACON_LED = "equipmentBeaconLed"
    EQUIPMENT_BINDING = "equipmentBinding"
    EQUIPMENT_BLADE_CAP_PROVIDER = "equipmentBladeCapProvider"
    EQUIPMENT_BREAKOUT_CAP = "equipmentBreakoutCap"
    EQUIPMENT_CPMETA = "equipmentCPMeta"
    EQUIPMENT_CHASSIS = "equipmentChassis"
    EQUIPMENT_CHASSIS_ASSOC_CTX = "equipmentChassisAssocCtx"
    EQUIPMENT_CHASSIS_CAP_PROVIDER = "equipmentChassisCapProvider"
    EQUIPMENT_CHASSIS_ISSUES = "equipmentChassisIssues"
    EQUIPMENT_CHASSIS_OPERATION = "equipmentChassisOperation"
    EQUIPMENT_CHASSIS_PROFILE = "equipmentChassisProfile"
    EQUIPMENT_CHASSIS_PROFILE_ASSOC_CTX = "equipmentChassisProfileAssocCtx"
    EQUIPMENT_CHASSIS_PROFILE_FSM = "equipmentChassisProfileFsm"
    EQUIPMENT_CHASSIS_PROFILE_FSM_STAGE = "equipmentChassisProfileFsmStage"
    EQUIPMENT_CHASSIS_PROFILE_FSM_TASK = "equipmentChassisProfileFsmTask"
    EQUIPMENT_CHASSIS_QUAL = "equipmentChassisQual"
    EQUIPMENT_CHASSIS_REQUIREMENT = "equipmentChassisRequirement"
    EQUIPMENT_CHASSIS_STATS = "equipmentChassisStats"
    EQUIPMENT_CHASSIS_STATS_HIST = "equipmentChassisStatsHist"
    EQUIPMENT_CIMC_VMEDIA = "equipmentCimcVmedia"
    EQUIPMENT_CLONE = "equipmentClone"
    EQUIPMENT_COMPUTE_CONN = "equipmentComputeConn"
    EQUIPMENT_COMPUTE_CONN_POLICY = "equipmentComputeConnPolicy"
    EQUIPMENT_DRIVE_SEC_CAP = "equipmentDriveSecCap"
    EQUIPMENT_FAN = "equipmentFan"
    EQUIPMENT_FAN_MODULE = "equipmentFanModule"
    EQUIPMENT_FAN_MODULE_CAP_PROVIDER = "equipmentFanModuleCapProvider"
    EQUIPMENT_FAN_MODULE_STATS = "equipmentFanModuleStats"
    EQUIPMENT_FAN_MODULE_STATS_HIST = "equipmentFanModuleStatsHist"
    EQUIPMENT_FAN_STATS = "equipmentFanStats"
    EQUIPMENT_FAN_STATS_HIST = "equipmentFanStatsHist"
    EQUIPMENT_FEX = "equipmentFex"
    EQUIPMENT_FEX_CAP_PROVIDER = "equipmentFexCapProvider"
    EQUIPMENT_FEX_ENV_STATS = "equipmentFexEnvStats"
    EQUIPMENT_FEX_ENV_STATS_HIST = "equipmentFexEnvStatsHist"
    EQUIPMENT_FEX_OPERATION = "equipmentFexOperation"
    EQUIPMENT_FEX_POWER_SUMMARY = "equipmentFexPowerSummary"
    EQUIPMENT_FEX_POWER_SUMMARY_HIST = "equipmentFexPowerSummaryHist"
    EQUIPMENT_FEX_PSU_INPUT_STATS = "equipmentFexPsuInputStats"
    EQUIPMENT_FEX_PSU_INPUT_STATS_HIST = "equipmentFexPsuInputStatsHist"
    EQUIPMENT_FRU_VARIANT = "equipmentFruVariant"
    EQUIPMENT_GEM_CAP_PROVIDER = "equipmentGemCapProvider"
    EQUIPMENT_HEALTH_LED = "equipmentHealthLed"
    EQUIPMENT_HOST_IF_CAP_PROVIDER = "equipmentHostIfCapProvider"
    EQUIPMENT_IOCARD = "equipmentIOCard"
    EQUIPMENT_IOCARD_CAP_PROVIDER = "equipmentIOCardCapProvider"
    EQUIPMENT_IOCARD_STATS = "equipmentIOCardStats"
    EQUIPMENT_IOCARD_STATS_HIST = "equipmentIOCardStatsHist"
    EQUIPMENT_IMPLIED_STORAGE_ENCLOSURE_DEF = "equipmentImpliedStorageEnclosureDef"
    EQUIPMENT_INDICATOR_LED = "equipmentIndicatorLed"
    EQUIPMENT_INSTANCE = "equipmentInstance"
    EQUIPMENT_INSTANCE_MAPPING = "equipmentInstanceMapping"
    EQUIPMENT_INSTANTIATE_NNAMED_TEMPLATE = "equipmentInstantiateNNamedTemplate"
    EQUIPMENT_INSTANTIATE_NTEMPLATE = "equipmentInstantiateNTemplate"
    EQUIPMENT_INSTANTIATE_TEMPLATE = "equipmentInstantiateTemplate"
    EQUIPMENT_LOCAL_DISK_CAP_PROVIDER = "equipmentLocalDiskCapProvider"
    EQUIPMENT_LOCAL_DISK_CONTROLLER_CAP_PROVIDER = "equipmentLocalDiskControllerCapProvider"
    EQUIPMENT_LOCAL_DISK_DEF = "equipmentLocalDiskDef"
    EQUIPMENT_LOCAL_TEMPL_DEF = "equipmentLocalTemplDef"
    EQUIPMENT_LOCATOR_LED = "equipmentLocatorLed"
    EQUIPMENT_LOCATOR_LED_OPERATION = "equipmentLocatorLedOperation"
    EQUIPMENT_MANUFACTURING_DEF = "equipmentManufacturingDef"
    EQUIPMENT_MEMORY_UNIT_CAP_PROVIDER = "equipmentMemoryUnitCapProvider"
    EQUIPMENT_NETWORK_ELEMENT_FAN_STATS = "equipmentNetworkElementFanStats"
    EQUIPMENT_NETWORK_ELEMENT_FAN_STATS_HIST = "equipmentNetworkElementFanStatsHist"
    EQUIPMENT_PCI_DEF = "equipmentPciDef"
    EQUIPMENT_PHYSICAL_QUAL = "equipmentPhysicalQual"
    EQUIPMENT_PICTURE = "equipmentPicture"
    EQUIPMENT_POOL = "equipmentPool"
    EQUIPMENT_POOLABLE = "equipmentPoolable"
    EQUIPMENT_POOLING_POLICY = "equipmentPoolingPolicy"
    EQUIPMENT_PROCESSOR_UNIT_CAP_PROVIDER = "equipmentProcessorUnitCapProvider"
    EQUIPMENT_PSU = "equipmentPsu"
    EQUIPMENT_PSU_CAP_PROVIDER = "equipmentPsuCapProvider"
    EQUIPMENT_PSU_INPUT_STATS = "equipmentPsuInputStats"
    EQUIPMENT_PSU_INPUT_STATS_HIST = "equipmentPsuInputStatsHist"
    EQUIPMENT_PSU_OUTPUT_STATS = "equipmentPsuOutputStats"
    EQUIPMENT_PSU_OUTPUT_STATS_HIST = "equipmentPsuOutputStatsHist"
    EQUIPMENT_PSU_STATS = "equipmentPsuStats"
    EQUIPMENT_PSU_STATS_HIST = "equipmentPsuStatsHist"
    EQUIPMENT_QUAL = "equipmentQual"
    EQUIPMENT_RACK_UNIT_CAP_PROVIDER = "equipmentRackUnitCapProvider"
    EQUIPMENT_RACK_UNIT_FAN_STATS = "equipmentRackUnitFanStats"
    EQUIPMENT_RACK_UNIT_FAN_STATS_HIST = "equipmentRackUnitFanStatsHist"
    EQUIPMENT_RACK_UNIT_PSU_STATS = "equipmentRackUnitPsuStats"
    EQUIPMENT_RACK_UNIT_PSU_STATS_HIST = "equipmentRackUnitPsuStatsHist"
    EQUIPMENT_REQUIREMENT = "equipmentRequirement"
    EQUIPMENT_SECURE_BOOT = "equipmentSecureBoot"
    EQUIPMENT_SERVER_FEATURE_CAP = "equipmentServerFeatureCap"
    EQUIPMENT_SERVER_UNIT_CAP_PROVIDER = "equipmentServerUnitCapProvider"
    EQUIPMENT_SHARED_IOMODULE = "equipmentSharedIOModule"
    EQUIPMENT_SIOC_TEMP_STATS = "equipmentSiocTempStats"
    EQUIPMENT_SIOC_TEMP_STATS_HIST = "equipmentSiocTempStatsHist"
    EQUIPMENT_STORAGE_PROCESSOR_CAP = "equipmentStorageProcessorCap"
    EQUIPMENT_SWITCH_CAP_PROVIDER = "equipmentSwitchCapProvider"
    EQUIPMENT_SWITCH_CARD = "equipmentSwitchCard"
    EQUIPMENT_SWITCH_IOCARD = "equipmentSwitchIOCard"
    EQUIPMENT_SWITCH_IOCARD_CAP_PROVIDER = "equipmentSwitchIOCardCapProvider"
    EQUIPMENT_SYSTEM_FRU_CAP_PROVIDER = "equipmentSystemFruCapProvider"
    EQUIPMENT_SYSTEM_IOCONTROLLER = "equipmentSystemIOController"
    EQUIPMENT_SYSTEM_IOCONTROLLER_OPERATION = "equipmentSystemIOControllerOperation"
    EQUIPMENT_TEMPLATE = "equipmentTemplate"
    EQUIPMENT_TEMPLATE_MAPPING = "equipmentTemplateMapping"
    EQUIPMENT_TEMPLATISE = "equipmentTemplatise"
    EQUIPMENT_TIER = "equipmentTier"
    EQUIPMENT_UNIFIED_PORT_CAP_PROVIDER = "equipmentUnifiedPortCapProvider"
    EQUIPMENT_XCVR = "equipmentXcvr"
    ETHER_ERR_STATS = "etherErrStats"
    ETHER_ERR_STATS_HIST = "etherErrStatsHist"
    ETHER_FCOE_INTERFACE_STATS = "etherFcoeInterfaceStats"
    ETHER_FCOE_INTERFACE_STATS_HIST = "etherFcoeInterfaceStatsHist"
    ETHER_LOSS_STATS = "etherLossStats"
    ETHER_LOSS_STATS_HIST = "etherLossStatsHist"
    ETHER_PIO = "etherPIo"
    ETHER_PAUSE_STATS = "etherPauseStats"
    ETHER_PAUSE_STATS_HIST = "etherPauseStatsHist"
    ETHER_RX_STATS = "etherRxStats"
    ETHER_RX_STATS_HIST = "etherRxStatsHist"
    ETHER_SERVER_INT_FIO = "etherServerIntFIo"
    ETHER_SWITCH_INT_FIO = "etherSwitchIntFIo"
    ETHER_TX_STATS = "etherTxStats"
    ETHER_TX_STATS_HIST = "etherTxStatsHist"
    EVENT_APPLICATION = "eventApplication"
    EVENT_EP_CTRL = "eventEpCtrl"
    EVENT_HOLDER = "eventHolder"
    EVENT_INST = "eventInst"
    EVENT_LOG = "eventLog"
    EVENT_POLICY = "eventPolicy"
    EVENT_RECORD = "eventRecord"
    EVENT_SEND_HEARTBEAT = "eventSendHeartbeat"
    EVENT_SUBSCRIBE = "eventSubscribe"
    EVENT_SUBSCRIBE_APPS = "eventSubscribeApps"
    EXTMGMT_ARP_TARGETS = "extmgmtArpTargets"
    EXTMGMT_GATEWAY_PING = "extmgmtGatewayPing"
    EXTMGMT_IF_MON_POLICY = "extmgmtIfMonPolicy"
    EXTMGMT_MII_STATUS = "extmgmtMiiStatus"
    EXTMGMT_NDISC_TARGETS = "extmgmtNdiscTargets"
    EXTPOL_CLIENT = "extpolClient"
    EXTPOL_CLIENT_CONT = "extpolClientCont"
    EXTPOL_CLIENT_FSM = "extpolClientFsm"
    EXTPOL_CLIENT_FSM_STAGE = "extpolClientFsmStage"
    EXTPOL_CLIENT_FSM_TASK = "extpolClientFsmTask"
    EXTPOL_CONTROLLER = "extpolController"
    EXTPOL_CONTROLLER_CONT = "extpolControllerCont"
    EXTPOL_DOMAIN = "extpolDomain"
    EXTPOL_EP = "extpolEp"
    EXTPOL_EP_FSM = "extpolEpFsm"
    EXTPOL_EP_FSM_STAGE = "extpolEpFsmStage"
    EXTPOL_EP_FSM_TASK = "extpolEpFsmTask"
    EXTPOL_HBSTATUS = "extpolHBStatus"
    EXTPOL_PROVIDER = "extpolProvider"
    EXTPOL_PROVIDER_CONT = "extpolProviderCont"
    EXTPOL_REGISTRY = "extpolRegistry"
    EXTPOL_REGISTRY_CAPABILITY = "extpolRegistryCapability"
    EXTPOL_SYSTEM_CONTEXT = "extpolSystemContext"
    EXTPOL_VERSION_HOLDER = "extpolVersionHolder"
    EXTVMM_NETWORK_SETS = "extvmmNetworkSets"
    EXTVMM_VMNETWORK_SETS = "extvmmVMNetworkSets"
    FABRIC_BREAKOUT = "fabricBreakout"
    FABRIC_BREAKOUT_OPERATION = "fabricBreakoutOperation"
    FABRIC_CABLING = "fabricCabling"
    FABRIC_CABLING_SW = "fabricCablingSw"
    FABRIC_CARTRIDGE_SLOT_EP = "fabricCartridgeSlotEp"
    FABRIC_CARTRIDGE_SLOT_EP_OPERATION = "fabricCartridgeSlotEpOperation"
    FABRIC_CDP_LINK_POLICY = "fabricCdpLinkPolicy"
    FABRIC_CHANGED_OBJECT_REF = "fabricChangedObjectRef"
    FABRIC_CHASSIS_EP = "fabricChassisEp"
    FABRIC_COMPUTE_MSLOT_EP = "fabricComputeMSlotEp"
    FABRIC_COMPUTE_PH_EP = "fabricComputePhEp"
    FABRIC_COMPUTE_PH_EP_OPERATION = "fabricComputePhEpOperation"
    FABRIC_COMPUTE_SLOT_EP = "fabricComputeSlotEp"
    FABRIC_COMPUTE_SLOT_EP_OPERATION = "fabricComputeSlotEpOperation"
    FABRIC_CONSUMER = "fabricConsumer"
    FABRIC_DCE_SRV = "fabricDceSrv"
    FABRIC_DCE_SW_SRV = "fabricDceSwSrv"
    FABRIC_DCE_SW_SRV_EP = "fabricDceSwSrvEp"
    FABRIC_DCE_SW_SRV_EP_OPERATION = "fabricDceSwSrvEpOperation"
    FABRIC_DCE_SW_SRV_PC = "fabricDceSwSrvPc"
    FABRIC_DCE_SW_SRV_PC_EP = "fabricDceSwSrvPcEp"
    FABRIC_DCE_SW_SRV_PC_EP_OPERATION = "fabricDceSwSrvPcEpOperation"
    FABRIC_DCE_SW_SRV_PC_OPERATION = "fabricDceSwSrvPcOperation"
    FABRIC_DCE_SW_SRV_PC_OPERATION_FSM = "fabricDceSwSrvPcOperationFsm"
    FABRIC_DCE_SW_SRV_PC_OPERATION_FSM_STAGE = "fabricDceSwSrvPcOperationFsmStage"
    FABRIC_DOMAIN_EP = "fabricDomainEp"
    FABRIC_ENCLOSURE_PH_EP = "fabricEnclosurePhEp"
    FABRIC_ENCLOSURE_PH_EP_OPERATION = "fabricEnclosurePhEpOperation"
    FABRIC_ENCLOSURE_SLOT_EP = "fabricEnclosureSlotEp"
    FABRIC_ENCLOSURE_SLOT_EP_OPERATION = "fabricEnclosureSlotEpOperation"
    FABRIC_EP = "fabricEp"
    FABRIC_ETH_ESTC = "fabricEthEstc"
    FABRIC_ETH_ESTC_CLOUD = "fabricEthEstcCloud"
    FABRIC_ETH_ESTC_EP = "fabricEthEstcEp"
    FABRIC_ETH_ESTC_EP_OPERATION = "fabricEthEstcEpOperation"
    FABRIC_ETH_ESTC_EP_OPERATION_FSM = "fabricEthEstcEpOperationFsm"
    FABRIC_ETH_ESTC_EP_OPERATION_FSM_STAGE = "fabricEthEstcEpOperationFsmStage"
    FABRIC_ETH_ESTC_PC = "fabricEthEstcPc"
    FABRIC_ETH_ESTC_PC_EP = "fabricEthEstcPcEp"
    FABRIC_ETH_ESTC_PC_EP_OPERATION = "fabricEthEstcPcEpOperation"
    FABRIC_ETH_ESTC_PC_OPERATION = "fabricEthEstcPcOperation"
    FABRIC_ETH_ESTC_PC_OPERATION_FSM = "fabricEthEstcPcOperationFsm"
    FABRIC_ETH_ESTC_PC_OPERATION_FSM_STAGE = "fabricEthEstcPcOperationFsmStage"
    FABRIC_ETH_LAN = "fabricEthLan"
    FABRIC_ETH_LAN_EP = "fabricEthLanEp"
    FABRIC_ETH_LAN_EP_OPERATION = "fabricEthLanEpOperation"
    FABRIC_ETH_LAN_EP_OPERATION_FSM = "fabricEthLanEpOperationFsm"
    FABRIC_ETH_LAN_EP_OPERATION_FSM_STAGE = "fabricEthLanEpOperationFsmStage"
    FABRIC_ETH_LAN_PC = "fabricEthLanPc"
    FABRIC_ETH_LAN_PC_EP = "fabricEthLanPcEp"
    FABRIC_ETH_LAN_PC_EP_OPERATION = "fabricEthLanPcEpOperation"
    FABRIC_ETH_LAN_PC_OPERATION = "fabricEthLanPcOperation"
    FABRIC_ETH_LAN_PC_OPERATION_FSM = "fabricEthLanPcOperationFsm"
    FABRIC_ETH_LAN_PC_OPERATION_FSM_STAGE = "fabricEthLanPcOperationFsmStage"
    FABRIC_ETH_LINK_PROFILE = "fabricEthLinkProfile"
    FABRIC_ETH_MON = "fabricEthMon"
    FABRIC_ETH_MON_DEST_EP = "fabricEthMonDestEp"
    FABRIC_ETH_MON_DEST_EP_OPERATION = "fabricEthMonDestEpOperation"
    FABRIC_ETH_MON_LAN = "fabricEthMonLan"
    FABRIC_ETH_MON_OPERATION = "fabricEthMonOperation"
    FABRIC_ETH_MON_OPERATION_FSM = "fabricEthMonOperationFsm"
    FABRIC_ETH_MON_OPERATION_FSM_STAGE = "fabricEthMonOperationFsmStage"
    FABRIC_ETH_MON_SRC_EP = "fabricEthMonSrcEp"
    FABRIC_ETH_MON_SRC_EP_OPERATION = "fabricEthMonSrcEpOperation"
    FABRIC_ETH_MON_SRC_REF = "fabricEthMonSrcRef"
    FABRIC_ETH_PORT_OPERATION_FSM = "fabricEthPortOperationFsm"
    FABRIC_ETH_PORT_OPERATION_FSM_STAGE = "fabricEthPortOperationFsmStage"
    FABRIC_ETH_TARGET_EP = "fabricEthTargetEp"
    FABRIC_ETH_TARGET_EP_OPERATION = "fabricEthTargetEpOperation"
    FABRIC_ETH_VLAN_PC = "fabricEthVlanPc"
    FABRIC_ETH_VLAN_PORT_EP = "fabricEthVlanPortEp"
    FABRIC_ETHER_REF = "fabricEtherRef"
    FABRIC_EXTENSION = "fabricExtension"
    FABRIC_FIPORT_OPERATION_FSM = "fabricFIPortOperationFsm"
    FABRIC_FIPORT_OPERATION_FSM_STAGE = "fabricFIPortOperationFsmStage"
    FABRIC_FIPORT_OPERATION_FSM_TASK = "fabricFIPortOperationFsmTask"
    FABRIC_FC_ENDPOINT = "fabricFcEndpoint"
    FABRIC_FC_ESTC = "fabricFcEstc"
    FABRIC_FC_ESTC_CLOUD = "fabricFcEstcCloud"
    FABRIC_FC_ESTC_EP = "fabricFcEstcEp"
    FABRIC_FC_ESTC_EP_OPERATION = "fabricFcEstcEpOperation"
    FABRIC_FC_ESTC_EP_OPERATION_FSM = "fabricFcEstcEpOperationFsm"
    FABRIC_FC_ESTC_EP_OPERATION_FSM_STAGE = "fabricFcEstcEpOperationFsmStage"
    FABRIC_FC_MON = "fabricFcMon"
    FABRIC_FC_MON_DEST_EP = "fabricFcMonDestEp"
    FABRIC_FC_MON_DEST_EP_OPERATION = "fabricFcMonDestEpOperation"
    FABRIC_FC_MON_OPERATION = "fabricFcMonOperation"
    FABRIC_FC_MON_OPERATION_FSM = "fabricFcMonOperationFsm"
    FABRIC_FC_MON_OPERATION_FSM_STAGE = "fabricFcMonOperationFsmStage"
    FABRIC_FC_MON_SAN = "fabricFcMonSan"
    FABRIC_FC_MON_SRC_EP = "fabricFcMonSrcEp"
    FABRIC_FC_MON_SRC_EP_OPERATION = "fabricFcMonSrcEpOperation"
    FABRIC_FC_MON_SRC_REF = "fabricFcMonSrcRef"
    FABRIC_FC_PORT_OPERATION_FSM = "fabricFcPortOperationFsm"
    FABRIC_FC_PORT_OPERATION_FSM_STAGE = "fabricFcPortOperationFsmStage"
    FABRIC_FC_SAN = "fabricFcSan"
    FABRIC_FC_SAN_EP = "fabricFcSanEp"
    FABRIC_FC_SAN_EP_OPERATION = "fabricFcSanEpOperation"
    FABRIC_FC_SAN_EP_OPERATION_FSM = "fabricFcSanEpOperationFsm"
    FABRIC_FC_SAN_EP_OPERATION_FSM_STAGE = "fabricFcSanEpOperationFsmStage"
    FABRIC_FC_SAN_PC = "fabricFcSanPc"
    FABRIC_FC_SAN_PC_EP = "fabricFcSanPcEp"
    FABRIC_FC_SAN_PC_EP_OPERATION = "fabricFcSanPcEpOperation"
    FABRIC_FC_SAN_PC_OPERATION = "fabricFcSanPcOperation"
    FABRIC_FC_SAN_PC_OPERATION_FSM = "fabricFcSanPcOperationFsm"
    FABRIC_FC_SAN_PC_OPERATION_FSM_STAGE = "fabricFcSanPcOperationFsmStage"
    FABRIC_FC_UPLINK_OPERATION = "fabricFcUplinkOperation"
    FABRIC_FC_USER_ZONE = "fabricFcUserZone"
    FABRIC_FC_USER_ZONE_IVT = "fabricFcUserZoneIvt"
    FABRIC_FC_VSAN_PC = "fabricFcVsanPc"
    FABRIC_FC_VSAN_PORT_EP = "fabricFcVsanPortEp"
    FABRIC_FC_ZONE_PROFILE = "fabricFcZoneProfile"
    FABRIC_FC_ZONE_PROFILE_FSM = "fabricFcZoneProfileFsm"
    FABRIC_FC_ZONE_PROFILE_FSM_STAGE = "fabricFcZoneProfileFsmStage"
    FABRIC_FC_ZONE_PROFILE_FSM_TASK = "fabricFcZoneProfileFsmTask"
    FABRIC_FC_ZONE_PROFILE_IVT = "fabricFcZoneProfileIvt"
    FABRIC_FCOE_ESTC_EP = "fabricFcoeEstcEp"
    FABRIC_FCOE_ESTC_EP_OPERATION = "fabricFcoeEstcEpOperation"
    FABRIC_FCOE_ESTC_EP_OPERATION_FSM = "fabricFcoeEstcEpOperationFsm"
    FABRIC_FCOE_ESTC_EP_OPERATION_FSM_STAGE = "fabricFcoeEstcEpOperationFsmStage"
    FABRIC_FCOE_SAN_EP = "fabricFcoeSanEp"
    FABRIC_FCOE_SAN_EP_OPERATION = "fabricFcoeSanEpOperation"
    FABRIC_FCOE_SAN_EP_OPERATION_FSM = "fabricFcoeSanEpOperationFsm"
    FABRIC_FCOE_SAN_EP_OPERATION_FSM_STAGE = "fabricFcoeSanEpOperationFsmStage"
    FABRIC_FCOE_SAN_PC = "fabricFcoeSanPc"
    FABRIC_FCOE_SAN_PC_EP = "fabricFcoeSanPcEp"
    FABRIC_FCOE_SAN_PC_EP_OPERATION = "fabricFcoeSanPcEpOperation"
    FABRIC_FCOE_SAN_PC_OPERATION = "fabricFcoeSanPcOperation"
    FABRIC_FCOE_SAN_PC_OPERATION_FSM = "fabricFcoeSanPcOperationFsm"
    FABRIC_FCOE_SAN_PC_OPERATION_FSM_STAGE = "fabricFcoeSanPcOperationFsmStage"
    FABRIC_FCOE_VSAN_PC = "fabricFcoeVsanPc"
    FABRIC_FCOE_VSAN_PORT_EP = "fabricFcoeVsanPortEp"
    FABRIC_HOLDER = "fabricHolder"
    FABRIC_IF = "fabricIf"
    FABRIC_LACP_POLICY = "fabricLacpPolicy"
    FABRIC_LAN_ACCESS_MGR = "fabricLanAccessMgr"
    FABRIC_LAN_CLOUD = "fabricLanCloud"
    FABRIC_LAN_CLOUD_POLICY = "fabricLanCloudPolicy"
    FABRIC_LAN_MON_CLOUD = "fabricLanMonCloud"
    FABRIC_LAN_PIN_GROUP = "fabricLanPinGroup"
    FABRIC_LAN_PIN_GROUP_OPERATION = "fabricLanPinGroupOperation"
    FABRIC_LAN_PIN_TARGET = "fabricLanPinTarget"
    FABRIC_LAN_PIN_TARGET_OPERATION = "fabricLanPinTargetOperation"
    FABRIC_LAST_ACKED_SLOT = "fabricLastAckedSlot"
    FABRIC_MULTICAST_POLICY = "fabricMulticastPolicy"
    FABRIC_NET_GROUP = "fabricNetGroup"
    FABRIC_NET_GROUP_EP = "fabricNetGroupEp"
    FABRIC_NET_GROUP_PERMIT = "fabricNetGroupPermit"
    FABRIC_NET_GROUP_REF = "fabricNetGroupRef"
    FABRIC_NET_GROUP_REQ = "fabricNetGroupReq"
    FABRIC_ORG_VLAN_POLICY = "fabricOrgVlanPolicy"
    FABRIC_PERMITS_FOR_EXISTING_VLAN_NAMES = "fabricPermitsForExistingVlanNames"
    FABRIC_POOLABLE_VLAN = "fabricPoolableVlan"
    FABRIC_POOLED_VLAN = "fabricPooledVlan"
    FABRIC_RESOLVE_VLAN_PERMITS = "fabricResolveVlanPermits"
    FABRIC_SAN_CLOUD = "fabricSanCloud"
    FABRIC_SAN_GROUP = "fabricSanGroup"
    FABRIC_SAN_GROUP_REF = "fabricSanGroupRef"
    FABRIC_SAN_MON_CLOUD = "fabricSanMonCloud"
    FABRIC_SAN_PIN_GROUP = "fabricSanPinGroup"
    FABRIC_SAN_PIN_GROUP_OPERATION = "fabricSanPinGroupOperation"
    FABRIC_SAN_PIN_TARGET = "fabricSanPinTarget"
    FABRIC_SAN_PIN_TARGET_OPERATION = "fabricSanPinTargetOperation"
    FABRIC_SUB_GROUP = "fabricSubGroup"
    FABRIC_SW_CH_PH_EP = "fabricSwChPhEp"
    FABRIC_SW_CH_PH_EP_OPERATION = "fabricSwChPhEpOperation"
    FABRIC_SW_SUB_GROUP = "fabricSwSubGroup"
    FABRIC_SYSTEM = "fabricSystem"
    FABRIC_UDLD_LINK_POLICY = "fabricUdldLinkPolicy"
    FABRIC_UDLD_POLICY = "fabricUdldPolicy"
    FABRIC_VCON = "fabricVCon"
    FABRIC_VCON_PROFILE = "fabricVConProfile"
    FABRIC_VLAN = "fabricVlan"
    FABRIC_VLAN_EP = "fabricVlanEp"
    FABRIC_VLAN_GROUP_REQ = "fabricVlanGroupReq"
    FABRIC_VLAN_PERMIT = "fabricVlanPermit"
    FABRIC_VLAN_PERMIT_ITEM = "fabricVlanPermitItem"
    FABRIC_VLAN_REQ = "fabricVlanReq"
    FABRIC_VNET_EP_SYNC_EP = "fabricVnetEpSyncEp"
    FABRIC_VNET_EP_SYNC_EP_FSM = "fabricVnetEpSyncEpFsm"
    FABRIC_VNET_EP_SYNC_EP_FSM_STAGE = "fabricVnetEpSyncEpFsmStage"
    FABRIC_VNET_EP_SYNC_EP_FSM_TASK = "fabricVnetEpSyncEpFsmTask"
    FABRIC_VNET_ID_EP_OVERLAP_CHECK = "fabricVnetIdEpOverlapCheck"
    FABRIC_VSAN = "fabricVsan"
    FABRIC_VSAN_EP = "fabricVsanEp"
    FABRIC_VSAN_MEMBERSHIP = "fabricVsanMembership"
    FAULT_ACK_FAULT = "faultAckFault"
    FAULT_ACK_FAULT_BY_DN = "faultAckFaultByDn"
    FAULT_ACK_FAULTS = "faultAckFaults"
    FAULT_ACK_FAULTS_BY_DN = "faultAckFaultsByDn"
    FAULT_DOMAIN_EP = "faultDomainEp"
    FAULT_DOMAIN_INST = "faultDomainInst"
    FAULT_GLOBAL_SEVERITY_HOLDER = "faultGlobalSeverityHolder"
    FAULT_GLOBAL_TYPED_HOLDER = "faultGlobalTypedHolder"
    FAULT_HOLDER = "faultHolder"
    FAULT_INST = "faultInst"
    FAULT_LOCAL_TYPED_HOLDER = "faultLocalTypedHolder"
    FAULT_POLICY = "faultPolicy"
    FAULT_RESOLVE_FAULT = "faultResolveFault"
    FAULT_SUMMARY = "faultSummary"
    FAULT_SUMMARY_INST = "faultSummaryInst"
    FAULT_SVC_SUMMARY = "faultSvcSummary"
    FAULT_TYPED_HOLDER = "faultTypedHolder"
    FC_ERR_STATS = "fcErrStats"
    FC_ERR_STATS_HIST = "fcErrStatsHist"
    FC_PIO = "fcPIo"
    FC_STATS = "fcStats"
    FC_STATS_HIST = "fcStatsHist"
    FCPOOL_ADDR = "fcpoolAddr"
    FCPOOL_BLOCK = "fcpoolBlock"
    FCPOOL_BOOT_TARGET = "fcpoolBootTarget"
    FCPOOL_FORMAT = "fcpoolFormat"
    FCPOOL_INITIATOR = "fcpoolInitiator"
    FCPOOL_INITIATOR_EP = "fcpoolInitiatorEp"
    FCPOOL_INITIATORS = "fcpoolInitiators"
    FCPOOL_UNIVERSE = "fcpoolUniverse"
    FD_BLADE = "fdBlade"
    FD_BLADE_FSM = "fdBladeFsm"
    FD_BLADE_FSM_STAGE = "fdBladeFsmStage"
    FD_CHASSIS = "fdChassis"
    FD_PHYSICAL_FSM = "fdPhysicalFsm"
    FD_PHYSICAL_FSM_STAGE = "fdPhysicalFsmStage"
    FD_PHYSICAL_FSM_TASK = "fdPhysicalFsmTask"
    FD_RACK_UNIT = "fdRackUnit"
    FD_RACK_UNIT_FSM = "fdRackUnitFsm"
    FD_RACK_UNIT_FSM_STAGE = "fdRackUnitFsmStage"
    FEATURE_CATALOG_EP = "featureCatalogEp"
    FEATURE_CHASSIS_DEF = "featureChassisDef"
    FEATURE_ENV_DEF = "featureEnvDef"
    FEATURE_NETWORK_DEF = "featureNetworkDef"
    FEATURE_SERVER_DEF = "featureServerDef"
    FEATURE_STORAGE_DEF = "featureStorageDef"
    FILTER_FILTER = "filterFilter"
    FIRMWARE_ACK = "firmwareAck"
    FIRMWARE_AUTO_SYNC_POLICY = "firmwareAutoSyncPolicy"
    FIRMWARE_BOOT_DEFINITION = "firmwareBootDefinition"
    FIRMWARE_BOOT_UNIT = "firmwareBootUnit"
    FIRMWARE_BUNDLE_INFO = "firmwareBundleInfo"
    FIRMWARE_BUNDLE_INFO_DIGEST = "firmwareBundleInfoDigest"
    FIRMWARE_BUNDLE_TYPE = "firmwareBundleType"
    FIRMWARE_BUNDLE_TYPE_CAP_PROVIDER = "firmwareBundleTypeCapProvider"
    FIRMWARE_CATALOG_PACK = "firmwareCatalogPack"
    FIRMWARE_CATALOG_PACK_CONFIG = "firmwareCatalogPackConfig"
    FIRMWARE_CATALOGUE = "firmwareCatalogue"
    FIRMWARE_CHASSIS_COMPONENT_SPEC = "firmwareChassisComponentSpec"
    FIRMWARE_CHASSIS_PACK = "firmwareChassisPack"
    FIRMWARE_COMP_SOURCE = "firmwareCompSource"
    FIRMWARE_COMP_TARGET = "firmwareCompTarget"
    FIRMWARE_COMPONENT_SPEC = "firmwareComponentSpec"
    FIRMWARE_COMPUTE_HOST_PACK = "firmwareComputeHostPack"
    FIRMWARE_COMPUTE_MGMT_PACK = "firmwareComputeMgmtPack"
    FIRMWARE_COMPUTE_STORAGE_PACK = "firmwareComputeStoragePack"
    FIRMWARE_CONNECTION_POLICY = "firmwareConnectionPolicy"
    FIRMWARE_DEPENDENCY = "firmwareDependency"
    FIRMWARE_DIST_IMAGE = "firmwareDistImage"
    FIRMWARE_DISTRIBUTABLE = "firmwareDistributable"
    FIRMWARE_DISTRIBUTABLE_FSM = "firmwareDistributableFsm"
    FIRMWARE_DISTRIBUTABLE_FSM_STAGE = "firmwareDistributableFsmStage"
    FIRMWARE_DISTRIBUTABLE_FSM_TASK = "firmwareDistributableFsmTask"
    FIRMWARE_DOMAIN_INFO = "firmwareDomainInfo"
    FIRMWARE_DOMAIN_INFRA_PROFILE = "firmwareDomainInfraProfile"
    FIRMWARE_DOWNLOAD_POLICY = "firmwareDownloadPolicy"
    FIRMWARE_DOWNLOADER = "firmwareDownloader"
    FIRMWARE_DOWNLOADER_FSM = "firmwareDownloaderFsm"
    FIRMWARE_DOWNLOADER_FSM_STAGE = "firmwareDownloaderFsmStage"
    FIRMWARE_DOWNLOADER_FSM_TASK = "firmwareDownloaderFsmTask"
    FIRMWARE_ESTIMATE_PACK_IMPACT = "firmwareEstimatePackImpact"
    FIRMWARE_EXCLUDE_CHASSIS_COMPONENT = "firmwareExcludeChassisComponent"
    FIRMWARE_EXCLUDE_SERVER_COMPONENT = "firmwareExcludeServerComponent"
    FIRMWARE_IMAGE = "firmwareImage"
    FIRMWARE_INFRA = "firmwareInfra"
    FIRMWARE_INFRA_PACK = "firmwareInfraPack"
    FIRMWARE_INFRA_PACK_CONFIG = "firmwareInfraPackConfig"
    FIRMWARE_INFRA_POLICY = "firmwareInfraPolicy"
    FIRMWARE_INSTALL_ALL = "firmwareInstallAll"
    FIRMWARE_INSTALL_IMPACT = "firmwareInstallImpact"
    FIRMWARE_POLICY = "firmwarePolicy"
    FIRMWARE_PRODUCT_FAMILY = "firmwareProductFamily"
    FIRMWARE_REMOTE_CATALOGUE = "firmwareRemoteCatalogue"
    FIRMWARE_RUNNING = "firmwareRunning"
    FIRMWARE_SOURCE = "firmwareSource"
    FIRMWARE_STATUS = "firmwareStatus"
    FIRMWARE_STORAGE_PACK = "firmwareStoragePack"
    FIRMWARE_SYSTEM = "firmwareSystem"
    FIRMWARE_TYPE = "firmwareType"
    FIRMWARE_UPDATABLE = "firmwareUpdatable"
    FIRMWARE_UPGRADE_DETAIL = "firmwareUpgradeDetail"
    FIRMWARE_UPGRADE_INFO = "firmwareUpgradeInfo"
    FLOWCTRL_DEFINITION = "flowctrlDefinition"
    FLOWCTRL_ITEM = "flowctrlItem"
    FSM_DEBUG_ACTION = "fsmDebugAction"
    FSM_STATUS = "fsmStatus"
    GE_FILTER = "geFilter"
    GL_APPEND_RULE = "glAppendRule"
    GL_BLOCK_EP = "glBlockEp"
    GL_BLOCK_OP = "glBlockOp"
    GL_BY_MO = "glByMo"
    GL_COMPLEX_REF_EP = "glComplexRefEp"
    GL_CONFLICT_EP = "glConflictEp"
    GL_CONFLICT_RESOLUTION_RULE_EP = "glConflictResolutionRuleEp"
    GL_DOMAIN_EP = "glDomainEp"
    GL_EP = "glEp"
    GL_GLOBAL_DEFAULT_POLICY_EP = "glGlobalDefaultPolicyEp"
    GL_ID_REF = "glIdRef"
    GL_ID_REF_EP = "glIdRefEp"
    GL_IDENT_CTX_EP = "glIdentCtxEp"
    GL_IDENT_CTX_OP = "glIdentCtxOp"
    GL_IDENT_CTX_RES_OP = "glIdentCtxResOp"
    GL_IDENT_CTX_RES_OP_FSM = "glIdentCtxResOpFsm"
    GL_IDENT_CTX_RES_OP_FSM_STAGE = "glIdentCtxResOpFsmStage"
    GL_IDENT_CTX_RES_OP_FSM_TASK = "glIdentCtxResOpFsmTask"
    GL_INVENTORY_EP = "glInventoryEp"
    GL_LSP = "glLsp"
    GL_MCAST_POLICY = "glMcastPolicy"
    GL_OPERATION_EP = "glOperationEp"
    GL_PATH_EP = "glPathEp"
    GL_POLICY = "glPolicy"
    GL_POLICY_ALGORITHMED_OP = "glPolicyAlgorithmedOp"
    GL_POLICY_EP = "glPolicyEp"
    GL_POLICY_INV_EP = "glPolicyInvEp"
    GL_POLICY_NAME_RULE_EP = "glPolicyNameRuleEp"
    GL_POLICY_OP = "glPolicyOp"
    GL_POLICY_REF = "glPolicyRef"
    GL_POLICY_REF_EP = "glPolicyRefEp"
    GL_POLICY_RES_OP = "glPolicyResOp"
    GL_POLICY_RESOLUTION_EP = "glPolicyResolutionEp"
    GL_POOL = "glPool"
    GL_POOL_EP = "glPoolEp"
    GL_POOL_INV_EP = "glPoolInvEp"
    GL_POOL_OP = "glPoolOp"
    GL_REFS_EP = "glRefsEp"
    GL_REQUEST = "glRequest"
    GL_REQUEST_FSM = "glRequestFsm"
    GL_REQUEST_FSM_STAGE = "glRequestFsmStage"
    GL_REQUEST_FSM_TASK = "glRequestFsmTask"
    GL_REQUEST_VNET_EP = "glRequestVnetEp"
    GL_REQUEST_VNET_EP_DOMAIN_EP = "glRequestVnetEpDomainEp"
    GL_REQUEST_VNET_EP_DOMAIN_EP_FSM = "glRequestVnetEpDomainEpFsm"
    GL_REQUEST_VNET_EP_DOMAIN_EP_FSM_STAGE = "glRequestVnetEpDomainEpFsmStage"
    GL_REQUEST_VNET_EP_DOMAIN_EP_FSM_TASK = "glRequestVnetEpDomainEpFsmTask"
    GL_REQUEST_VNET_EP_FSM = "glRequestVnetEpFsm"
    GL_REQUEST_VNET_EP_FSM_STAGE = "glRequestVnetEpFsmStage"
    GL_REQUEST_VNET_EP_FSM_TASK = "glRequestVnetEpFsmTask"
    GL_REQUEST_VNET_EP_HOLDER = "glRequestVnetEpHolder"
    GL_REQUESTOR = "glRequestor"
    GL_REQUESTOR_EP = "glRequestorEp"
    GL_SPINV_EP = "glSPInvEp"
    GL_SERVER_POOL_RES_OP = "glServerPoolResOp"
    GL_SERVICE_PROFILE = "glServiceProfile"
    GL_SP_DEF_EP = "glSpDefEp"
    GL_TEMPLATE_EP = "glTemplateEp"
    GL_TEMPLATE_OP = "glTemplateOp"
    GL_TEMPLATE_RES_OP = "glTemplateResOp"
    GL_USAGE = "glUsage"
    GL_USAGE_EP = "glUsageEp"
    GL_VLAN = "glVlan"
    GL_VNET_INV_HOLDER = "glVnetInvHolder"
    GL_VNIC_TEMPLATE = "glVnicTemplate"
    GL_VNIC_TEMPLATE_EP = "glVnicTemplateEp"
    GL_VSAN = "glVsan"
    GL_VXAN_EP = "glVxanEp"
    GL_VXAN_OP = "glVxanOp"
    GL_VXAN_RES_OP = "glVxanResOp"
    GMETA_CLASS = "gmetaClass"
    GMETA_POLICY_MAP_ELEMENT = "gmetaPolicyMapElement"
    GMETA_PROP = "gmetaProp"
    GRAPHICS_CARD = "graphicsCard"
    GRAPHICS_CONTROLLER = "graphicsController"
    GT_FILTER = "gtFilter"
    GUI_GUI_COMPONENT = "guiGuiComponent"
    GUI_GUI_CONT = "guiGuiCont"
    HC_ADAPTER_FIRMWARE_ITEM = "hcAdapterFirmwareItem"
    HC_ADAPTER_ITEM = "hcAdapterItem"
    HC_ADMIN = "hcAdmin"
    HC_CATALOG = "hcCatalog"
    HC_CATALOG_LIST = "hcCatalogList"
    HC_CATALOG_SOURCE = "hcCatalogSource"
    HC_CATALOG_VERSION = "hcCatalogVersion"
    HC_CLEANUP = "hcCleanup"
    HC_DOWNLOAD_POLICY = "hcDownloadPolicy"
    HC_DOWNLOADER = "hcDownloader"
    HC_DRIVER_INFO_ITEM = "hcDriverInfoItem"
    HC_DRIVER_ITEM = "hcDriverItem"
    HC_HOLDER = "hcHolder"
    HC_ITEM_NOTE = "hcItemNote"
    HC_OS_INFO_ITEM = "hcOsInfoItem"
    HC_OS_ITEM = "hcOsItem"
    HC_REPORT = "hcReport"
    HC_SCOPE_DN = "hcScopeDn"
    HC_SERVER_COMPONENT = "hcServerComponent"
    HC_SUPPORTED_ADAPTER_FIRMWARE_ITEM = "hcSupportedAdapterFirmwareItem"
    HC_SUPPORTED_ADAPTER_ITEM = "hcSupportedAdapterItem"
    HC_SUPPORTED_DRIVER_ITEM = "hcSupportedDriverItem"
    HC_SUPPORTED_OS_ITEM = "hcSupportedOsItem"
    HC_UCS_VERSION_ITEM = "hcUcsVersionItem"
    ID = "id"
    ID_SET = "idSet"
    IDENT_DOMAIN_SYNC_EP = "identDomainSyncEp"
    IDENT_EXECUTION_EP = "identExecutionEp"
    IDENT_EXECUTION_REQUEST_EP = "identExecutionRequestEp"
    IDENT_GET_BLOCK_REPORT = "identGetBlockReport"
    IDENT_GET_ID_USAGE = "identGetIdUsage"
    IDENT_GET_SORTED_IDS = "identGetSortedIds"
    IDENT_IDENT_CTX = "identIdentCtx"
    IDENT_IDENT_REQUEST = "identIdentRequest"
    IDENT_IDENT_REQUEST_FSM = "identIdentRequestFsm"
    IDENT_IDENT_REQUEST_FSM_STAGE = "identIdentRequestFsmStage"
    IDENT_IDENT_REQUEST_FSM_TASK = "identIdentRequestFsmTask"
    IDENT_META_SYSTEM = "identMetaSystem"
    IDENT_META_SYSTEM_FSM = "identMetaSystemFsm"
    IDENT_META_SYSTEM_FSM_STAGE = "identMetaSystemFsmStage"
    IDENT_META_SYSTEM_FSM_TASK = "identMetaSystemFsmTask"
    IDENT_META_VERSE = "identMetaVerse"
    IDENT_REQUEST_EP = "identRequestEp"
    IDENT_SYS_INFO = "identSysInfo"
    IDENTPOOL_BLOCK_QUAL = "identpoolBlockQual"
    IDENTPOOL_CONSUMED = "identpoolConsumed"
    IDENTPOOL_DOMAIN = "identpoolDomain"
    IDENTPOOL_DOMAIN_GROUP_QUAL = "identpoolDomainGroupQual"
    IDENTPOOL_IPQUAL = "identpoolIPQual"
    IDENTPOOL_IPV6_QUAL = "identpoolIPV6Qual"
    IDENTPOOL_META_SYSTEM = "identpoolMetaSystem"
    IDENTPOOL_META_VERSE = "identpoolMetaVerse"
    IDENTPOOL_POOLABLE = "identpoolPoolable"
    INBAND_POLICY = "inbandPolicy"
    INITIATOR_FC_INITIATOR_EP = "initiatorFcInitiatorEp"
    INITIATOR_GROUP_EP = "initiatorGroupEp"
    INITIATOR_ISCSI_INITIATOR_EP = "initiatorIScsiInitiatorEp"
    INITIATOR_LUN_EP = "initiatorLunEp"
    INITIATOR_MEMBER_EP = "initiatorMemberEp"
    INITIATOR_REQUESTOR_EP = "initiatorRequestorEp"
    INITIATOR_REQUESTOR_GRP_EP = "initiatorRequestorGrpEp"
    INITIATOR_STORE_EP = "initiatorStoreEp"
    INITIATOR_UNIT_EP = "initiatorUnitEp"
    INVENTORY_DOMAIN_EP = "inventoryDomainEp"
    INVENTORY_EP = "inventoryEp"
    INVENTORY_GLOBAL_EP = "inventoryGlobalEp"
    INVENTORY_HOLDER = "inventoryHolder"
    INVENTORY_INVENTORY_MO_META = "inventoryInventoryMoMeta"
    IP_IPV4_DNS = "ipIPv4Dns"
    IP_IP_V4_STATIC_ADDR = "ipIpV4StaticAddr"
    IP_SERVICE_IF = "ipServiceIf"
    IPPOOL_ADDR = "ippoolAddr"
    IPPOOL_BLOCK = "ippoolBlock"
    IPPOOL_IP_V6_ADDR = "ippoolIpV6Addr"
    IPPOOL_IP_V6_BLOCK = "ippoolIpV6Block"
    IPPOOL_IP_V6_POOLED = "ippoolIpV6Pooled"
    IPPOOL_POOL = "ippoolPool"
    IPPOOL_POOLED = "ippoolPooled"
    IPPOOL_UNIVERSE = "ippoolUniverse"
    IQNPOOL_ADDR = "iqnpoolAddr"
    IQNPOOL_BLOCK = "iqnpoolBlock"
    IQNPOOL_FORMAT = "iqnpoolFormat"
    IQNPOOL_POOL = "iqnpoolPool"
    IQNPOOL_POOLED = "iqnpoolPooled"
    IQNPOOL_TRANSPORT_BLOCK = "iqnpoolTransportBlock"
    IQNPOOL_UNIVERSE = "iqnpoolUniverse"
    ISCSI_AUTH_PROFILE = "iscsiAuthProfile"
    LE_FILTER = "leFilter"
    LICENSE_CONTENTS = "licenseContents"
    LICENSE_DOMAIN = "licenseDomain"
    LICENSE_DOWNLOADER = "licenseDownloader"
    LICENSE_DOWNLOADER_FSM = "licenseDownloaderFsm"
    LICENSE_DOWNLOADER_FSM_STAGE = "licenseDownloaderFsmStage"
    LICENSE_DOWNLOADER_FSM_TASK = "licenseDownloaderFsmTask"
    LICENSE_EP = "licenseEp"
    LICENSE_FEATURE = "licenseFeature"
    LICENSE_FEATURE_CAP_PROVIDER = "licenseFeatureCapProvider"
    LICENSE_FEATURE_LINE = "licenseFeatureLine"
    LICENSE_FILE = "licenseFile"
    LICENSE_FILE_FSM = "licenseFileFsm"
    LICENSE_FILE_FSM_STAGE = "licenseFileFsmStage"
    LICENSE_FILE_FSM_TASK = "licenseFileFsmTask"
    LICENSE_INSTANCE = "licenseInstance"
    LICENSE_INSTANCE_FSM = "licenseInstanceFsm"
    LICENSE_INSTANCE_FSM_STAGE = "licenseInstanceFsmStage"
    LICENSE_INSTANCE_FSM_TASK = "licenseInstanceFsmTask"
    LICENSE_PROP = "licenseProp"
    LICENSE_SERVER_HOST_ID = "licenseServerHostId"
    LICENSE_SOURCE = "licenseSource"
    LICENSE_SOURCE_FILE = "licenseSourceFile"
    LOGGING_SYNC_OCNS = "loggingSyncOcns"
    LS_BINDING = "lsBinding"
    LS_CLONE = "lsClone"
    LS_FC_LOCALE = "lsFcLocale"
    LS_FC_ZONE = "lsFcZone"
    LS_FC_ZONE_GROUP = "lsFcZoneGroup"
    LS_IDENTITY_INFO = "lsIdentityInfo"
    LS_INSTANTIATE_NNAMED_TEMPLATE = "lsInstantiateNNamedTemplate"
    LS_INSTANTIATE_NTEMPLATE = "lsInstantiateNTemplate"
    LS_INSTANTIATE_TEMPLATE = "lsInstantiateTemplate"
    LS_ISSUES = "lsIssues"
    LS_POWER = "lsPower"
    LS_REQUIREMENT = "lsRequirement"
    LS_SPMETA = "lsSPMeta"
    LS_SERVER = "lsServer"
    LS_SERVER_ASSOC_CTX = "lsServerAssocCtx"
    LS_SERVER_EXTENSION = "lsServerExtension"
    LS_SERVER_FSM = "lsServerFsm"
    LS_SERVER_FSM_STAGE = "lsServerFsmStage"
    LS_SERVER_FSM_TASK = "lsServerFsmTask"
    LS_SERVER_OPERATION = "lsServerOperation"
    LS_TEMPLATISE = "lsTemplatise"
    LS_TIER = "lsTier"
    LS_VCON_ASSIGN = "lsVConAssign"
    LS_WAITING_USER_ACK = "lsWaitingUserAck"
    LS_ZONE_INITIATOR_MEMBER = "lsZoneInitiatorMember"
    LS_ZONE_TARGET_MEMBER = "lsZoneTargetMember"
    LSBOOT_BOOT_SECURITY = "lsbootBootSecurity"
    LSBOOT_DEF = "lsbootDef"
    LSBOOT_DEFAULT_LOCAL_IMAGE = "lsbootDefaultLocalImage"
    LSBOOT_EFISHELL = "lsbootEFIShell"
    LSBOOT_EMBEDDED_LOCAL_DISK_IMAGE = "lsbootEmbeddedLocalDiskImage"
    LSBOOT_EMBEDDED_LOCAL_DISK_IMAGE_PATH = "lsbootEmbeddedLocalDiskImagePath"
    LSBOOT_EMBEDDED_LOCAL_LUN_IMAGE = "lsbootEmbeddedLocalLunImage"
    LSBOOT_ISCSI = "lsbootIScsi"
    LSBOOT_ISCSI_IMAGE_PATH = "lsbootIScsiImagePath"
    LSBOOT_LAN = "lsbootLan"
    LSBOOT_LAN_IMAGE_PATH = "lsbootLanImagePath"
    LSBOOT_LOCAL_DISK_IMAGE = "lsbootLocalDiskImage"
    LSBOOT_LOCAL_DISK_IMAGE_PATH = "lsbootLocalDiskImagePath"
    LSBOOT_LOCAL_HDD_IMAGE = "lsbootLocalHddImage"
    LSBOOT_LOCAL_LUN_IMAGE_PATH = "lsbootLocalLunImagePath"
    LSBOOT_LOCAL_STORAGE = "lsbootLocalStorage"
    LSBOOT_NVME = "lsbootNvme"
    LSBOOT_NVME_DISK_SSD = "lsbootNvmeDiskSsd"
    LSBOOT_NVME_PCI_SSD = "lsbootNvmePciSsd"
    LSBOOT_POLICY = "lsbootPolicy"
    LSBOOT_SAN = "lsbootSan"
    LSBOOT_SAN_CAT_SAN_IMAGE = "lsbootSanCatSanImage"
    LSBOOT_SAN_CAT_SAN_IMAGE_PATH = "lsbootSanCatSanImagePath"
    LSBOOT_SAN_IMAGE = "lsbootSanImage"
    LSBOOT_SAN_IMAGE_PATH = "lsbootSanImagePath"
    LSBOOT_STORAGE = "lsbootStorage"
    LSBOOT_UEFIBOOT_PARAM = "lsbootUEFIBootParam"
    LSBOOT_UPGRADE_STATUS = "lsbootUpgradeStatus"
    LSBOOT_USB_EXTERNAL_IMAGE = "lsbootUsbExternalImage"
    LSBOOT_USB_FLASH_STORAGE_IMAGE = "lsbootUsbFlashStorageImage"
    LSBOOT_USB_INTERNAL_IMAGE = "lsbootUsbInternalImage"
    LSBOOT_VIRTUAL_MEDIA = "lsbootVirtualMedia"
    LSMAINT_ACK = "lsmaintAck"
    LSMAINT_MAINT_POLICY = "lsmaintMaintPolicy"
    LSTORAGE_ACK = "lstorageAck"
    LSTORAGE_ARRAY_REQUIREMENT = "lstorageArrayRequirement"
    LSTORAGE_BLADE = "lstorageBlade"
    LSTORAGE_CLONE = "lstorageClone"
    LSTORAGE_CONTROLLER_DEF = "lstorageControllerDef"
    LSTORAGE_CONTROLLER_MODE_CONFIG = "lstorageControllerModeConfig"
    LSTORAGE_CONTROLLER_QUALIFIER = "lstorageControllerQualifier"
    LSTORAGE_CONTROLLER_REF = "lstorageControllerRef"
    LSTORAGE_CTRL_SERVICE_OPERATION = "lstorageCtrlServiceOperation"
    LSTORAGE_DAS_SCSI_LUN = "lstorageDasScsiLun"
    LSTORAGE_DISK_GROUP_CONFIG_DEF = "lstorageDiskGroupConfigDef"
    LSTORAGE_DISK_GROUP_CONFIG_POLICY = "lstorageDiskGroupConfigPolicy"
    LSTORAGE_DISK_GROUP_QUALIFIER = "lstorageDiskGroupQualifier"
    LSTORAGE_DISK_SLOT = "lstorageDiskSlot"
    LSTORAGE_DISK_ZONING_CONFIG_DEF = "lstorageDiskZoningConfigDef"
    LSTORAGE_DISK_ZONING_POLICY = "lstorageDiskZoningPolicy"
    LSTORAGE_DRIVE_SECURITY = "lstorageDriveSecurity"
    LSTORAGE_EXTENSION = "lstorageExtension"
    LSTORAGE_LOCAL = "lstorageLocal"
    LSTORAGE_LOCAL_DEF = "lstorageLocalDef"
    LSTORAGE_LOCAL_DISK_CONFIG_REF = "lstorageLocalDiskConfigRef"
    LSTORAGE_LOCAL_DISK_REF = "lstorageLocalDiskRef"
    LSTORAGE_LOGIN = "lstorageLogin"
    LSTORAGE_META = "lstorageMeta"
    LSTORAGE_PROFILE = "lstorageProfile"
    LSTORAGE_PROFILE_BINDING = "lstorageProfileBinding"
    LSTORAGE_PROFILE_DEF = "lstorageProfileDef"
    LSTORAGE_RECURR_WINDOW = "lstorageRecurrWindow"
    LSTORAGE_REMOTE = "lstorageRemote"
    LSTORAGE_REMOTE_DEF = "lstorageRemoteDef"
    LSTORAGE_REQUEST_CTX = "lstorageRequestCtx"
    LSTORAGE_SECURITY = "lstorageSecurity"
    LSTORAGE_VIRTUAL_DRIVE_DEF = "lstorageVirtualDriveDef"
    LT_FILTER = "ltFilter"
    MACPOOL_ADDR = "macpoolAddr"
    MACPOOL_BLOCK = "macpoolBlock"
    MACPOOL_FORMAT = "macpoolFormat"
    MACPOOL_POOL = "macpoolPool"
    MACPOOL_POOLED = "macpoolPooled"
    MACPOOL_UNIVERSE = "macpoolUniverse"
    MEMORY_ARRAY = "memoryArray"
    MEMORY_ARRAY_ENV_STATS = "memoryArrayEnvStats"
    MEMORY_ARRAY_ENV_STATS_HIST = "memoryArrayEnvStatsHist"
    MEMORY_BUFFER_UNIT = "memoryBufferUnit"
    MEMORY_BUFFER_UNIT_ENV_STATS = "memoryBufferUnitEnvStats"
    MEMORY_BUFFER_UNIT_ENV_STATS_HIST = "memoryBufferUnitEnvStatsHist"
    MEMORY_ERROR_STATS = "memoryErrorStats"
    MEMORY_ERROR_STATS_HIST = "memoryErrorStatsHist"
    MEMORY_NV_DIMM = "memoryNvDimm"
    MEMORY_NV_DIMM_BATTERY = "memoryNvDimmBattery"
    MEMORY_NV_DIMM_CONTROLLER = "memoryNvDimmController"
    MEMORY_QUAL = "memoryQual"
    MEMORY_RUNTIME = "memoryRuntime"
    MEMORY_RUNTIME_HIST = "memoryRuntimeHist"
    MEMORY_UNIT = "memoryUnit"
    MEMORY_UNIT_ENV_STATS = "memoryUnitEnvStats"
    MEMORY_UNIT_ENV_STATS_HIST = "memoryUnitEnvStatsHist"
    MESSAGE_ENTRY = "messageEntry"
    MESSAGE_EP = "messageEp"
    METHOD_VESSEL = "methodVessel"
    MGMT_BACKUP = "mgmtBackup"
    MGMT_BACKUP_FSM = "mgmtBackupFsm"
    MGMT_BACKUP_FSM_STAGE = "mgmtBackupFsmStage"
    MGMT_BACKUP_FSM_TASK = "mgmtBackupFsmTask"
    MGMT_BACKUP_OPERATION = "mgmtBackupOperation"
    MGMT_BACKUP_POLICY = "mgmtBackupPolicy"
    MGMT_BACKUP_TRIGGER = "mgmtBackupTrigger"
    MGMT_BACKUP_TRIGGER_FSM = "mgmtBackupTriggerFsm"
    MGMT_BACKUP_TRIGGER_FSM_STAGE = "mgmtBackupTriggerFsmStage"
    MGMT_BACKUP_TRIGGER_FSM_TASK = "mgmtBackupTriggerFsmTask"
    MGMT_CFG_EXPORT_POLICY = "mgmtCfgExportPolicy"
    MGMT_CMC_SECURE_BOOT = "mgmtCmcSecureBoot"
    MGMT_CMC_SECURE_BOOT_OPERATION = "mgmtCmcSecureBootOperation"
    MGMT_CONNECTION = "mgmtConnection"
    MGMT_CONTROLLER = "mgmtController"
    MGMT_DATA_EXPORTER = "mgmtDataExporter"
    MGMT_DATA_EXPORTER_FSM = "mgmtDataExporterFsm"
    MGMT_DATA_EXPORTER_FSM_STAGE = "mgmtDataExporterFsmStage"
    MGMT_DATA_EXPORTER_FSM_TASK = "mgmtDataExporterFsmTask"
    MGMT_DATA_IMPORTER = "mgmtDataImporter"
    MGMT_DATA_IMPORTER_FSM = "mgmtDataImporterFsm"
    MGMT_DATA_IMPORTER_FSM_STAGE = "mgmtDataImporterFsmStage"
    MGMT_DATA_IMPORTER_FSM_TASK = "mgmtDataImporterFsmTask"
    MGMT_DATA_ITEM = "mgmtDataItem"
    MGMT_ENTITY = "mgmtEntity"
    MGMT_EP = "mgmtEp"
    MGMT_IPV6_IF_ADDR = "mgmtIPv6IfAddr"
    MGMT_IPV6_IF_CONFIG = "mgmtIPv6IfConfig"
    MGMT_IF = "mgmtIf"
    MGMT_IF_FSM = "mgmtIfFsm"
    MGMT_IF_FSM_STAGE = "mgmtIfFsmStage"
    MGMT_IF_FSM_TASK = "mgmtIfFsmTask"
    MGMT_IMPORT_ITEM = "mgmtImportItem"
    MGMT_IMPORTER = "mgmtImporter"
    MGMT_IMPORTER_FSM = "mgmtImporterFsm"
    MGMT_IMPORTER_FSM_STAGE = "mgmtImporterFsmStage"
    MGMT_IMPORTER_FSM_TASK = "mgmtImporterFsmTask"
    MGMT_INBAND_PROFILE = "mgmtInbandProfile"
    MGMT_INTERFACE = "mgmtInterface"
    MGMT_KMIP = "mgmtKmip"
    MGMT_KMIP_CERT_POLICY = "mgmtKmipCertPolicy"
    MGMT_KMIP_OPERATION = "mgmtKmipOperation"
    MGMT_NAMED_KMIP_CERT_POLICY = "mgmtNamedKmipCertPolicy"
    MGMT_REGISTRY_INFO = "mgmtRegistryInfo"
    MGMT_REGISTRY_INFO_FSM = "mgmtRegistryInfoFsm"
    MGMT_REGISTRY_INFO_FSM_STAGE = "mgmtRegistryInfoFsmStage"
    MGMT_REGISTRY_INFO_FSM_TASK = "mgmtRegistryInfoFsmTask"
    MGMT_SECURITY = "mgmtSecurity"
    MGMT_SVC = "mgmtSvc"
    MGMT_VNET = "mgmtVnet"
    NE_FILTER = "neFilter"
    NET_NET_GROUP_PERMIT = "netNetGroupPermit"
    NETWORK_ELEMENT = "networkElement"
    NETWORK_ELEMENT_FSM = "networkElementFsm"
    NETWORK_ELEMENT_FSM_STAGE = "networkElementFsmStage"
    NETWORK_ELEMENT_FSM_TASK = "networkElementFsmTask"
    NETWORK_ELEMENT_OPERATION = "networkElementOperation"
    NETWORK_SYSTEM_CACERT = "networkSystemCACert"
    NFS_CLIENT_DEF = "nfsClientDef"
    NFS_CLIENT_DEF_FSM = "nfsClientDefFsm"
    NFS_CLIENT_DEF_FSM_STAGE = "nfsClientDefFsmStage"
    NFS_CLIENT_DEF_FSM_TASK = "nfsClientDefFsmTask"
    NFS_EP = "nfsEp"
    NFS_EXPORT_DEF = "nfsExportDef"
    NFS_EXPORT_DEF_FSM = "nfsExportDefFsm"
    NFS_EXPORT_DEF_FSM_STAGE = "nfsExportDefFsmStage"
    NFS_EXPORT_DEF_FSM_TASK = "nfsExportDefFsmTask"
    NFS_MOUNT_DEF = "nfsMountDef"
    NFS_REPOSITORY_SPEC_POLICY = "nfsRepositorySpecPolicy"
    NOT_FILTER = "notFilter"
    NWCTRL_DEFINITION = "nwctrlDefinition"
    OBSERVE_FILTER = "observeFilter"
    OBSERVE_OBSERVED = "observeObserved"
    OBSERVE_OBSERVED_CONT = "observeObservedCont"
    OBSERVE_OBSERVED_FSM = "observeObservedFsm"
    OBSERVE_OBSERVED_FSM_STAGE = "observeObservedFsmStage"
    OBSERVE_OBSERVED_FSM_TASK = "observeObservedFsmTask"
    OR_FILTER = "orFilter"
    ORG_DOMAIN_FIRMWARE_INFO = "orgDomainFirmwareInfo"
    ORG_DOMAIN_GROUP = "orgDomainGroup"
    ORG_DOMAIN_GROUP_FIRMWARE_REPORT = "orgDomainGroupFirmwareReport"
    ORG_DOMAIN_GROUP_POLICY = "orgDomainGroupPolicy"
    ORG_DOMAIN_GROUP_POLICY_REPORT = "orgDomainGroupPolicyReport"
    ORG_EXTENSION = "orgExtension"
    ORG_FIRMWARE_VERSION_COUNT = "orgFirmwareVersionCount"
    ORG_GET_DOMAIN_FIRMWARE_REPORT = "orgGetDomainFirmwareReport"
    ORG_GET_DOMAIN_POLICY_REPORT = "orgGetDomainPolicyReport"
    ORG_GET_IMPACTED_DOMAINS = "orgGetImpactedDomains"
    ORG_GET_NUM_IMPACTED_DOMAINS = "orgGetNumImpactedDomains"
    ORG_GET_SUBSCRIBED_DOMAINS = "orgGetSubscribedDomains"
    ORG_MAINT_TAG_FIRMWARE_REPORT = "orgMaintTagFirmwareReport"
    ORG_ORG = "orgOrg"
    ORG_ORG_FSM = "orgOrgFsm"
    ORG_ORG_FSM_STAGE = "orgOrgFsmStage"
    ORG_ORG_FSM_TASK = "orgOrgFsmTask"
    ORG_ORG_SOURCE = "orgOrgSource"
    ORG_RESOLVE_ELEMENTS = "orgResolveElements"
    ORG_RESOLVE_IN_SCOPE = "orgResolveInScope"
    ORG_RESOLVE_LOGICAL_PARENTS = "orgResolveLogicalParents"
    ORG_SOURCE_MASK = "orgSourceMask"
    OS_CONTROLLER = "osController"
    OS_ETH_BOND_INTF = "osEthBondIntf"
    OS_ETH_INTF = "osEthIntf"
    OS_INSTANCE = "osInstance"
    OS_PRIMARY_SLAVE = "osPrimarySlave"
    PAIR = "pair"
    PKI_CERT_REQ = "pkiCertReq"
    PKI_EP = "pkiEp"
    PKI_EP_FSM = "pkiEpFsm"
    PKI_EP_FSM_STAGE = "pkiEpFsmStage"
    PKI_EP_FSM_TASK = "pkiEpFsmTask"
    PKI_KEY_RING = "pkiKeyRing"
    PKI_TP = "pkiTP"
    POLICY_CHILD_CLASS = "policyChildClass"
    POLICY_CLUSTER = "policyCluster"
    POLICY_COMMUNICATION = "policyCommunication"
    POLICY_COMMUNICATION_OP = "policyCommunicationOp"
    POLICY_CONFIG_BACKUP = "policyConfigBackup"
    POLICY_CONFIG_BACKUP_OP = "policyConfigBackupOp"
    POLICY_CONFIG_ERROR = "policyConfigError"
    POLICY_CONTEXT = "policyContext"
    POLICY_CONTROL_EP = "policyControlEp"
    POLICY_CONTROL_EP_OP = "policyControlEpOp"
    POLICY_CONTROL_EP_OP_FSM = "policyControlEpOpFsm"
    POLICY_CONTROL_EP_OP_FSM_STAGE = "policyControlEpOpFsmStage"
    POLICY_CONTROL_EP_OP_FSM_TASK = "policyControlEpOpFsmTask"
    POLICY_CONTROL_EP_OPERATION = "policyControlEpOperation"
    POLICY_CONTROLLED_INSTANCE = "policyControlledInstance"
    POLICY_CONTROLLED_TYPE = "policyControlledType"
    POLICY_DATE_TIME = "policyDateTime"
    POLICY_DATE_TIME_OP = "policyDateTimeOp"
    POLICY_DEST_CLASS = "policyDestClass"
    POLICY_DEST_EP = "policyDestEp"
    POLICY_DEVICE_PROFILE = "policyDeviceProfile"
    POLICY_DIGEST = "policyDigest"
    POLICY_DISCOVERY = "policyDiscovery"
    POLICY_DISCOVERY_OP = "policyDiscoveryOp"
    POLICY_DNS = "policyDns"
    POLICY_DNS_OP = "policyDnsOp"
    POLICY_ELEMENT = "policyElement"
    POLICY_EQUIPMENT = "policyEquipment"
    POLICY_EQUIPMENT_OP = "policyEquipmentOp"
    POLICY_FAULT = "policyFault"
    POLICY_FAULT_OP = "policyFaultOp"
    POLICY_IDENTIFIER_POLICY = "policyIdentifierPolicy"
    POLICY_INFRA_FIRMWARE = "policyInfraFirmware"
    POLICY_INFRA_FIRMWARE_OP = "policyInfraFirmwareOp"
    POLICY_LOCAL_MAP = "policyLocalMap"
    POLICY_LOG_PROFILE = "policyLogProfile"
    POLICY_MEP = "policyMEp"
    POLICY_MEP_OP = "policyMEpOp"
    POLICY_MONITORING = "policyMonitoring"
    POLICY_MONITORING_OP = "policyMonitoringOp"
    POLICY_POLICY_DEST_CLASS = "policyPolicyDestClass"
    POLICY_POLICY_EP = "policyPolicyEp"
    POLICY_POLICY_REQUESTOR = "policyPolicyRequestor"
    POLICY_POLICY_SCOPE = "policyPolicyScope"
    POLICY_POLICY_SCOPE_CONT = "policyPolicyScopeCont"
    POLICY_POLICY_SCOPE_CONTEXT = "policyPolicyScopeContext"
    POLICY_POLICY_SCOPE_FSM = "policyPolicyScopeFsm"
    POLICY_POLICY_SCOPE_FSM_STAGE = "policyPolicyScopeFsmStage"
    POLICY_POLICY_SCOPE_FSM_TASK = "policyPolicyScopeFsmTask"
    POLICY_PORT_CONFIG = "policyPortConfig"
    POLICY_PORT_CONFIG_OP = "policyPortConfigOp"
    POLICY_POWER_MGMT = "policyPowerMgmt"
    POLICY_POWER_MGMT_OP = "policyPowerMgmtOp"
    POLICY_PROXY_MO = "policyProxyMo"
    POLICY_PSU = "policyPsu"
    POLICY_PSU_OP = "policyPsuOp"
    POLICY_REQUESTOR = "policyRequestor"
    POLICY_RESOLVE_NAMES = "policyResolveNames"
    POLICY_SCOPE = "policyScope"
    POLICY_SECURITY = "policySecurity"
    POLICY_SECURITY_OP = "policySecurityOp"
    POLICY_SOURCE = "policySource"
    POLICY_SOURCE_APP = "policySourceApp"
    POLICY_STORAGE_AUTO_CONFIG = "policyStorageAutoConfig"
    POLICY_STORAGE_AUTO_CONFIG_OP = "policyStorageAutoConfigOp"
    POLICY_SYSTEM_EP = "policySystemEp"
    POLICY_SYSTEM_PROFILE = "policySystemProfile"
    POLICY_TRACKER = "policyTracker"
    POLICY_UNIVERSE = "policyUniverse"
    POOL_RESOLVE_IN_SCOPE = "poolResolveInScope"
    PORT_GROUP = "portGroup"
    PORT_SUB_GROUP = "portSubGroup"
    POWER_BUDGET = "powerBudget"
    POWER_CHASSIS_MEMBER = "powerChassisMember"
    POWER_EP = "powerEp"
    POWER_GROUP = "powerGroup"
    POWER_GROUP_QUAL = "powerGroupQual"
    POWER_GROUP_STATS = "powerGroupStats"
    POWER_GROUP_STATS_HIST = "powerGroupStatsHist"
    POWER_MGMT_POLICY = "powerMgmtPolicy"
    POWER_POLICY = "powerPolicy"
    POWER_PROFILED_POWER = "powerProfiledPower"
    PROC_DOER = "procDoer"
    PROC_MANAGER = "procManager"
    PROC_PRT = "procPrt"
    PROC_PRT_COUNTS = "procPrtCounts"
    PROC_STIMULUS_COUNTS = "procStimulusCounts"
    PROC_SVC = "procSvc"
    PROC_TX_COUNTS = "procTxCounts"
    PROCESSOR_ENV_STATS = "processorEnvStats"
    PROCESSOR_ENV_STATS_HIST = "processorEnvStatsHist"
    PROCESSOR_ERROR_STATS = "processorErrorStats"
    PROCESSOR_ERROR_STATS_HIST = "processorErrorStatsHist"
    PROCESSOR_QUAL = "processorQual"
    PROCESSOR_RUNTIME = "processorRuntime"
    PROCESSOR_RUNTIME_HIST = "processorRuntimeHist"
    PROCESSOR_UNIT = "processorUnit"
    PROCESSOR_UNIT_ASSOC_CTX = "processorUnitAssocCtx"
    QOSCLASS_DEFINITION = "qosclassDefinition"
    QOSCLASS_ETH_BE = "qosclassEthBE"
    QOSCLASS_ETH_CLASSIFIED = "qosclassEthClassified"
    QOSCLASS_FC = "qosclassFc"
    QOSCLASS_POLICY = "qosclassPolicy"
    QUERY_DEPENDENCY_CONTEXT = "queryDependencyContext"
    QUERY_DEPENDENCY_REF = "queryDependencyRef"
    QUERY_EP = "queryEp"
    QUERY_IMPORT_CONTEXT = "queryImportContext"
    QUERY_USAGE_CONTEXT = "queryUsageContext"
    QUERYRESULT_DEPENDENCY = "queryresultDependency"
    QUERYRESULT_DOMAIN_GROUP_EP = "queryresultDomainGroupEp"
    QUERYRESULT_ORG_EP = "queryresultOrgEp"
    QUERYRESULT_USAGE = "queryresultUsage"
    SECURITY_UNIT = "securityUnit"
    SES_DISK_SLOT_EP = "sesDiskSlotEp"
    SES_ENCLOSURE = "sesEnclosure"
    SMARTCALLHOME_HTTP_PROXY = "smartcallhomeHttpProxy"
    SMARTCALLHOME_PERIODIC_INVENTORY_STATUS = "smartcallhomePeriodicInventoryStatus"
    SMARTCALLHOME_PERIODIC_SYSTEM_INVENTORY = "smartcallhomePeriodicSystemInventory"
    SMARTCALLHOME_POLICY = "smartcallhomePolicy"
    SMARTCALLHOME_PROFILE = "smartcallhomeProfile"
    SMARTCALLHOME_SOURCE = "smartcallhomeSource"
    SMARTCALLHOME_TRANSPORT_GATEWAY = "smartcallhomeTransportGateway"
    SMARTLICENSE_AGENT = "smartlicenseAgent"
    SMARTLICENSE_AGENT_FSM = "smartlicenseAgentFsm"
    SMARTLICENSE_AGENT_FSM_STAGE = "smartlicenseAgentFsmStage"
    SMARTLICENSE_AGENT_FSM_TASK = "smartlicenseAgentFsmTask"
    SMARTLICENSE_ENTITLEMENT = "smartlicenseEntitlement"
    SMARTLICENSE_ENTITLEMENT_EP = "smartlicenseEntitlementEp"
    SMARTLICENSE_ENTITLEMENT_EP_FSM = "smartlicenseEntitlementEpFsm"
    SMARTLICENSE_ENTITLEMENT_EP_FSM_STAGE = "smartlicenseEntitlementEpFsmStage"
    SMARTLICENSE_ENTITLEMENT_EP_FSM_TASK = "smartlicenseEntitlementEpFsmTask"
    SMARTLICENSE_EP = "smartlicenseEp"
    SMARTLICENSE_HOLDER = "smartlicenseHolder"
    SMARTLICENSE_HOLDER_FSM = "smartlicenseHolderFsm"
    SMARTLICENSE_HOLDER_FSM_STAGE = "smartlicenseHolderFsmStage"
    SMARTLICENSE_HOLDER_FSM_TASK = "smartlicenseHolderFsmTask"
    SMARTLICENSE_TEST = "smartlicenseTest"
    SMARTLICENSE_TEST_FSM = "smartlicenseTestFsm"
    SMARTLICENSE_TEST_FSM_STAGE = "smartlicenseTestFsmStage"
    SMARTLICENSE_TEST_FSM_TASK = "smartlicenseTestFsmTask"
    SNMP_FIND_VAR = "snmpFindVar"
    SOL_POLICY = "solPolicy"
    STATS_BUILD_CHART_RESULT = "statsBuildChartResult"
    STATS_BUILD_CUSTOM_CHART = "statsBuildCustomChart"
    STATS_BUILD_STANDARD_CHART = "statsBuildStandardChart"
    STATS_CHART_CONTAINER = "statsChartContainer"
    STATS_CLEAR_INTERVAL = "statsClearInterval"
    STATS_COLLECTION_POLICY = "statsCollectionPolicy"
    STATS_CUSTOM_CHART = "statsCustomChart"
    STATS_CUSTOM_EP = "statsCustomEp"
    STATS_DB_MIGRATION_STATUS = "statsDbMigrationStatus"
    STATS_DB_SUMMARY_META = "statsDbSummaryMeta"
    STATS_HOLDER = "statsHolder"
    STATS_INVENTORY_META = "statsInventoryMeta"
    STATS_PASADENA_COLLECTION_POLICY = "statsPasadenaCollectionPolicy"
    STATS_STANDARD_CHART = "statsStandardChart"
    STATS_STANDARD_EP = "statsStandardEp"
    STATS_STATS_QUERY = "statsStatsQuery"
    STATS_STATS_QUERY_HOLDER = "statsStatsQueryHolder"
    STATS_SUBSCRIBE = "statsSubscribe"
    STATS_THR32_DEFINITION = "statsThr32Definition"
    STATS_THR32_VALUE = "statsThr32Value"
    STATS_THR64_DEFINITION = "statsThr64Definition"
    STATS_THR64_VALUE = "statsThr64Value"
    STATS_THR_FLOAT_DEFINITION = "statsThrFloatDefinition"
    STATS_THR_FLOAT_VALUE = "statsThrFloatValue"
    STATS_THRESHOLD_CLASS = "statsThresholdClass"
    STATS_THRESHOLD_POLICY = "statsThresholdPolicy"
    STORAGE_ARRAY = "storageArray"
    STORAGE_AUTH_KEY = "storageAuthKey"
    STORAGE_BLADE = "storageBlade"
    STORAGE_CLOUD = "storageCloud"
    STORAGE_CLUSTER_ID_UNIVERSE = "storageClusterIdUniverse"
    STORAGE_COMPUTE_BLADE_OPERATION = "storageComputeBladeOperation"
    STORAGE_CONNECTION_DEF = "storageConnectionDef"
    STORAGE_CONNECTION_POLICY = "storageConnectionPolicy"
    STORAGE_CONTROLLER = "storageController"
    STORAGE_CONTROLLER_EP = "storageControllerEp"
    STORAGE_CONTROLLER_OPERATION = "storageControllerOperation"
    STORAGE_CONTROLLER_REF = "storageControllerRef"
    STORAGE_CTRL_STORAGE_STATS = "storageCtrlStorageStats"
    STORAGE_CTRL_STORAGE_STATS_HIST = "storageCtrlStorageStatsHist"
    STORAGE_DISK_ENV_STATS = "storageDiskEnvStats"
    STORAGE_DISK_ENV_STATS_HIST = "storageDiskEnvStatsHist"
    STORAGE_DISK_EP = "storageDiskEp"
    STORAGE_DISK_GROUP = "storageDiskGroup"
    STORAGE_EMBEDDED_STORAGE = "storageEmbeddedStorage"
    STORAGE_ENCLOSURE = "storageEnclosure"
    STORAGE_ENCLOSURE_DISK_SLOT_EP = "storageEnclosureDiskSlotEp"
    STORAGE_ENCLOSURE_LOCAL_DISK_CONFIG = "storageEnclosureLocalDiskConfig"
    STORAGE_EP_USER = "storageEpUser"
    STORAGE_ETH_LIF = "storageEthLif"
    STORAGE_ETHER_IF = "storageEtherIf"
    STORAGE_FC_IF = "storageFcIf"
    STORAGE_FC_TARGET_EP = "storageFcTargetEp"
    STORAGE_FC_TARGET_IF = "storageFcTargetIf"
    STORAGE_FLEX_FLASH_CARD = "storageFlexFlashCard"
    STORAGE_FLEX_FLASH_CONTROLLER = "storageFlexFlashController"
    STORAGE_FLEX_FLASH_CONTROLLER_OPERATION = "storageFlexFlashControllerOperation"
    STORAGE_FLEX_FLASH_DRIVE = "storageFlexFlashDrive"
    STORAGE_FLEX_FLASH_VIRTUAL_DRIVE = "storageFlexFlashVirtualDrive"
    STORAGE_HDD_MOTHER_BOARD_TEMP_STATS = "storageHddMotherBoardTempStats"
    STORAGE_HDD_MOTHER_BOARD_TEMP_STATS_HIST = "storageHddMotherBoardTempStatsHist"
    STORAGE_ISCSI_INITIATOR_EP = "storageIScsiInitiatorEp"
    STORAGE_ISCSI_TARGET_IF = "storageIScsiTargetIf"
    STORAGE_INI_GROUP = "storageIniGroup"
    STORAGE_INITIATOR = "storageInitiator"
    STORAGE_INITIATOR_REF = "storageInitiatorRef"
    STORAGE_IP_V4_POOLED_ADDR = "storageIpV4PooledAddr"
    STORAGE_IP_V4_STATIC_ADDR = "storageIpV4StaticAddr"
    STORAGE_ITEM = "storageItem"
    STORAGE_LOCAL_DISK = "storageLocalDisk"
    STORAGE_LOCAL_DISK_CONFIG_DEF = "storageLocalDiskConfigDef"
    STORAGE_LOCAL_DISK_CONFIG_POLICY = "storageLocalDiskConfigPolicy"
    STORAGE_LOCAL_DISK_EP = "storageLocalDiskEp"
    STORAGE_LOCAL_DISK_OPERATION = "storageLocalDiskOperation"
    STORAGE_LOCAL_DISK_PARTITION = "storageLocalDiskPartition"
    STORAGE_LOCAL_LUN = "storageLocalLun"
    STORAGE_LUN_COUNTERS = "storageLunCounters"
    STORAGE_LUN_DISK = "storageLunDisk"
    STORAGE_LUN_MASK_GROUP = "storageLunMaskGroup"
    STORAGE_LUN_REPLICA = "storageLunReplica"
    STORAGE_LUN_RESOURCE_SELECTION_LOG = "storageLunResourceSelectionLog"
    STORAGE_LUN_SNAPSHOT = "storageLunSnapshot"
    STORAGE_META = "storageMeta"
    STORAGE_MEZZ_FLASH_LIFE = "storageMezzFlashLife"
    STORAGE_NODE_EP = "storageNodeEp"
    STORAGE_NVME_STATS = "storageNvmeStats"
    STORAGE_NVME_STATS_HIST = "storageNvmeStatsHist"
    STORAGE_NVME_STORAGE = "storageNvmeStorage"
    STORAGE_ONBOARD_DEVICE = "storageOnboardDevice"
    STORAGE_OPERATION = "storageOperation"
    STORAGE_PARTITION = "storagePartition"
    STORAGE_PROCESSOR = "storageProcessor"
    STORAGE_PROCESSOR_EP = "storageProcessorEp"
    STORAGE_PROCESSOR_RUNTIME = "storageProcessorRuntime"
    STORAGE_QUAL = "storageQual"
    STORAGE_RAID_BATTERY = "storageRaidBattery"
    STORAGE_REPLICATION_CTX = "storageReplicationCtx"
    STORAGE_SAS_EXPANDER = "storageSasExpander"
    STORAGE_SAS_PORT = "storageSasPort"
    STORAGE_SAS_UP_LINK = "storageSasUpLink"
    STORAGE_SCSI_DEVICE_DESCRIPTOR = "storageScsiDeviceDescriptor"
    STORAGE_SCSI_LUN = "storageScsiLun"
    STORAGE_SCSI_LUN_CTX = "storageScsiLunCtx"
    STORAGE_SCSI_LUN_INST_REF = "storageScsiLunInstRef"
    STORAGE_SCSI_LUN_MASK = "storageScsiLunMask"
    STORAGE_SCSI_LUN_REF = "storageScsiLunRef"
    STORAGE_SNAPSHOT_CTX = "storageSnapshotCtx"
    STORAGE_SSD_HEALTH_STATS = "storageSsdHealthStats"
    STORAGE_SSD_HEALTH_STATS_HIST = "storageSsdHealthStatsHist"
    STORAGE_STORAGE_STATS = "storageStorageStats"
    STORAGE_STORAGE_STATS_HIST = "storageStorageStatsHist"
    STORAGE_SYSTEM = "storageSystem"
    STORAGE_TRANSPORTABLE_FLASH_MODULE = "storageTransportableFlashModule"
    STORAGE_USAGE_COUNTERS = "storageUsageCounters"
    STORAGE_VDMEMBER_EP = "storageVDMemberEp"
    STORAGE_VIRTUAL_DRIVE = "storageVirtualDrive"
    STORAGE_VIRTUAL_DRIVE_CONTAINER = "storageVirtualDriveContainer"
    STORAGE_VIRTUAL_DRIVE_EP = "storageVirtualDriveEp"
    STORAGE_VIRTUAL_DRIVE_OPERATION = "storageVirtualDriveOperation"
    STORAGE_VIRTUAL_DRIVE_REF = "storageVirtualDriveRef"
    STORAGE_VIRTUAL_DRIVE_REF_OPERATION = "storageVirtualDriveRefOperation"
    STORAGE_VOLUME = "storageVolume"
    STORAGE_VSAN_REF = "storageVsanRef"
    STORAGE_VSAN_REF_IVT = "storageVsanRefIvt"
    SW_CARD_ENV_STATS = "swCardEnvStats"
    SW_CARD_ENV_STATS_HIST = "swCardEnvStatsHist"
    SW_ENV_STATS = "swEnvStats"
    SW_ENV_STATS_HIST = "swEnvStatsHist"
    SW_SYSTEM_STATS = "swSystemStats"
    SW_SYSTEM_STATS_HIST = "swSystemStatsHist"
    SYNTHETIC_DIRECTORY = "syntheticDirectory"
    SYNTHETIC_FSOBJ_INVENTORY = "syntheticFSObjInventory"
    SYNTHETIC_FSOBJ_INVENTORY_B = "syntheticFSObjInventoryB"
    SYNTHETIC_FILE = "syntheticFile"
    SYNTHETIC_FILE_SYSTEM = "syntheticFileSystem"
    SYNTHETIC_FS_OBJ = "syntheticFsObj"
    SYNTHETIC_TEST_TX = "syntheticTestTx"
    SYNTHETIC_TIME = "syntheticTime"
    SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET = "sysdebugAutoCoreFileExportTarget"
    SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM = "sysdebugAutoCoreFileExportTargetFsm"
    SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM_STAGE = "sysdebugAutoCoreFileExportTargetFsmStage"
    SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM_TASK = "sysdebugAutoCoreFileExportTargetFsmTask"
    SYSDEBUG_BACKUP_BEHAVIOR = "sysdebugBackupBehavior"
    SYSDEBUG_CORE = "sysdebugCore"
    SYSDEBUG_CORE_FILE_REPOSITORY = "sysdebugCoreFileRepository"
    SYSDEBUG_DIAGNOSTIC_LOG = "sysdebugDiagnosticLog"
    SYSDEBUG_EP = "sysdebugEp"
    SYSDEBUG_LOG_CONTROL_DESTINATION_FILE = "sysdebugLogControlDestinationFile"
    SYSDEBUG_LOG_CONTROL_DESTINATION_SYSLOG = "sysdebugLogControlDestinationSyslog"
    SYSDEBUG_LOG_CONTROL_DOMAIN = "sysdebugLogControlDomain"
    SYSDEBUG_LOG_CONTROL_EP = "sysdebugLogControlEp"
    SYSDEBUG_LOG_CONTROL_EP_FSM = "sysdebugLogControlEpFsm"
    SYSDEBUG_LOG_CONTROL_EP_FSM_STAGE = "sysdebugLogControlEpFsmStage"
    SYSDEBUG_LOG_CONTROL_EP_FSM_TASK = "sysdebugLogControlEpFsmTask"
    SYSDEBUG_LOG_CONTROL_MODULE = "sysdebugLogControlModule"
    SYSDEBUG_MEP_LOG_POLICY = "sysdebugMEpLogPolicy"
    SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET = "sysdebugManualCoreFileExportTarget"
    SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM = "sysdebugManualCoreFileExportTargetFsm"
    SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM_STAGE = "sysdebugManualCoreFileExportTargetFsmStage"
    SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM_TASK = "sysdebugManualCoreFileExportTargetFsmTask"
    SYSDEBUG_TECH_SUP_FILE_REPOSITORY = "sysdebugTechSupFileRepository"
    SYSDEBUG_TECH_SUPPORT = "sysdebugTechSupport"
    SYSDEBUG_TECH_SUPPORT_CMD_OPT = "sysdebugTechSupportCmdOpt"
    SYSDEBUG_TECH_SUPPORT_FSM = "sysdebugTechSupportFsm"
    SYSDEBUG_TECH_SUPPORT_FSM_STAGE = "sysdebugTechSupportFsmStage"
    SYSDEBUG_TECH_SUPPORT_FSM_TASK = "sysdebugTechSupportFsmTask"
    SYSDEBUG_TECH_SUPPORT_OP = "sysdebugTechSupportOp"
    SYSDEBUG_TECH_SUPPORT_OPERATION = "sysdebugTechSupportOperation"
    SYSFILE_DIGEST = "sysfileDigest"
    SYSFILE_MUTATION = "sysfileMutation"
    SYSFILE_MUTATION_FSM = "sysfileMutationFsm"
    SYSFILE_MUTATION_FSM_STAGE = "sysfileMutationFsmStage"
    SYSFILE_MUTATION_FSM_TASK = "sysfileMutationFsmTask"
    TAG_DEF = "tagDef"
    TAG_DEF_EP = "tagDefEp"
    TAG_DRIVER = "tagDriver"
    TAG_INSTANCE = "tagInstance"
    TAG_INSTANCE_EP = "tagInstanceEp"
    TAG_INSTANCE_ITEM = "tagInstanceItem"
    TAG_ITEM = "tagItem"
    TAG_SOFTWARE_INST = "tagSoftwareInst"
    TESTING_CLI_POLICY = "testingCliPolicy"
    TESTING_SERVICE_PROFILE = "testingServiceProfile"
    TESTING_SERVICE_PROFILE_FSM = "testingServiceProfileFsm"
    TESTING_SERVICE_PROFILE_FSM_STAGE = "testingServiceProfileFsmStage"
    TESTING_SERVICE_PROFILE_FSM_TASK = "testingServiceProfileFsmTask"
    TESTING_SNMP_COMMUNITY = "testingSnmpCommunity"
    TESTING_SNMP_POLICY = "testingSnmpPolicy"
    TESTING_SNMP_SUPPORT = "testingSnmpSupport"
    TESTING_SNMP_TRAP = "testingSnmpTrap"
    TOP_INFO_SYNC_POLICY = "topInfoSyncPolicy"
    TOP_META_INF = "topMetaInf"
    TOP_ROOT = "topRoot"
    TOP_SYSTEM = "topSystem"
    TOP_SYSTEM_FSM = "topSystemFsm"
    TOP_SYSTEM_FSM_STAGE = "topSystemFsmStage"
    TOP_SYSTEM_FSM_TASK = "topSystemFsmTask"
    TRIG_ABS_WINDOW = "trigAbsWindow"
    TRIG_META = "trigMeta"
    TRIG_PENDING_ACK_COUNT = "trigPendingAckCount"
    TRIG_RECURR_WINDOW = "trigRecurrWindow"
    TRIG_SCHED = "trigSched"
    TRIG_SERVER_TOKEN = "trigServerToken"
    TRIG_TEST = "trigTest"
    TRIG_TOKEN_REQUESTOR = "trigTokenRequestor"
    TRIG_TRIGGERED = "trigTriggered"
    UUIDPOOL_ADDR = "uuidpoolAddr"
    UUIDPOOL_BLOCK = "uuidpoolBlock"
    UUIDPOOL_FORMAT = "uuidpoolFormat"
    UUIDPOOL_POOL = "uuidpoolPool"
    UUIDPOOL_POOLED = "uuidpoolPooled"
    UUIDPOOL_UNIVERSE = "uuidpoolUniverse"
    VERSION_APPLICATION = "versionApplication"
    VERSION_EP = "versionEp"
    VERSION_FILTER = "versionFilter"
    VERSION_MATRIX = "versionMatrix"
    VERSION_PRODUCT = "versionProduct"
    VM_NIC = "vmNic"
    VNIC_BOOT_IP_POLICY = "vnicBootIpPolicy"
    VNIC_BOOT_TARGET = "vnicBootTarget"
    VNIC_CONN_DEF = "vnicConnDef"
    VNIC_DEF_BEH = "vnicDefBeh"
    VNIC_DYNAMIC_CON = "vnicDynamicCon"
    VNIC_DYNAMIC_CON_POLICY = "vnicDynamicConPolicy"
    VNIC_DYNAMIC_CON_POLICY_REF = "vnicDynamicConPolicyRef"
    VNIC_ETH_LIF = "vnicEthLif"
    VNIC_ETHER = "vnicEther"
    VNIC_ETHER_IF = "vnicEtherIf"
    VNIC_FAULT = "vnicFault"
    VNIC_FC = "vnicFc"
    VNIC_FC_GROUP_DEF = "vnicFcGroupDef"
    VNIC_FC_GROUP_TEMPL = "vnicFcGroupTempl"
    VNIC_FC_IF = "vnicFcIf"
    VNIC_FC_LIF = "vnicFcLif"
    VNIC_FC_NODE = "vnicFcNode"
    VNIC_FC_OEIF = "vnicFcOEIf"
    VNIC_IPV4_DHCP = "vnicIPv4Dhcp"
    VNIC_IPV4_DNS = "vnicIPv4Dns"
    VNIC_IPV4_IF = "vnicIPv4If"
    VNIC_IPV4_ISCSI_ADDR = "vnicIPv4IscsiAddr"
    VNIC_IPV4_POOLED_ISCSI_ADDR = "vnicIPv4PooledIscsiAddr"
    VNIC_IPV4_STATIC_ROUTE = "vnicIPv4StaticRoute"
    VNIC_IPV6_IF = "vnicIPv6If"
    VNIC_ISCSI = "vnicIScsi"
    VNIC_ISCSI_AUTO_TARGET_IF = "vnicIScsiAutoTargetIf"
    VNIC_ISCSI_BOOT_PARAMS = "vnicIScsiBootParams"
    VNIC_ISCSI_BOOT_VNIC = "vnicIScsiBootVnic"
    VNIC_ISCSI_INITIATOR_PARAMS = "vnicIScsiInitiatorParams"
    VNIC_ISCSI_LCP = "vnicIScsiLCP"
    VNIC_ISCSI_NODE = "vnicIScsiNode"
    VNIC_ISCSI_STATIC_TARGET_IF = "vnicIScsiStaticTargetIf"
    VNIC_ISCSI_TARGET_PARAMS = "vnicIScsiTargetParams"
    VNIC_INI_GRP_FC = "vnicIniGrpFc"
    VNIC_INI_GRP_FC_B = "vnicIniGrpFcB"
    VNIC_INI_GRP_FC_BIF = "vnicIniGrpFcBIf"
    VNIC_INI_GRP_FC_IF = "vnicIniGrpFcIf"
    VNIC_IP_V4_MGMT_POOLED_ADDR = "vnicIpV4MgmtPooledAddr"
    VNIC_IP_V4_POOLED_ADDR = "vnicIpV4PooledAddr"
    VNIC_IP_V4_PROF_DERIVED_ADDR = "vnicIpV4ProfDerivedAddr"
    VNIC_IP_V4_STATIC_ADDR = "vnicIpV4StaticAddr"
    VNIC_IP_V6_MGMT_POOLED_ADDR = "vnicIpV6MgmtPooledAddr"
    VNIC_IP_V6_STATIC_ADDR = "vnicIpV6StaticAddr"
    VNIC_LAN_CONN_POLICY = "vnicLanConnPolicy"
    VNIC_LAN_CONN_TEMPL = "vnicLanConnTempl"
    VNIC_LIF_VLAN = "vnicLifVlan"
    VNIC_LIF_VSAN = "vnicLifVsan"
    VNIC_LSTORAGE_ISCSI = "vnicLstorageIScsi"
    VNIC_LUN = "vnicLun"
    VNIC_MGMT = "vnicMgmt"
    VNIC_MGMT_IF = "vnicMgmtIf"
    VNIC_MON_SES_FC = "vnicMonSesFc"
    VNIC_MON_SES_FC_IF = "vnicMonSesFcIf"
    VNIC_NET_GROUP = "vnicNetGroup"
    VNIC_NET_GROUP_REF = "vnicNetGroupRef"
    VNIC_OUTBAND_MGMT_EP = "vnicOutbandMgmtEp"
    VNIC_OUTBAND_MGMT_EP_FSM = "vnicOutbandMgmtEpFsm"
    VNIC_OUTBAND_MGMT_EP_FSM_STAGE = "vnicOutbandMgmtEpFsmStage"
    VNIC_OUTBAND_MGMT_EP_FSM_TASK = "vnicOutbandMgmtEpFsmTask"
    VNIC_PROFILE_SET = "vnicProfileSet"
    VNIC_RACK_SERVER_DISCOVERY_PROFILE = "vnicRackServerDiscoveryProfile"
    VNIC_SAN_CONN_POLICY = "vnicSanConnPolicy"
    VNIC_SAN_CONN_TEMPL = "vnicSanConnTempl"
    VNIC_STORAGE_ETH_LIF = "vnicStorageEthLif"
    VNIC_USNIC_CON_POLICY = "vnicUsnicConPolicy"
    VNIC_USNIC_CON_POLICY_REF = "vnicUsnicConPolicyRef"
    VNIC_VHBA_BEH_POLICY = "vnicVhbaBehPolicy"
    VNIC_VLAN = "vnicVlan"
    VNIC_VMQ_CON_POLICY = "vnicVmqConPolicy"
    VNIC_VMQ_CON_POLICY_REF = "vnicVmqConPolicyRef"
    VNIC_VNIC_BEH_POLICY = "vnicVnicBehPolicy"
    WCARD_FILTER = "wcardFilter"

class YesOrNo:
    FALSE = "false"
    NO = "no"
    TRUE = "true"
    YES = "yes"

class NamingPropertyId:
    _ABORT_ERRORS = "AbortErrors"
    _ABORT_ERRORS_AVG = "AbortErrorsAvg"
    _ABORT_ERRORS_MAX = "AbortErrorsMax"
    _ABORT_ERRORS_MIN = "AbortErrorsMin"
    _ABORT_ERRORS_RUNNING = "AbortErrorsRunning"
    _CPCOUNT = "CPCount"
    _CPTEMPLATE_COUNT = "CPTemplateCount"
    _CHASSIS_PROFILE = "ChassisProfile"
    _CLUSTER_STATE = "ClusterState"
    _DEPENDENCY_DN = "DependencyDn"
    _MAXIMUM = "Maximum"
    _MIGRATE_ADMIN_SETTING = "MigrateAdminSetting"
    _MINIMUM = "Minimum"
    _MODULE_POWER = "ModulePower"
    _MODULE_POWER_AVG = "ModulePowerAvg"
    _MODULE_POWER_MAX = "ModulePowerMax"
    _MODULE_POWER_MIN = "ModulePowerMin"
    _NUMBEROF_POLICY = "NumberofPolicy"
    _NUMBEROF_POOL = "NumberofPool"
    _NUMBEROF_VLAN = "NumberofVlan"
    _NUMBEROF_VSAN = "NumberofVsan"
    _OFFLOAD = "Offload"
    _RWTYPE = "RWType"
    _SPCOUNT = "SPCount"
    _SQETEST = "SQETest"
    _SQETEST_DELTA = "SQETestDelta"
    _SQETEST_DELTA_AVG = "SQETestDeltaAvg"
    _SQETEST_DELTA_MAX = "SQETestDeltaMax"
    _SQETEST_DELTA_MIN = "SQETestDeltaMin"
    _SLOT_OUTLET1 = "SlotOutlet1"
    _SLOT_OUTLET1_AVG = "SlotOutlet1Avg"
    _SLOT_OUTLET1_MAX = "SlotOutlet1Max"
    _SLOT_OUTLET1_MIN = "SlotOutlet1Min"
    _SLOT_OUTLET2 = "SlotOutlet2"
    _SLOT_OUTLET2_AVG = "SlotOutlet2Avg"
    _SLOT_OUTLET2_MAX = "SlotOutlet2Max"
    _SLOT_OUTLET2_MIN = "SlotOutlet2Min"
    _SLOT_OUTLET3 = "SlotOutlet3"
    _SLOT_OUTLET3_AVG = "SlotOutlet3Avg"
    _SLOT_OUTLET3_MAX = "SlotOutlet3Max"
    _SLOT_OUTLET3_MIN = "SlotOutlet3Min"
    _STEP = "Step"
    _TEMPLATE_COUNT = "TemplateCount"
    _TIMEOUT_ERRORS = "TimeoutErrors"
    _TIMEOUT_ERRORS_AVG = "TimeoutErrorsAvg"
    _TIMEOUT_ERRORS_MAX = "TimeoutErrorsMax"
    _TIMEOUT_ERRORS_MIN = "TimeoutErrorsMin"
    _TIMEOUT_ERRORS_RUNNING = "TimeoutErrorsRunning"
    _TYPE = "Type"
    _UCSDOMAIN_NAME = "UCSDomainName"
    _UCS_DN = "UcsDn"
    _UCS_NAME = "UcsName"
    _UNIT = "Unit"
    _VMMQ_SUB_VNIC_COUNT = "VmmqSubVnicCount"
    A_PARTIAL_ENUM = "aPartialEnum"
    ABITMASK = "abitmask"
    ABS_MIN_POST_POWER = "absMinPostPower"
    ABS_QUANT = "absQuant"
    ACCELARATED_RFS = "accelaratedRFS"
    ACCESS = "access"
    ACCESS_POLICY = "accessPolicy"
    ACCOUNT_STATUS = "accountStatus"
    ACHAR = "achar"
    ACHARBUF = "acharbuf"
    ACK = "ack"
    ACK_ACTION = "ackAction"
    ACK_APP_RESPONSE_COUNT = "ackAppResponseCount"
    ACK_DN = "ackDn"
    ACK_STATE = "ackState"
    ACKED = "acked"
    ACKED_BY = "ackedBy"
    ACS_VIOLATION_ERRORS = "acsViolationErrors"
    ACS_VIOLATION_ERRORS_AVG = "acsViolationErrorsAvg"
    ACS_VIOLATION_ERRORS_MAX = "acsViolationErrorsMax"
    ACS_VIOLATION_ERRORS_MIN = "acsViolationErrorsMin"
    ACS_VIOLATION_ERRORS_RUNNING = "acsViolationErrorsRunning"
    ACTION = "action"
    ACTION_CODE = "actionCode"
    ACTION_EVENT = "actionEvent"
    ACTION_MSG = "actionMsg"
    ACTION_VALUES = "actionValues"
    ACTIVITY_TS = "activityTs"
    ACTUAL_SIZE = "actualSize"
    ACTUAL_WRITE_CACHE_POLICY = "actualWriteCachePolicy"
    ADAPTER_ID = "adapterId"
    ADAPTER_MODEL = "adapterModel"
    ADAPTER_PID = "adapterPid"
    ADAPTOR_ID = "adaptorId"
    ADAPTOR_MODEL = "adaptorModel"
    ADAPTOR_PROFILE_NAME = "adaptorProfileName"
    ADATE = "adate"
    ADATETIME = "adatetime"
    ADDR = "addr"
    ADDRESS = "address"
    ADDRESS_PARITY_ERRORS = "addressParityErrors"
    ADDRESS_PARITY_ERRORS_AVG = "addressParityErrorsAvg"
    ADDRESS_PARITY_ERRORS_MAX = "addressParityErrorsMax"
    ADDRESS_PARITY_ERRORS_MIN = "addressParityErrorsMin"
    ADDRESS_PARITY_ERRORS_RUNNING = "addressParityErrorsRunning"
    ADMIN_ACTION = "adminAction"
    ADMIN_ACTION_TRIGGER = "adminActionTrigger"
    ADMIN_CDN_NAME = "adminCdnName"
    ADMIN_COMMITTED = "adminCommitted"
    ADMIN_DNLD_STATUS = "adminDnldStatus"
    ADMIN_EULASTATUS = "adminEULAStatus"
    ADMIN_EVAC_STATE = "adminEvacState"
    ADMIN_FPLOCK_STATE = "adminFPLockState"
    ADMIN_HOST_PORT = "adminHostPort"
    ADMIN_INBAND_IF_STATE = "adminInbandIfState"
    ADMIN_LEADERSHIP = "adminLeadership"
    ADMIN_NAME = "adminName"
    ADMIN_PEAK = "adminPeak"
    ADMIN_PEAK_NEW = "adminPeakNew"
    ADMIN_PEER_POWER_STATE = "adminPeerPowerState"
    ADMIN_POWER = "adminPower"
    ADMIN_POWER_STATE = "adminPowerState"
    ADMIN_PROP_MASK = "adminPropMask"
    ADMIN_PROP_MOD = "adminPropMod"
    ADMIN_SECURITY_KEY = "adminSecurityKey"
    ADMIN_SLOT_NUMBER = "adminSlotNumber"
    ADMIN_SPEED = "adminSpeed"
    ADMIN_STATE = "adminState"
    ADMIN_STATE_ACK = "adminStateAck"
    ADMIN_STATE_REQUESTOR = "adminStateRequestor"
    ADMIN_TRANSPORT = "adminTransport"
    ADMIN_VCON = "adminVcon"
    ADMIN_VIRTUAL_DRIVE_ID = "adminVirtualDriveId"
    ADV_BOOT_ORDER_APPLICABLE = "advBootOrderApplicable"
    AFFECTED = "affected"
    AFFECTED_CHASSIS = "affectedChassis"
    AFFECTED_CHASSIS_CNT = "affectedChassisCnt"
    AFFECTED_OBJ = "affectedObj"
    AFFECTED_OBJECT = "affectedObject"
    AFFECTED_SP = "affectedSP"
    AFFECTED_SERVER = "affectedServer"
    AFFECTED_SERVERS = "affectedServers"
    AFLOAT = "afloat"
    AGENT_COMPONENT_VERSION = "agentComponentVersion"
    AGENT_POLICY_NAME = "agentPolicyName"
    AGENT_STATE = "agentState"
    AGENT_VERSION = "agentVersion"
    AGGR_PORT_ID = "aggrPortId"
    AIRFLOW_DIRECTION = "airflowDirection"
    ALERT_GROUPS = "alertGroups"
    ALERT_THROTTLING_ADMIN_STATE = "alertThrottlingAdminState"
    ALIGN = "align"
    ALIGN_DELTA = "alignDelta"
    ALIGN_DELTA_AVG = "alignDeltaAvg"
    ALIGN_DELTA_MAX = "alignDeltaMax"
    ALIGN_DELTA_MIN = "alignDeltaMin"
    ALLOC_STATE = "allocState"
    ALLOCATED_SIZE = "allocatedSize"
    ALLOW_DESCENDANTS = "allowDescendants"
    ALWAYS_USE = "alwaysUse"
    AMAC = "amac"
    AMBIENT_TEMP = "ambientTemp"
    AMBIENT_TEMP_AVG = "ambientTempAvg"
    AMBIENT_TEMP_MAX = "ambientTempMax"
    AMBIENT_TEMP_MIN = "ambientTempMin"
    AND_OPERATION = "andOperation"
    ANENUM = "anenum"
    ANIPV4 = "anipv4"
    ANIPV6 = "anipv6"
    ANSBYTE = "ansbyte"
    ANSINT16 = "ansint16"
    ANSINT32 = "ansint32"
    ANSINT64 = "ansint64"
    APASSWORD = "apassword"
    APP_CONNECTOR_ID = "appConnectorId"
    APP_ID = "appId"
    APP_TYPE = "appType"
    APPLY = "apply"
    ARANGE = "arange"
    ARCH = "arch"
    ARCSTRING = "arcstring"
    ARRAY = "array"
    ARXSTRING = "arxstring"
    ASSET_TAG = "assetTag"
    ASSIGN_STATE = "assignState"
    ASSIGNED = "assigned"
    ASSIGNED_FROM_POOL = "assignedFromPool"
    ASSIGNED_ON_BEHALF = "assignedOnBehalf"
    ASSIGNED_OWNER_DN = "assignedOwnerDn"
    ASSIGNED_TO_DN = "assignedToDn"
    ASSIGNED_VOLUME = "assignedVolume"
    ASSOC_PRIMARY_VLAN_STATE = "assocPrimaryVlanState"
    ASSOC_PRIMARY_VLAN_SWITCH_ID = "assocPrimaryVlanSwitchId"
    ASSOC_STATE = "assocState"
    ASSOCIATION = "association"
    ASTRING = "astring"
    AT_VMLEVEL = "atVMLevel"
    ATIME = "atime"
    ATTR_NAME = "attrName"
    ATTR_VALUE = "attrValue"
    ATTRIBUTE = "attribute"
    AUBYTE = "aubyte"
    AUDITS = "audits"
    AUINT16 = "auint16"
    AUINT32 = "auint32"
    AUINT64 = "auint64"
    AUTH = "auth"
    AUTH_EXPIRE_TIME = "authExpireTime"
    AUTH_EXPIRED = "authExpired"
    AUTH_OPTION = "authOption"
    AUTH_PORT = "authPort"
    AUTH_PROFILE_NAME = "authProfileName"
    AUTH_STATUS = "authStatus"
    AUTH_USER = "authUser"
    AUTHORIZATION = "authorization"
    AUTO_AQUIRED = "autoAquired"
    AUTO_DELETE = "autoDelete"
    AUTO_DEPLOY = "autoDeploy"
    AUTO_NEGOTIATE = "autoNegotiate"
    AUTO_ZONE_CAUSE = "autoZoneCause"
    AVAILABILITY = "availability"
    AVAILABLE = "available"
    AVAILABLE_AVG = "availableAvg"
    AVAILABLE_MAX = "availableMax"
    AVAILABLE_MEMORY = "availableMemory"
    AVAILABLE_MIN = "availableMin"
    AVAILABLE_PHYSICAL_CNT = "availablePhysicalCnt"
    AVAILABLE_POWER = "availablePower"
    AVAILABLE_POWER_AVG = "availablePowerAvg"
    AVAILABLE_POWER_MAX = "availablePowerMax"
    AVAILABLE_POWER_MIN = "availablePowerMin"
    AVAILABLE_SIZE = "availableSize"
    AWWN = "awwn"
    BACKPLANE_SPEED_PREF = "backplaneSpeedPref"
    BACKSTORE_DN = "backstoreDn"
    BACKSTORE_ID = "backstoreId"
    BACKUP_ABILITY = "backupAbility"
    BACKUP_COUNT = "backupCount"
    BACKUP_STATUS = "backupStatus"
    BACKUP_TRIGGER_STATUS = "backupTriggerStatus"
    BACKUP_TYPE = "backupType"
    BAD_CRC_PACKETS = "badCrcPackets"
    BAD_CRC_PACKETS_DELTA = "badCrcPacketsDelta"
    BAD_CRC_PACKETS_DELTA_AVG = "badCrcPacketsDeltaAvg"
    BAD_CRC_PACKETS_DELTA_MAX = "badCrcPacketsDeltaMax"
    BAD_CRC_PACKETS_DELTA_MIN = "badCrcPacketsDeltaMin"
    BAD_LENGTH_PACKETS = "badLengthPackets"
    BAD_LENGTH_PACKETS_DELTA = "badLengthPacketsDelta"
    BAD_LENGTH_PACKETS_DELTA_AVG = "badLengthPacketsDeltaAvg"
    BAD_LENGTH_PACKETS_DELTA_MAX = "badLengthPacketsDeltaMax"
    BAD_LENGTH_PACKETS_DELTA_MIN = "badLengthPacketsDeltaMin"
    BANDWIDTH = "bandwidth"
    BANK = "bank"
    BASE_ADDR = "baseAddr"
    BASE_MAC = "baseMac"
    BASEDN = "basedn"
    BASIC_WIDGET_DISABLED = "basicWidgetDisabled"
    BATTERY_TYPE = "batteryType"
    BBU_STATUS = "bbuStatus"
    BIOS_FW_STATUS = "biosFwStatus"
    BIOS_FW_VERSION = "biosFwVersion"
    BIOS_PROFILE_NAME = "biosProfileName"
    BIOS_RET_SETTING_NAME = "biosRetSettingName"
    BIOS_SETTINGS_SCRUB = "biosSettingsScrub"
    BLADE_BUNDLE_NAME = "bladeBundleName"
    BLADE_BUNDLE_VERSION = "bladeBundleVersion"
    BLADE_DN = "bladeDn"
    BLADE_ID = "bladeId"
    BLADE_OPER_STATE = "bladeOperState"
    BLADE_VERSION = "bladeVersion"
    BLKSIZE = "blksize"
    BLOCK_DN = "blockDn"
    BLOCK_SIZE = "blockSize"
    BLOCKS = "blocks"
    BOARD_AGGREGATION_ROLE = "boardAggregationRole"
    BOARD_CONNECTOR_TYPE = "boardConnectorType"
    BOARD_CONTROLLER_FW_STATUS = "boardControllerFwStatus"
    BOARD_CONTROLLER_FW_VERSION = "boardControllerFwVersion"
    BOOT = "boot"
    BOOT_DESCRIPTION = "bootDescription"
    BOOT_DEV = "bootDev"
    BOOT_IP_POLICY_NAME = "bootIpPolicyName"
    BOOT_LOADER_NAME = "bootLoaderName"
    BOOT_LOADER_PATH = "bootLoaderPath"
    BOOT_MODE = "bootMode"
    BOOT_ORDER_TYPE = "bootOrderType"
    BOOT_POLICY_NAME = "bootPolicyName"
    BOOT_POWER = "bootPower"
    BOOT_TO_TARGET = "bootToTarget"
    BOOTABLE = "bootable"
    BORDER_AGGR_PORT_ID = "borderAggrPortId"
    BORDER_PORT_ID = "borderPortId"
    BORDER_SLOT_ID = "borderSlotId"
    BORDER_VFC_ID = "borderVfcId"
    BREAKOUT_TYPE = "breakoutType"
    BROADCAST_PACKETS = "broadcastPackets"
    BROADCAST_PACKETS_DELTA = "broadcastPacketsDelta"
    BROADCAST_PACKETS_DELTA_AVG = "broadcastPacketsDeltaAvg"
    BROADCAST_PACKETS_DELTA_MAX = "broadcastPacketsDeltaMax"
    BROADCAST_PACKETS_DELTA_MIN = "broadcastPacketsDeltaMin"
    BSD_CHECKSUM = "bsdChecksum"
    BUFFER_OVERFLOW_ERRORS = "bufferOverflowErrors"
    BUFFER_OVERFLOW_ERRORS_AVG = "bufferOverflowErrorsAvg"
    BUFFER_OVERFLOW_ERRORS_MAX = "bufferOverflowErrorsMax"
    BUFFER_OVERFLOW_ERRORS_MIN = "bufferOverflowErrorsMin"
    BUFFER_OVERFLOW_ERRORS_RUNNING = "bufferOverflowErrorsRunning"
    BULKED = "bulked"
    BUNDLE = "bundle"
    BUNDLE_NAME = "bundleName"
    BURST = "burst"
    BW_PERCENT = "bwPercent"
    BY = "by"
    BYTES_RX = "bytesRx"
    BYTES_RX_DELTA = "bytesRxDelta"
    BYTES_RX_DELTA_AVG = "bytesRxDeltaAvg"
    BYTES_RX_DELTA_MAX = "bytesRxDeltaMax"
    BYTES_RX_DELTA_MIN = "bytesRxDeltaMin"
    BYTES_TX = "bytesTx"
    BYTES_TX_DELTA = "bytesTxDelta"
    BYTES_TX_DELTA_AVG = "bytesTxDeltaAvg"
    BYTES_TX_DELTA_MAX = "bytesTxDeltaMax"
    BYTES_TX_DELTA_MIN = "bytesTxDeltaMin"
    CA_CERTIFICATE = "caCertificate"
    CACHE_SIZE = "cacheSize"
    CACHED = "cached"
    CACHED_AVG = "cachedAvg"
    CACHED_MAX = "cachedMax"
    CACHED_MIN = "cachedMin"
    CAP_ACTION = "capAction"
    CAPABILITY = "capability"
    CAPACITY = "capacity"
    CAPACITY_PERCENTAGE = "capacityPercentage"
    CAPTION = "caption"
    CARD_HEALTH = "cardHealth"
    CARD_MODE = "cardMode"
    CARD_STATE = "cardState"
    CARD_SYNC = "cardSync"
    CARD_TYPE = "cardType"
    CARRIER_SENSE = "carrierSense"
    CARRIER_SENSE_DELTA = "carrierSenseDelta"
    CARRIER_SENSE_DELTA_AVG = "carrierSenseDeltaAvg"
    CARRIER_SENSE_DELTA_MAX = "carrierSenseDeltaMax"
    CARRIER_SENSE_DELTA_MIN = "carrierSenseDeltaMin"
    CARTRIDGE_CIMCID = "cartridgeCIMCId"
    CARTRIDGE_ID = "cartridgeId"
    CARTRIDGE_OPER_STATE = "cartridgeOperState"
    CATALOG_NAME = "catalogName"
    CATALOG_POWER = "catalogPower"
    CATALOG_UPDATED_DATE = "catalogUpdatedDate"
    CATALOG_VERSION = "catalogVersion"
    CATEGORY = "category"
    CAUSE = "cause"
    CAUSE_STRING = "causeString"
    CDN_NAME = "cdnName"
    CDN_SOURCE = "cdnSource"
    CDP = "cdp"
    CDP_LINK_POLICY_NAME = "cdpLinkPolicyName"
    CENTRAL_AFFECTED_OBJECT = "centralAffectedObject"
    CENTRAL_IP = "centralIp"
    CENTRAL_RANGE_CHECK_CONFIG_STATE = "centralRangeCheckConfigState"
    CENTRALE_MO_DN = "centraleMoDn"
    CENTRALE_VNET_EP_DN = "centraleVnetEpDn"
    CERT = "cert"
    CERT_CHAIN = "certChain"
    CERT_SIGN_REQUEST = "certSignRequest"
    CERT_STATUS = "certStatus"
    CERTIFICATE = "certificate"
    CH_RSRVD_POWER = "chRsrvdPower"
    CHANGE_BY = "changeBy"
    CHANGE_COUNT = "changeCount"
    CHANGE_DETAILS = "changeDetails"
    CHANGE_DURING_INTERVAL = "changeDuringInterval"
    CHANGE_FLAG = "changeFlag"
    CHANGE_ID = "changeId"
    CHANGE_INTERVAL = "changeInterval"
    CHANGE_MODE = "changeMode"
    CHANGE_QUALIFIER = "changeQualifier"
    CHANGE_SET = "changeSet"
    CHANGED_MO_CLASS_ID = "changedMoClassId"
    CHANGES = "changes"
    CHANNEL_STATE = "channelState"
    CHART_DOMAIN = "chartDomain"
    CHART_INTERVAL = "chartInterval"
    CHART_TYPE = "chartType"
    CHASSIS1 = "chassis1"
    CHASSIS2 = "chassis2"
    CHASSIS3 = "chassis3"
    CHASSIS_BUNDLE_NAME = "chassisBundleName"
    CHASSIS_BUNDLE_VERSION = "chassisBundleVersion"
    CHASSIS_CARTRIDGE_ID = "chassisCartridgeId"
    CHASSIS_CIMC_ID = "chassisCimcId"
    CHASSIS_COMPONENT = "chassisComponent"
    CHASSIS_CONFIG_ISSUES = "chassisConfigIssues"
    CHASSIS_CONFIG_QUALIFIER = "chassisConfigQualifier"
    CHASSIS_CONFIG_STATE = "chassisConfigState"
    CHASSIS_DEVICE_IO_STATE1 = "chassisDeviceIoState1"
    CHASSIS_DEVICE_IO_STATE2 = "chassisDeviceIoState2"
    CHASSIS_DEVICE_IO_STATE3 = "chassisDeviceIoState3"
    CHASSIS_DN = "chassisDn"
    CHASSIS_FW_POLICY_NAME = "chassisFwPolicyName"
    CHASSIS_ID = "chassisId"
    CHASSIS_IOM_ID = "chassisIomId"
    CHASSIS_POOL_DN = "chassisPoolDn"
    CHASSIS_PROFILE_AFFECTED = "chassisProfileAffected"
    CHASSIS_PROFILE_DN = "chassisProfileDn"
    CHASSIS_PROFILE_NAME = "chassisProfileName"
    CHASSIS_PROFILE_OWNER = "chassisProfileOwner"
    CHASSIS_STORAGE_CONFIG_ISSUES = "chassisStorageConfigIssues"
    CHECK_POINT = "checkPoint"
    CHECKSUM = "checksum"
    CHILD_ACTION = "childAction"
    CHILD_CLASS_ID = "childClassId"
    CIMC_ADAPTER_ID = "cimcAdapterId"
    CIMC_BACKUP_TRIGGER_STATUS = "cimcBackupTriggerStatus"
    CIMC_HEARTBEAT_STATUS = "cimcHeartbeatStatus"
    CLASS_NAME = "className"
    CLASS_TYPE = "classType"
    CLEANUP_MODE = "cleanupMode"
    CLEAR_ACTION = "clearAction"
    CLEAR_INTERVAL = "clearInterval"
    CLEAR_ON_BACKUP = "clearOnBackup"
    CLEAR_PWD_HISTORY = "clearPwdHistory"
    CLEI = "clei"
    CLIENT_ARRAY_DESTINATION_DN = "clientArrayDestinationDn"
    CLIENT_BLADE_LOCATION_DN = "clientBladeLocationDn"
    CLIENT_DN = "clientDn"
    CLIENT_ID = "clientId"
    CLIENT_MO_DN = "clientMoDn"
    CLIENT_TYPE = "clientType"
    CLOCK = "clock"
    CLONE_STATUS = "cloneStatus"
    CLOUD = "cloud"
    CLUSTER_STATE = "clusterState"
    CMC_TEMP = "cmcTemp"
    CMC_TEMP_AVG = "cmcTempAvg"
    CMC_TEMP_MAX = "cmcTempMax"
    CMC_TEMP_MIN = "cmcTempMin"
    CMOS_RESET_SUPPORTED = "cmosResetSupported"
    CMOS_VOLTAGE = "cmosVoltage"
    COALESCING_TIME = "coalescingTime"
    COALESCING_TYPE = "coalescingType"
    CODE = "code"
    COLLECTION_INTERVAL = "collectionInterval"
    COLOR = "color"
    COMMAND_OPTIONS = "commandOptions"
    COMMUNITY = "community"
    COMPATIBLE_VERSION = "compatibleVersion"
    COMPLETENESS = "completeness"
    COMPLETION = "completion"
    COMPLETION_TIME = "completionTime"
    COMPLETION_TIMESTAMP = "completionTimestamp"
    COMPONENT_DN = "componentDn"
    COMPONENT_ID = "componentId"
    COMPONENT_NAME = "componentName"
    COMPOSITE_ID = "compositeId"
    COMPRESSION_TYPE = "compressionType"
    COMPUTE_CONN_POLICY_NAME = "computeConnPolicyName"
    COMPUTE_INSTANCE_DN = "computeInstanceDn"
    CON_LOGIN = "conLogin"
    CON_POLICY_NAME = "conPolicyName"
    CONCUR_CAP = "concurCap"
    CONDITION = "condition"
    CONFIG_CHECK_POINT = "configCheckPoint"
    CONFIG_DN = "configDn"
    CONFIG_ERROR_COUNT = "configErrorCount"
    CONFIG_FAIL_REASON = "configFailReason"
    CONFIG_ISSUE = "configIssue"
    CONFIG_ISSUES = "configIssues"
    CONFIG_MESSAGE = "configMessage"
    CONFIG_QUAL = "configQual"
    CONFIG_QUALIFIER = "configQualifier"
    CONFIG_QUALIFIER_REASON = "configQualifierReason"
    CONFIG_RANGE_MESSAGE = "configRangeMessage"
    CONFIG_REGISTERED_STATE = "configRegisteredState"
    CONFIG_SCOPE = "configScope"
    CONFIG_STATE = "configState"
    CONFIG_STATUS = "configStatus"
    CONFIG_STATUS_MESSAGE = "configStatusMessage"
    CONFIG_WARNINGS = "configWarnings"
    CONFIGURATION = "configuration"
    CONFIGURED_MODE = "configuredMode"
    CONFIGURED_WRITE_CACHE_POLICY = "configuredWriteCachePolicy"
    CONFLICT = "conflict"
    CONN_PATH = "connPath"
    CONN_PROTOCOL = "connProtocol"
    CONN_STATUS = "connStatus"
    CONNECTION_PROTOCOL = "connectionProtocol"
    CONNECTION_STATE = "connectionState"
    CONNECTION_TIME_OUT = "connectionTimeOut"
    CONNECTOR_ID = "connectorId"
    CONS_CNT = "consCnt"
    CONS_DN = "consDn"
    CONS_TYPE = "consType"
    CONSUMED_POWER = "consumedPower"
    CONSUMED_POWER_AVG = "consumedPowerAvg"
    CONSUMED_POWER_MAX = "consumedPowerMax"
    CONSUMED_POWER_MIN = "consumedPowerMin"
    CONSUMER_DN = "consumerDn"
    CONSUMER_ELEMENT_ID = "consumerElementId"
    CONSUMER_NAME = "consumerName"
    CONTACT = "contact"
    CONTAINER_ID = "containerId"
    CONTEXT = "context"
    CONTEXT_CLASS = "contextClass"
    CONTEXT_DN = "contextDn"
    CONTRACT = "contract"
    CONTROL_REQUESTS = "controlRequests"
    CONTROL_REQUESTS_DELTA = "controlRequestsDelta"
    CONTROL_REQUESTS_DELTA_AVG = "controlRequestsDeltaAvg"
    CONTROL_REQUESTS_DELTA_MAX = "controlRequestsDeltaMax"
    CONTROL_REQUESTS_DELTA_MIN = "controlRequestsDeltaMin"
    CONTROLLER_DN = "controllerDn"
    CONTROLLER_FLAGS = "controllerFlags"
    CONTROLLER_HEALTH = "controllerHealth"
    CONTROLLER_ID = "controllerId"
    CONTROLLER_INDEX = "controllerIndex"
    CONTROLLER_OPS = "controllerOps"
    CONTROLLER_STATE = "controllerState"
    CONTROLLER_STATUS = "controllerStatus"
    CONTROLLER_TYPE = "controllerType"
    CONVERTED_DN = "convertedDn"
    CONVERTED_EP_REF = "convertedEpRef"
    COOKIE = "cookie"
    COOLING_ENDPOINT = "coolingEndpoint"
    CORES = "cores"
    CORES_ENABLED = "coresEnabled"
    CORRECTABLE_ERRORS = "correctableErrors"
    CORRECTABLE_ERRORS_DELTA = "correctableErrorsDelta"
    CORRECTABLE_ERRORS_DELTA_AVG = "correctableErrorsDeltaAvg"
    CORRECTABLE_ERRORS_DELTA_MAX = "correctableErrorsDeltaMax"
    CORRECTABLE_ERRORS_DELTA_MIN = "correctableErrorsDeltaMin"
    COS = "cos"
    COUNT = "count"
    COUNTER = "counter"
    COUNTRY = "country"
    COUNTRY_CODE = "countryCode"
    CP_DN = "cpDn"
    CP_REFRESH = "cpRefresh"
    CPU_ARCH = "cpuArch"
    CPU_FILTER = "cpuFilter"
    CPU_ID = "cpuId"
    CPU_LOAD = "cpuLoad"
    CPU_LOAD_AVG = "cpuLoadAvg"
    CPU_LOAD_MAX = "cpuLoadMax"
    CPU_LOAD_MIN = "cpuLoadMin"
    CPU_TYPE_DESCRIPTION = "cpuTypeDescription"
    CRC_RX = "crcRx"
    CRC_RX_DELTA = "crcRxDelta"
    CRC_RX_DELTA_AVG = "crcRxDeltaAvg"
    CRC_RX_DELTA_MAX = "crcRxDeltaMax"
    CRC_RX_DELTA_MIN = "crcRxDeltaMin"
    CREATE_FROM_DN = "createFromDn"
    CREATE_INITIAL_VOLUMES = "createInitialVolumes"
    CREATE_TS = "createTs"
    CREATED = "created"
    CREATION_DATE = "creationDate"
    CREATION_TS = "creationTS"
    CREATION_TIMESTAMP = "creationTimestamp"
    CRITICAL_CNT = "criticalCnt"
    CTIME = "ctime"
    CTPASSWORD = "ctpassword"
    CUR_REQ_POWER = "curReqPower"
    CURR_CAPACITY = "currCapacity"
    CURRENT = "current"
    CURRENT_AVG = "currentAvg"
    CURRENT_EPFB = "currentEPFB"
    CURRENT_FIRMWARE = "currentFirmware"
    CURRENT_FSM = "currentFsm"
    CURRENT_MAX = "currentMax"
    CURRENT_MIN = "currentMin"
    CURRENT_POWER = "currentPower"
    CURRENT_SET_IN_POLLING = "currentSetInPolling"
    CURRENT_TIME = "currentTime"
    CUSTOMER = "customer"
    DAILY_LAST_RUN = "dailyLastRun"
    DAILY_RECORDS = "dailyRecords"
    DASHBOARD = "dashboard"
    DATA = "data"
    DATA_DISR = "dataDisr"
    DATA_SRC_APP_TYPE = "dataSrcAppType"
    DATA_SRC_SYS_ID = "dataSrcSysId"
    DATABASE = "database"
    DATE = "date"
    DAY = "day"
    DB_ERROR = "dbError"
    DBTXS = "dbtxs"
    DECISION_TYPE = "decisionType"
    DECOMMISSIONED = "decommissioned"
    DEESCALATING = "deescalating"
    DEF_DN = "defDn"
    DEF_GW = "defGw"
    DEF_LOGIN = "defLogin"
    DEF_NAME = "defName"
    DEF_QUANT = "defQuant"
    DEF_ROLE_POLICY = "defRolePolicy"
    DEFAULT_IDENT_POOL_NAME = "defaultIdentPoolName"
    DEFAULT_LEVEL = "defaultLevel"
    DEFAULT_NET = "defaultNet"
    DEFAULT_NETWORK = "defaultNetwork"
    DEFAULT_POLICY_NAME = "defaultPolicyName"
    DEFAULT_SIZE = "defaultSize"
    DEFAULT_STRIP_SIZE = "defaultStripSize"
    DEFAULT_VIEW = "defaultView"
    DEFAULT_VLAN_NAME = "defaultVlanName"
    DEFAULT_ZONING = "defaultZoning"
    DEFERRED_NAMING = "deferredNaming"
    DEFERRED_TX = "deferredTx"
    DEFERRED_TX_DELTA = "deferredTxDelta"
    DEFERRED_TX_DELTA_AVG = "deferredTxDeltaAvg"
    DEFERRED_TX_DELTA_MAX = "deferredTxDeltaMax"
    DEFERRED_TX_DELTA_MIN = "deferredTxDeltaMin"
    DEFINED_IN_IDM = "definedInIdm"
    DEL_FE_TS = "delFeTs"
    DELETE_SOURCE = "deleteSource"
    DELETED = "deleted"
    DEPLOY_ACTION = "deployAction"
    DEPLOY_DN = "deployDn"
    DEPLOY_STATE = "deployState"
    DEPLOYED_SECURITY_KEY = "deployedSecurityKey"
    DEPLOYMENT = "deployment"
    DEPLOYMENT_MODE = "deploymentMode"
    DEPRECATED = "deprecated"
    DEREGISTER = "deregister"
    DEREGISTER_FAILED = "deregisterFailed"
    DEREGISTER_FAILURE_MSG = "deregisterFailureMsg"
    DERIVED_FROM_ID = "derivedFromId"
    DESCR = "descr"
    DESCRIPTION = "description"
    DEST_DN = "destDn"
    DETAIL = "detail"
    DEV = "dev"
    DEVICE = "device"
    DEVICE_ID = "deviceId"
    DEVICE_NAME = "deviceName"
    DEVICE_PROFILE_REF = "deviceProfileRef"
    DEVICE_RAID_SUPPORT = "deviceRaidSupport"
    DEVICE_TYPE = "deviceType"
    DEVICE_VERSION = "deviceVersion"
    DHCP_TIME_OUT = "dhcpTimeOut"
    DHCP_VENDOR_ID = "dhcpVendorId"
    DIAG_OPER_STATE = "diagOperState"
    DIAG_OVERALL_PROGRESS = "diagOverallProgress"
    DIE1 = "die1"
    DIE1_AVG = "die1Avg"
    DIE1_MAX = "die1Max"
    DIE1_MIN = "die1Min"
    DIFF_MEMORY = "diffMemory"
    DIR = "dir"
    DIRECTION = "direction"
    DISCARD_RX = "discardRx"
    DISCARD_RX_DELTA = "discardRxDelta"
    DISCARD_RX_DELTA_AVG = "discardRxDeltaAvg"
    DISCARD_RX_DELTA_MAX = "discardRxDeltaMax"
    DISCARD_RX_DELTA_MIN = "discardRxDeltaMin"
    DISCARD_TX = "discardTx"
    DISCARD_TX_DELTA = "discardTxDelta"
    DISCARD_TX_DELTA_AVG = "discardTxDeltaAvg"
    DISCARD_TX_DELTA_MAX = "discardTxDeltaMax"
    DISCARD_TX_DELTA_MIN = "discardTxDeltaMin"
    DISCOVERED_PATH = "discoveredPath"
    DISCOVERY = "discovery"
    DISCOVERY_STATUS = "discoveryStatus"
    DISK_DN = "diskDn"
    DISK_OPS = "diskOps"
    DISK_PRESENT = "diskPresent"
    DISK_SCRUB = "diskScrub"
    DISK_SELECTION_ORDER = "diskSelectionOrder"
    DISK_SELECTION_TS = "diskSelectionTs"
    DISK_STATE = "diskState"
    DISK_TYPE = "diskType"
    DISK_ZONING_POLICY_NAME = "diskZoningPolicyName"
    DISKLESS = "diskless"
    DISPLAY_ID = "displayId"
    DISR = "disr"
    DISR_TYPE = "disrType"
    DLLP_ERRORS = "dllpErrors"
    DLLP_ERRORS_AVG = "dllpErrorsAvg"
    DLLP_ERRORS_MAX = "dllpErrorsMax"
    DLLP_ERRORS_MIN = "dllpErrorsMin"
    DLLP_ERRORS_RUNNING = "dllpErrorsRunning"
    DN = "dn"
    DNS = "dns"
    DOM = "dom"
    DOMAIN = "domain"
    DOMAIN_CNT = "domainCnt"
    DOMAIN_CONNECTION_STATE = "domainConnectionState"
    DOMAIN_DN = "domainDn"
    DOMAIN_GROUP = "domainGroup"
    DOMAIN_GROUP_DN = "domainGroupDn"
    DOMAIN_GROUP_NAME = "domainGroupName"
    DOMAIN_GROUP_SCOPE_DN_CNT = "domainGroupScopeDnCnt"
    DOMAIN_ID = "domainId"
    DOMAIN_INST_REF = "domainInstRef"
    DOMAIN_IPV4 = "domainIpv4"
    DOMAIN_IPV6 = "domainIpv6"
    DOMAIN_NAME = "domainName"
    DOMAIN_OPER_STATE = "domainOperState"
    DOMAIN_POOL_DN = "domainPoolDn"
    DOMAIN_POOL_NAME = "domainPoolName"
    DOMAIN_SCOPE_DN_CNT = "domainScopeDnCnt"
    DOMAIN_STATE = "domainState"
    DOMAIN_SUSPEND_STATE = "domainSuspendState"
    DOMAIN_TEMPLATE_DN = "domainTemplateDn"
    DOMAIN_TEMPLATE_NAME = "domainTemplateName"
    DOMAINGROUP_DN = "domaingroupDn"
    DOWNLOAD_DATE = "downloadDate"
    DOWNLOAD_ERROR = "downloadError"
    DOWNLOAD_INTERVAL = "downloadInterval"
    DOWNLOAD_STATUS = "downloadStatus"
    DRIVE_CACHE = "driveCache"
    DRIVE_LIFE_USED_PERCENTAGE = "driveLifeUsedPercentage"
    DRIVE_LIFE_USED_PERCENTAGE_AVG = "driveLifeUsedPercentageAvg"
    DRIVE_LIFE_USED_PERCENTAGE_MAX = "driveLifeUsedPercentageMax"
    DRIVE_LIFE_USED_PERCENTAGE_MIN = "driveLifeUsedPercentageMin"
    DRIVE_PATH = "drivePath"
    DRIVE_PERCENTAGE = "drivePercentage"
    DRIVE_PERCENTAGE_AVG = "drivePercentageAvg"
    DRIVE_PERCENTAGE_MAX = "drivePercentageMax"
    DRIVE_PERCENTAGE_MIN = "drivePercentageMin"
    DRIVE_SECURITY = "driveSecurity"
    DRIVE_STATE = "driveState"
    DRIVE_TYPE = "driveType"
    DRIVER_PROTOCOL = "driverProtocol"
    DRIVER_VENDOR = "driverVendor"
    DRIVER_VERSION = "driverVersion"
    DRIVES = "drives"
    DRIVES_ENABLED = "drivesEnabled"
    DROP = "drop"
    DROP_ACL = "dropAcl"
    DROP_ACL_DELTA = "dropAclDelta"
    DROP_ACL_DELTA_AVG = "dropAclDeltaAvg"
    DROP_ACL_DELTA_MAX = "dropAclDeltaMax"
    DROP_ACL_DELTA_MIN = "dropAclDeltaMin"
    DROP_CMD = "dropCmd"
    DROP_CMD_DELTA = "dropCmdDelta"
    DROP_CMD_DELTA_AVG = "dropCmdDeltaAvg"
    DROP_CMD_DELTA_MAX = "dropCmdDeltaMax"
    DROP_CMD_DELTA_MIN = "dropCmdDeltaMin"
    DROP_FC_LIF_INVALID = "dropFcLifInvalid"
    DROP_FC_LIF_INVALID_DELTA = "dropFcLifInvalidDelta"
    DROP_FC_LIF_INVALID_DELTA_AVG = "dropFcLifInvalidDeltaAvg"
    DROP_FC_LIF_INVALID_DELTA_MAX = "dropFcLifInvalidDeltaMax"
    DROP_FC_LIF_INVALID_DELTA_MIN = "dropFcLifInvalidDeltaMin"
    DROP_FC_MULTICAST = "dropFcMulticast"
    DROP_FC_MULTICAST_DELTA = "dropFcMulticastDelta"
    DROP_FC_MULTICAST_DELTA_AVG = "dropFcMulticastDeltaAvg"
    DROP_FC_MULTICAST_DELTA_MAX = "dropFcMulticastDeltaMax"
    DROP_FC_MULTICAST_DELTA_MIN = "dropFcMulticastDeltaMin"
    DROP_LIF_CFG_INVALID = "dropLifCfgInvalid"
    DROP_LIF_CFG_INVALID_DELTA = "dropLifCfgInvalidDelta"
    DROP_LIF_CFG_INVALID_DELTA_AVG = "dropLifCfgInvalidDeltaAvg"
    DROP_LIF_CFG_INVALID_DELTA_MAX = "dropLifCfgInvalidDeltaMax"
    DROP_LIF_CFG_INVALID_DELTA_MIN = "dropLifCfgInvalidDeltaMin"
    DROP_LIF_MAP_NO_HIT = "dropLifMapNoHit"
    DROP_LIF_MAP_NO_HIT_DELTA = "dropLifMapNoHitDelta"
    DROP_LIF_MAP_NO_HIT_DELTA_AVG = "dropLifMapNoHitDeltaAvg"
    DROP_LIF_MAP_NO_HIT_DELTA_MAX = "dropLifMapNoHitDeltaMax"
    DROP_LIF_MAP_NO_HIT_DELTA_MIN = "dropLifMapNoHitDeltaMin"
    DROP_NULL_PIF = "dropNullPif"
    DROP_NULL_PIF_DELTA = "dropNullPifDelta"
    DROP_NULL_PIF_DELTA_AVG = "dropNullPifDeltaAvg"
    DROP_NULL_PIF_DELTA_MAX = "dropNullPifDeltaMax"
    DROP_NULL_PIF_DELTA_MIN = "dropNullPifDeltaMin"
    DROP_OVERRUN = "dropOverrun"
    DROP_OVERRUN_DELTA = "dropOverrunDelta"
    DROP_OVERRUN_DELTA_AVG = "dropOverrunDeltaAvg"
    DROP_OVERRUN_DELTA_MAX = "dropOverrunDeltaMax"
    DROP_OVERRUN_DELTA_MIN = "dropOverrunDeltaMin"
    DROP_OVERRUN_N0 = "dropOverrunN0"
    DROP_OVERRUN_N0_DELTA = "dropOverrunN0Delta"
    DROP_OVERRUN_N0_DELTA_AVG = "dropOverrunN0DeltaAvg"
    DROP_OVERRUN_N0_DELTA_MAX = "dropOverrunN0DeltaMax"
    DROP_OVERRUN_N0_DELTA_MIN = "dropOverrunN0DeltaMin"
    DROP_OVERRUN_N1 = "dropOverrunN1"
    DROP_OVERRUN_N1_DELTA = "dropOverrunN1Delta"
    DROP_OVERRUN_N1_DELTA_AVG = "dropOverrunN1DeltaAvg"
    DROP_OVERRUN_N1_DELTA_MAX = "dropOverrunN1DeltaMax"
    DROP_OVERRUN_N1_DELTA_MIN = "dropOverrunN1DeltaMin"
    DROP_RUNT = "dropRunt"
    DROP_RUNT_DELTA = "dropRuntDelta"
    DROP_RUNT_DELTA_AVG = "dropRuntDeltaAvg"
    DROP_RUNT_DELTA_MAX = "dropRuntDeltaMax"
    DROP_RUNT_DELTA_MIN = "dropRuntDeltaMin"
    DROP_SRC_BIND = "dropSrcBind"
    DROP_SRC_BIND_DELTA = "dropSrcBindDelta"
    DROP_SRC_BIND_DELTA_AVG = "dropSrcBindDeltaAvg"
    DROP_SRC_BIND_DELTA_MAX = "dropSrcBindDeltaMax"
    DROP_SRC_BIND_DELTA_MIN = "dropSrcBindDeltaMin"
    DROPPED_RX = "droppedRx"
    DROPPED_RX_DELTA = "droppedRxDelta"
    DROPPED_RX_DELTA_AVG = "droppedRxDeltaAvg"
    DROPPED_RX_DELTA_MAX = "droppedRxDeltaMax"
    DROPPED_RX_DELTA_MIN = "droppedRxDeltaMin"
    DROPPED_TX = "droppedTx"
    DROPPED_TX_DELTA = "droppedTxDelta"
    DROPPED_TX_DELTA_AVG = "droppedTxDeltaAvg"
    DROPPED_TX_DELTA_MAX = "droppedTxDeltaMax"
    DROPPED_TX_DELTA_MIN = "droppedTxDeltaMin"
    DST_DN = "dstDn"
    DUAL_STACK = "dualStack"
    DUMPED_FRAMES = "dumpedFrames"
    DUMPED_FRAMES_DELTA = "dumpedFramesDelta"
    DUMPED_FRAMES_DELTA_AVG = "dumpedFramesDeltaAvg"
    DUMPED_FRAMES_DELTA_MAX = "dumpedFramesDeltaMax"
    DUMPED_FRAMES_DELTA_MIN = "dumpedFramesDeltaMin"
    DUPLICATE_TARGET = "duplicateTarget"
    DVS_GEN_PORT_ID = "dvsGenPortId"
    DVS_PORT_ID = "dvsPortId"
    DVS_SWITCH_ID = "dvsSwitchId"
    DYN_REALLOC = "dynRealloc"
    DYNAMIC_CON_POLICY_NAME = "dynamicConPolicyName"
    DYNAMIC_ETH = "dynamicEth"
    DYNAMIC_ID = "dynamicId"
    ECC_MULTIBIT_ERRORS = "eccMultibitErrors"
    ECC_MULTIBIT_ERRORS_AVG = "eccMultibitErrorsAvg"
    ECC_MULTIBIT_ERRORS_MAX = "eccMultibitErrorsMax"
    ECC_MULTIBIT_ERRORS_MIN = "eccMultibitErrorsMin"
    ECC_MULTIBIT_ERRORS_RUNNING = "eccMultibitErrorsRunning"
    ECC_SINGLEBIT_ERRORS = "eccSinglebitErrors"
    ECC_SINGLEBIT_ERRORS_AVG = "eccSinglebitErrorsAvg"
    ECC_SINGLEBIT_ERRORS_MAX = "eccSinglebitErrorsMax"
    ECC_SINGLEBIT_ERRORS_MIN = "eccSinglebitErrorsMin"
    ECC_SINGLEBIT_ERRORS_RUNNING = "eccSinglebitErrorsRunning"
    ECODE = "ecode"
    ELID = "elid"
    EMAIL = "email"
    EMAIL_ADDR = "emailAddr"
    ENABLE_HAFAILOVER = "enableHAFailover"
    ENABLE_SSL = "enableSSL"
    ENABLE_STATE = "enableState"
    ENABLED = "enabled"
    ENC_ALGORITHM = "encAlgorithm"
    ENC_ASSOCIATION = "encAssociation"
    ENC_ID = "encId"
    ENC_KEY = "encKey"
    ENC_PASSWORD = "encPassword"
    ENC_PROXY_PWD = "encProxyPwd"
    ENC_PWD = "encPwd"
    ENCAP = "encap"
    ENCLOSURE_ID = "enclosureId"
    END_PORT_ID = "endPortId"
    END_REQUEST = "endRequest"
    END_TIME = "endTime"
    END_TS = "endTs"
    END_TS_M = "endTsM"
    ENDPOINT = "endpoint"
    ENFORCE_MODE = "enforceMode"
    ENFORCE_VNIC_NAME = "enforceVnicName"
    ENFORCEMENT_MODE = "enforcementMode"
    EP = "ep"
    EP_CLASS_ID = "epClassId"
    EP_DN = "epDn"
    EP_NAME = "epName"
    EP_POOL_CNT = "epPoolCnt"
    EQ_TYPE = "eqType"
    EQUALS64 = "equals64"
    EQUALS64_DELTA = "equals64Delta"
    EQUALS64_DELTA_AVG = "equals64DeltaAvg"
    EQUALS64_DELTA_MAX = "equals64DeltaMax"
    EQUALS64_DELTA_MIN = "equals64DeltaMin"
    EQUIPMENT_DN = "equipmentDn"
    EQUIPMENT_NAME = "equipmentName"
    EQUIPMENT_SCOPE_DN_CNT = "equipmentScopeDnCnt"
    EQUIPMENT_TYPE = "equipmentType"
    ERR_DESCRIPTION = "errDescription"
    ERR_FATAL_ERRORS = "errFatalErrors"
    ERR_FATAL_ERRORS_AVG = "errFatalErrorsAvg"
    ERR_FATAL_ERRORS_MAX = "errFatalErrorsMax"
    ERR_FATAL_ERRORS_MIN = "errFatalErrorsMin"
    ERR_FATAL_ERRORS_RUNNING = "errFatalErrorsRunning"
    ERR_NON_FATAL_ERRORS = "errNonFatalErrors"
    ERR_NON_FATAL_ERRORS_AVG = "errNonFatalErrorsAvg"
    ERR_NON_FATAL_ERRORS_MAX = "errNonFatalErrorsMax"
    ERR_NON_FATAL_ERRORS_MIN = "errNonFatalErrorsMin"
    ERR_NON_FATAL_ERRORS_RUNNING = "errNonFatalErrorsRunning"
    ERR_VAL = "errVal"
    ERR_VALUE = "errValue"
    ERROR_CODE = "errorCode"
    ERROR_CORRECTION = "errorCorrection"
    ERROR_DESC = "errorDesc"
    ERROR_DESCR = "errorDescr"
    ERROR_DETECT_TIMEOUT = "errorDetectTimeout"
    ERROR_FRAMES = "errorFrames"
    ERROR_FRAMES_DELTA = "errorFramesDelta"
    ERROR_FRAMES_DELTA_AVG = "errorFramesDeltaAvg"
    ERROR_FRAMES_DELTA_MAX = "errorFramesDeltaMax"
    ERROR_FRAMES_DELTA_MIN = "errorFramesDeltaMin"
    ERROR_LOCATION = "errorLocation"
    ERROR_MSG = "errorMsg"
    ERROR_TYPE = "errorType"
    ERROR_VALUES = "errorValues"
    ERRORS_RX = "errorsRx"
    ERRORS_RX_DELTA = "errorsRxDelta"
    ERRORS_RX_DELTA_AVG = "errorsRxDeltaAvg"
    ERRORS_RX_DELTA_MAX = "errorsRxDeltaMax"
    ERRORS_RX_DELTA_MIN = "errorsRxDeltaMin"
    ERRORS_TX = "errorsTx"
    ERRORS_TX_DELTA = "errorsTxDelta"
    ERRORS_TX_DELTA_AVG = "errorsTxDeltaAvg"
    ERRORS_TX_DELTA_MAX = "errorsTxDeltaMax"
    ERRORS_TX_DELTA_MIN = "errorsTxDeltaMin"
    ESCALATING = "escalating"
    EST_PROG_WEIGHT = "estProgWeight"
    ETH_BREAKOUT_AUTO_DISCOVERY = "ethBreakoutAutoDiscovery"
    ETH_EP_DN = "ethEpDn"
    ETH_LINK_PROFILE_NAME = "ethLinkProfileName"
    ETH_SVR_AUTO_DISCOVERY = "ethSvrAutoDiscovery"
    ETHER_TYPE = "etherType"
    EVACUATE = "evacuate"
    EVAL_EXPIRED_TIME = "evalExpiredTime"
    EVAL_IN_USE = "evalInUse"
    EVAL_PERIOD_LEFT = "evalPeriodLeft"
    EVALUTION_STATE = "evalutionState"
    EVENTS = "events"
    EXCESS_COLLISION = "excessCollision"
    EXCESS_COLLISION_DELTA = "excessCollisionDelta"
    EXCESS_COLLISION_DELTA_AVG = "excessCollisionDeltaAvg"
    EXCESS_COLLISION_DELTA_MAX = "excessCollisionDeltaMax"
    EXCESS_COLLISION_DELTA_MIN = "excessCollisionDeltaMin"
    EXCLUDE_BY_DEFAULT = "excludeByDefault"
    EXP = "exp"
    EXP_MOD_ID = "expModId"
    EXPAND_INFO = "expandInfo"
    EXPAND_TO_AVAIL = "expandToAvail"
    EXPANDED_ADDR = "expandedAddr"
    EXPANDER_SLOT = "expanderSlot"
    EXPANDER_STATE = "expanderState"
    EXPECTED_MEMORY = "expectedMemory"
    EXPIRATION = "expiration"
    EXPIRATION_WARN_TIME = "expirationWarnTime"
    EXPIRE_TIME = "expireTime"
    EXPIRES = "expires"
    EXPORT_CONTROLLED_ALLOWED = "exportControlledAllowed"
    EXT_BROADCAST = "extBroadcast"
    EXT_DEP = "extDep"
    EXT_GW = "extGw"
    EXT_IPPOOL_NAME = "extIPPoolName"
    EXT_IPSTATE = "extIPState"
    EXT_IP = "extIp"
    EXT_MASK = "extMask"
    EXT_MGMT_IP_ADDR = "extMgmtIpAddr"
    EXT_PHY_PORT_BITMASK = "extPhyPortBitmask"
    EXTERNAL_RESOLVE_NAME = "externalResolveName"
    FAB_EXT_ID = "fabExtId"
    FABRIC = "fabric"
    FABRIC_ID = "fabricId"
    FABRIC_INTERCONNECT_DN = "fabricInterconnectDn"
    FABRIC_INTERCONNECT_MODEL = "fabricInterconnectModel"
    FAILED = "failed"
    FAILURE_ACTION = "failureAction"
    FAMILY = "family"
    FAMILY_NAME = "familyName"
    FAN_CTRLR_INLET1 = "fanCtrlrInlet1"
    FAN_CTRLR_INLET1_AVG = "fanCtrlrInlet1Avg"
    FAN_CTRLR_INLET1_MAX = "fanCtrlrInlet1Max"
    FAN_CTRLR_INLET1_MIN = "fanCtrlrInlet1Min"
    FAN_CTRLR_INLET2 = "fanCtrlrInlet2"
    FAN_CTRLR_INLET2_AVG = "fanCtrlrInlet2Avg"
    FAN_CTRLR_INLET2_MAX = "fanCtrlrInlet2Max"
    FAN_CTRLR_INLET2_MIN = "fanCtrlrInlet2Min"
    FAN_CTRLR_INLET3 = "fanCtrlrInlet3"
    FAN_CTRLR_INLET3_AVG = "fanCtrlrInlet3Avg"
    FAN_CTRLR_INLET3_MAX = "fanCtrlrInlet3Max"
    FAN_CTRLR_INLET3_MIN = "fanCtrlrInlet3Min"
    FAN_CTRLR_INLET4 = "fanCtrlrInlet4"
    FAN_CTRLR_INLET4_AVG = "fanCtrlrInlet4Avg"
    FAN_CTRLR_INLET4_MAX = "fanCtrlrInlet4Max"
    FAN_CTRLR_INLET4_MIN = "fanCtrlrInlet4Min"
    FAN_SPEED = "fanSpeed"
    FAN_SPEED_POLICY_ADMIN_STATE = "fanSpeedPolicyAdminState"
    FAN_SPEED_POLICY_OPER_STATE = "fanSpeedPolicyOperState"
    FAST_TIMER = "fastTimer"
    FAULT_CODE = "faultCode"
    FAULT_DESCR = "faultDescr"
    FAULT_LEVEL = "faultLevel"
    FAULT_MONITORING = "faultMonitoring"
    FAULT_QUALIFIER = "faultQualifier"
    FAULTS = "faults"
    FAVORITES = "favorites"
    FC_ZONE_SHARING_MODE = "fcZoneSharingMode"
    FCOE_ID = "fcoeId"
    FCOE_STATE = "fcoeState"
    FCOE_STATE_REASON = "fcoeStateReason"
    FCOE_VLAN = "fcoeVlan"
    FCP_ERROR_RECOVERY = "fcpErrorRecovery"
    FCS = "fcs"
    FCS_DELTA = "fcsDelta"
    FCS_DELTA_AVG = "fcsDeltaAvg"
    FCS_DELTA_MAX = "fcsDeltaMax"
    FCS_DELTA_MIN = "fcsDeltaMin"
    FE_OFFLINE_TS = "feOfflineTs"
    FE_READY_TS = "feReadyTs"
    FEAT_MASK = "featMask"
    FEATURE = "feature"
    FEATURE_MASK = "featureMask"
    FEATURE_NAME = "featureName"
    FEATURE_TOUR_DISABLED = "featureTourDisabled"
    FEX_DN = "fexDn"
    FI_ID = "fiId"
    FILE_CREATE_DATE = "fileCreateDate"
    FILE_DESCRIPTION = "fileDescription"
    FILE_DIR = "fileDir"
    FILE_HOST = "fileHost"
    FILE_NAME = "fileName"
    FILE_PASSWD = "filePasswd"
    FILE_PATH = "filePath"
    FILE_PORT = "filePort"
    FILE_PROTO = "fileProto"
    FILE_SKU = "fileSku"
    FILE_TRANSFER_PROTO = "fileTransferProto"
    FILE_USER = "fileUser"
    FILENAME = "filename"
    FILL_PATTERN = "fillPattern"
    FILTER = "filter"
    FILTER_CLASS_ID = "filterClassId"
    FILTER_PROP_ID1 = "filterPropId1"
    FILTER_PROP_ID2 = "filterPropId2"
    FILTER_PROP_ID3 = "filterPropId3"
    FILTER_PROP_VALUE1 = "filterPropValue1"
    FILTER_PROP_VALUE2 = "filterPropValue2"
    FILTER_PROP_VALUE3 = "filterPropValue3"
    FIRMWARE = "firmware"
    FIRMWARE_OPER_STATE = "firmwareOperState"
    FIRMWARE_VERSION = "firmwareVersion"
    FIRST_NAME = "firstName"
    FIRST_SLOT_IDX = "firstSlotIdx"
    FLAGS = "flags"
    FLAP_INTERVAL = "flapInterval"
    FLASH_PERCENTAGE = "flashPercentage"
    FLASH_STATUS = "flashStatus"
    FLEX_FLASH_RAIDREPORTING_STATE = "flexFlashRAIDReportingState"
    FLEX_FLASH_SCRUB = "flexFlashScrub"
    FLEX_FLASH_STATE = "flexFlashState"
    FLEX_FLASH_TYPE = "flexFlashType"
    FLEX_STORAGE_SCRUB = "flexStorageScrub"
    FLG_INITIAL_ACTIVE = "flgInitialActive"
    FLOW_CONTROL_ERRORS = "flowControlErrors"
    FLOW_CONTROL_ERRORS_AVG = "flowControlErrorsAvg"
    FLOW_CONTROL_ERRORS_MAX = "flowControlErrorsMax"
    FLOW_CONTROL_ERRORS_MIN = "flowControlErrorsMin"
    FLOW_CONTROL_ERRORS_RUNNING = "flowControlErrorsRunning"
    FLOW_CTRL_POLICY = "flowCtrlPolicy"
    FLT_AGGR = "fltAggr"
    FM_TEMP_SEN_IO = "fmTempSenIo"
    FM_TEMP_SEN_IO_AVG = "fmTempSenIoAvg"
    FM_TEMP_SEN_IO_MAX = "fmTempSenIoMax"
    FM_TEMP_SEN_IO_MIN = "fmTempSenIoMin"
    FM_TEMP_SEN_REAR = "fmTempSenRear"
    FM_TEMP_SEN_REAR_AVG = "fmTempSenRearAvg"
    FM_TEMP_SEN_REAR_L = "fmTempSenRearL"
    FM_TEMP_SEN_REAR_LAVG = "fmTempSenRearLAvg"
    FM_TEMP_SEN_REAR_LMAX = "fmTempSenRearLMax"
    FM_TEMP_SEN_REAR_LMIN = "fmTempSenRearLMin"
    FM_TEMP_SEN_REAR_MAX = "fmTempSenRearMax"
    FM_TEMP_SEN_REAR_MIN = "fmTempSenRearMin"
    FM_TEMP_SEN_REAR_R = "fmTempSenRearR"
    FM_TEMP_SEN_REAR_RAVG = "fmTempSenRearRAvg"
    FM_TEMP_SEN_REAR_RMAX = "fmTempSenRearRMax"
    FM_TEMP_SEN_REAR_RMIN = "fmTempSenRearRMin"
    FONT_SIZE = "fontSize"
    FORCE_DEPLOY = "forceDeploy"
    FORCE_ESTIMATE_IMPACT = "forceEstimateImpact"
    FORCE_EVAC = "forceEvac"
    FORCE_REGISTER = "forceRegister"
    FORCE_UPDATE_VERSION = "forceUpdateVersion"
    FORGE = "forge"
    FORGE_MAC = "forgeMac"
    FORM = "form"
    FORM_FACTOR = "formFactor"
    FORMAT = "format"
    FORWARDING_FACILITY = "forwardingFacility"
    FP = "fp"
    FRACTIONAL_SIZE = "fractionalSize"
    FREE_SPACE = "freeSpace"
    FROM = "from"
    FROM_VNIC_TEMPLATE_DN = "fromVnicTemplateDn"
    FRONT_TEMP = "frontTemp"
    FRONT_TEMP_AVG = "frontTempAvg"
    FRONT_TEMP_MAX = "frontTempMax"
    FRONT_TEMP_MIN = "frontTempMin"
    FRU_CAP_DN = "fruCapDn"
    FRU_IDENT_TRIG_TS = "fruIdentTrigTs"
    FRU_MAJOR_TYPE = "fruMajorType"
    FRU_MINOR_TYPE = "fruMinorType"
    FSM_DESCR = "fsmDescr"
    FSM_FLAGS = "fsmFlags"
    FSM_INSTANCE_ID = "fsmInstanceId"
    FSM_PREV = "fsmPrev"
    FSM_PROGR = "fsmProgr"
    FSM_RMT_INV_ERR_CODE = "fsmRmtInvErrCode"
    FSM_RMT_INV_ERR_DESCR = "fsmRmtInvErrDescr"
    FSM_RMT_INV_RSLT = "fsmRmtInvRslt"
    FSM_STAGE = "fsmStage"
    FSM_STAGE_DESCR = "fsmStageDescr"
    FSM_STAMP = "fsmStamp"
    FSM_STATUS = "fsmStatus"
    FSM_TRY = "fsmTry"
    FUNCTIONAL_STATE = "functionalState"
    FW_CURRENT_UPDATE_NAME = "fwCurrentUpdateName"
    FW_CURRENT_UPDATE_STATE = "fwCurrentUpdateState"
    FW_OPER_STATE = "fwOperState"
    FW_PACK_NAME = "fwPackName"
    FW_PACKAGE_VERSION = "fwPackageVersion"
    FW_REGION_ONE = "fwRegionOne"
    FW_REGION_TWO = "fwRegionTwo"
    FW_RUNNING_REGION = "fwRunningRegion"
    FW_SERVICE_PACK_VERSION = "fwServicePackVersion"
    FW_STATUS = "fwStatus"
    FW_VERSION = "fwVersion"
    FW_VERSION_HI = "fwVersionHi"
    FW_VERSION_LO = "fwVersionLo"
    FW_VERSION_OPR = "fwVersionOpr"
    FWD_LOOKUP_NO_HIT = "fwdLookupNoHit"
    FWD_LOOKUP_NO_HIT_DELTA = "fwdLookupNoHitDelta"
    FWD_LOOKUP_NO_HIT_DELTA_AVG = "fwdLookupNoHitDeltaAvg"
    FWD_LOOKUP_NO_HIT_DELTA_MAX = "fwdLookupNoHitDeltaMax"
    FWD_LOOKUP_NO_HIT_DELTA_MIN = "fwdLookupNoHitDeltaMin"
    GCH_DEBUG_LEVEL = "gchDebugLevel"
    GEN_NUM = "genNum"
    GEN_NUM_SYNC = "genNumSync"
    GEN_NUMBER = "genNumber"
    GENCOUNT = "gencount"
    GENERATED_TIME = "generatedTime"
    GENERATION = "generation"
    GIANTS = "giants"
    GIANTS_DELTA = "giantsDelta"
    GIANTS_DELTA_AVG = "giantsDeltaAvg"
    GIANTS_DELTA_MAX = "giantsDeltaMax"
    GIANTS_DELTA_MIN = "giantsDeltaMin"
    GID = "gid"
    GL_ACTION = "glAction"
    GL_ATTR_VALUE = "glAttrValue"
    GL_OPER_ACTION = "glOperAction"
    GL_OPER_ATTR_VALUE = "glOperAttrValue"
    GLOBAL = "global"
    GLOBAL_ASSIGNED_CNT = "globalAssignedCnt"
    GLOBAL_CP_DN = "globalCpDn"
    GLOBAL_DEFINED_CNT = "globalDefinedCnt"
    GLOBAL_LS_DN = "globalLsDn"
    GLOBAL_OPER_POOL_DN = "globalOperPoolDn"
    GLOBAL_PN_DN = "globalPnDn"
    GLOBAL_POOL_CNT = "globalPoolCnt"
    GLOBAL_POOL_DN = "globalPoolDn"
    GLOBAL_POOL_NAME = "globalPoolName"
    GLOBAL_TEMPLATE_NAME = "globalTemplateName"
    GLOBAL_TEMPLATE_ORG_DN = "globalTemplateOrgDn"
    GLOBALIZATION_STATE = "globalizationState"
    GLOBALIZE_ADMIN_STATE = "globalizeAdminState"
    GLOBALIZED_DN = "globalizedDn"
    GOOD_PACKETS = "goodPackets"
    GOOD_PACKETS_DELTA = "goodPacketsDelta"
    GOOD_PACKETS_DELTA_AVG = "goodPacketsDeltaAvg"
    GOOD_PACKETS_DELTA_MAX = "goodPacketsDeltaMax"
    GOOD_PACKETS_DELTA_MIN = "goodPacketsDeltaMin"
    GRACE_PERIOD = "gracePeriod"
    GRACE_PERIOD_USED = "gracePeriodUsed"
    GRAPHICS_CARD_MODE = "graphicsCardMode"
    GRAPHICS_CARD_POLICY_NAME = "graphicsCardPolicyName"
    GREATER_THAN_OR_EQUAL_TO9216 = "greaterThanOrEqualTo9216"
    GREATER_THAN_OR_EQUAL_TO9216_DELTA = "greaterThanOrEqualTo9216Delta"
    GREATER_THAN_OR_EQUAL_TO9216_DELTA_AVG = "greaterThanOrEqualTo9216DeltaAvg"
    GREATER_THAN_OR_EQUAL_TO9216_DELTA_MAX = "greaterThanOrEqualTo9216DeltaMax"
    GREATER_THAN_OR_EQUAL_TO9216_DELTA_MIN = "greaterThanOrEqualTo9216DeltaMin"
    GROUP = "group"
    GROUP_DN = "groupDn"
    GROUP_NAME = "groupName"
    GROUP_POLICY_NAME = "groupPolicyName"
    GUID = "guid"
    GW_ADDR = "gwAddr"
    GW_SUBNET = "gwSubnet"
    HA = "ha"
    HA_FAILURE_REASON = "haFailureReason"
    HA_PEER_DN = "haPeerDn"
    HA_READINESS = "haReadiness"
    HA_READY = "haReady"
    HA_STATE = "haState"
    HA_STATE_REASON = "haStateReason"
    HAS_ERROR = "hasError"
    HBA_MODE = "hbaMode"
    HEALTH = "health"
    HEALTH_LED_STATE = "healthLedState"
    HEALTH_LED_STATE_QUALIFIER = "healthLedStateQualifier"
    HEARTBEAT_STATUS = "heartbeatStatus"
    HIERARCHICAL = "hierarchical"
    HIGH_SPEED = "highSpeed"
    HIGHEST_SEVERITY = "highestSeverity"
    HISTORY_COUNT = "historyCount"
    HONOR_LS_MAINT_POLICY = "honorLsMaintPolicy"
    HOST = "host"
    HOST_CONTROL = "hostControl"
    HOST_FIRMWARE_POLICY_DN = "hostFirmwarePolicyDn"
    HOST_FW_POLICY_NAME = "hostFwPolicyName"
    HOST_ID = "hostId"
    HOST_IF_DN = "hostIfDn"
    HOST_NAME = "hostName"
    HOST_NAME_OR_IP = "hostNameOrIP"
    HOST_PORT = "hostPort"
    HOST_VISIBLE = "hostVisible"
    HOSTNAME = "hostname"
    HOUR = "hour"
    HOURLY_RECORDS = "hourlyRecords"
    HTTP_PROXY = "httpProxy"
    HTTP_URL = "httpURL"
    HW_CHANGE_DISC_POLICY_NAME = "hwChangeDiscPolicyName"
    HW_INVENTORY_STATUS = "hwInventoryStatus"
    HW_MODEL = "hwModel"
    HW_REVISION = "hwRevision"
    HW_VENDOR = "hwVendor"
    I_SCSIVNIC_NAME = "iSCSIVnicName"
    ID = "id"
    ID_COUNT = "idCount"
    ID_RELEASED_TIME = "idReleasedTime"
    ID_TOKEN = "idToken"
    IDCERTIFICATE = "idcertificate"
    IDENT_POOL_NAME = "identPoolName"
    IDENT_TYPE = "identType"
    IDENTITY = "identity"
    IDLE_POWER = "idlePower"
    IF_ROLE = "ifRole"
    IF_TYPE = "ifType"
    IGNORE_CAP = "ignoreCap"
    IGNORE_COMP_CHECK = "ignoreCompCheck"
    IMAGE = "image"
    IMAGE_FILE_NAME = "imageFileName"
    IMAGE_GUID = "imageGuid"
    IMAGE_NAME_VARIABLE = "imageNameVariable"
    IMAGE_PAGE_INDEX = "imagePageIndex"
    IMAGE_PATH = "imagePath"
    IMAGE_SIZE = "imageSize"
    IMAGE_URL = "imageUrl"
    IMG_POLICY_NAME = "imgPolicyName"
    IMG_SEC_POLICY_NAME = "imgSecPolicyName"
    IMPACT_ANALYZER_DN = "impactAnalyzerDn"
    IMPACT_ANALYZER_ID = "impactAnalyzerId"
    IMPORT_ALL = "importAll"
    IMPORT_METHOD = "importMethod"
    IMPORTED_NAME = "importedName"
    IN_USE = "inUse"
    INBAND_IF_GW = "inbandIfGw"
    INBAND_IF_IP = "inbandIfIp"
    INBAND_IF_MASK = "inbandIfMask"
    INBAND_IF_VNET = "inbandIfVnet"
    INBAND_POLICY_DN = "inbandPolicyDn"
    INBAND_POLICY_NAME = "inbandPolicyName"
    IND = "ind"
    INDEX = "index"
    INFRA_BUNDLE_NAME = "infraBundleName"
    INFRA_BUNDLE_VERSION = "infraBundleVersion"
    INFRA_PROFILE_STATUS = "infraProfileStatus"
    INFRA_VERSION = "infraVersion"
    INI_NAME = "iniName"
    INIT_NAME_SUFFIX = "initNameSuffix"
    INIT_SEQ = "initSeq"
    INIT_TS = "initTs"
    INITIALIZATION_STATE = "initializationState"
    INITIATOR = "initiator"
    INITIATOR_DN = "initiatorDn"
    INITIATOR_NAME = "initiatorName"
    INLET = "inlet"
    INLET1 = "inlet1"
    INLET1_AVG = "inlet1Avg"
    INLET1_MAX = "inlet1Max"
    INLET1_MIN = "inlet1Min"
    INLET_AVG = "inletAvg"
    INLET_MAX = "inletMax"
    INLET_MIN = "inletMin"
    INO = "ino"
    INPUT210V = "input210v"
    INPUT210V_AVG = "input210vAvg"
    INPUT210V_MAX = "input210vMax"
    INPUT210V_MIN = "input210vMin"
    INPUT_CONFIG_STATUS = "inputConfigStatus"
    INPUT_CURRENT = "inputCurrent"
    INPUT_CURRENT_AVG = "inputCurrentAvg"
    INPUT_CURRENT_MAX = "inputCurrentMax"
    INPUT_CURRENT_MIN = "inputCurrentMin"
    INPUT_MEGABYTES = "inputMegabytes"
    INPUT_MEGABYTES_DELTA = "inputMegabytesDelta"
    INPUT_MEGABYTES_DELTA_AVG = "inputMegabytesDeltaAvg"
    INPUT_MEGABYTES_DELTA_MAX = "inputMegabytesDeltaMax"
    INPUT_MEGABYTES_DELTA_MIN = "inputMegabytesDeltaMin"
    INPUT_NAME = "inputName"
    INPUT_POWER = "inputPower"
    INPUT_POWER_AVG = "inputPowerAvg"
    INPUT_POWER_MAX = "inputPowerMax"
    INPUT_POWER_MIN = "inputPowerMin"
    INPUT_REQUESTS = "inputRequests"
    INPUT_REQUESTS_DELTA = "inputRequestsDelta"
    INPUT_REQUESTS_DELTA_AVG = "inputRequestsDeltaAvg"
    INPUT_REQUESTS_DELTA_MAX = "inputRequestsDeltaMax"
    INPUT_REQUESTS_DELTA_MIN = "inputRequestsDeltaMin"
    INPUT_STATUS = "inputStatus"
    INPUT_VOLTAGE = "inputVoltage"
    INPUT_VOLTAGE_AVG = "inputVoltageAvg"
    INPUT_VOLTAGE_MAX = "inputVoltageMax"
    INPUT_VOLTAGE_MIN = "inputVoltageMin"
    INST_ID = "instId"
    INST_TYPE = "instType"
    INSTANCE = "instance"
    INSTANCE_DN = "instanceDn"
    INSTANCE_TYPE = "instanceType"
    INSTANTIATION_STATE = "instantiationState"
    INT_DEL = "intDel"
    INT_ID = "intId"
    INT_MAC_RX = "intMacRx"
    INT_MAC_RX_DELTA = "intMacRxDelta"
    INT_MAC_RX_DELTA_AVG = "intMacRxDeltaAvg"
    INT_MAC_RX_DELTA_MAX = "intMacRxDeltaMax"
    INT_MAC_RX_DELTA_MIN = "intMacRxDeltaMin"
    INT_MAC_TX = "intMacTx"
    INT_MAC_TX_DELTA = "intMacTxDelta"
    INT_MAC_TX_DELTA_AVG = "intMacTxDeltaAvg"
    INT_MAC_TX_DELTA_MAX = "intMacTxDeltaMax"
    INT_MAC_TX_DELTA_MIN = "intMacTxDeltaMin"
    INT_TYPE = "intType"
    INTEGRATED = "integrated"
    INTENT = "intent"
    INTEREST = "interest"
    INTERNAL_ID = "internalId"
    INTERNAL_NAME = "internalName"
    INTERNALPORTS = "internalports"
    INTERVAL = "interval"
    INTERVAL_DAYS = "intervalDays"
    INTERVALS = "intervals"
    INTR_COUNT = "intrCount"
    INV_DN = "invDn"
    INV_TAG = "invTag"
    INVALID_CRCCOUNT = "invalidCRCCount"
    INVALID_CRCCOUNT_DELTA = "invalidCRCCountDelta"
    INVALID_CRCCOUNT_DELTA_AVG = "invalidCRCCountDeltaAvg"
    INVALID_CRCCOUNT_DELTA_MAX = "invalidCRCCountDeltaMax"
    INVALID_CRCCOUNT_DELTA_MIN = "invalidCRCCountDeltaMin"
    INVENTORY_STATUS = "inventoryStatus"
    INVENTORY_TRIG_STATE = "inventoryTrigState"
    IO_POLICY = "ioPolicy"
    IO_RETRY_TIMEOUT = "ioRetryTimeout"
    IO_THROTTLE_COUNT = "ioThrottleCount"
    IOH1_TEMP = "ioh1Temp"
    IOH1_TEMP_AVG = "ioh1TempAvg"
    IOH1_TEMP_MAX = "ioh1TempMax"
    IOH1_TEMP_MIN = "ioh1TempMin"
    IOH2_TEMP = "ioh2Temp"
    IOH2_TEMP_AVG = "ioh2TempAvg"
    IOH2_TEMP_MAX = "ioh2TempMax"
    IOH2_TEMP_MIN = "ioh2TempMin"
    IOPS = "iops"
    IOPS_AVG = "iopsAvg"
    IOPS_MAX = "iopsMax"
    IOPS_MIN = "iopsMin"
    IP = "ip"
    IP_A = "ipA"
    IP_ADDR_TYPE = "ipAddrType"
    IP_ADDRESS = "ipAddress"
    IP_B = "ipB"
    IP_HASH = "ipHash"
    IP_URL = "ipUrl"
    IP_V4_STATE = "ipV4State"
    IP_V6_STATE = "ipV6State"
    IPMI_OVER_LAN = "ipmiOverLan"
    IPV4 = "ipv4"
    IPV6 = "ipv6"
    IPV6_A = "ipv6A"
    IPV6_ADDR = "ipv6Addr"
    IPV6_B = "ipv6B"
    IPV6_TARGET1 = "ipv6Target1"
    IPV6_TARGET2 = "ipv6Target2"
    IPV6_TARGET3 = "ipv6Target3"
    IPV6ADDR = "ipv6addr"
    IPV6SERVER = "ipv6server"
    IQN = "iqn"
    IQN_IDENT_POOL_NAME = "iqnIdentPoolName"
    IS_ASSIGNED = "isAssigned"
    IS_BLOCK = "isBlock"
    IS_BOOTABLE = "isBootable"
    IS_BREAKOUT_XCVR = "isBreakoutXcvr"
    IS_CARD_MISMATCH = "isCardMismatch"
    IS_CHANGED_OBJECT_UPDATE = "isChangedObjectUpdate"
    IS_COMPLEX_POLICY = "isComplexPolicy"
    IS_CONFIG_SUCCESS = "isConfigSuccess"
    IS_DEFAULT_DERIVED = "isDefaultDerived"
    IS_DELETED = "isDeleted"
    IS_EXCLUDE_DATA = "isExcludeData"
    IS_FIRST_SYNC = "isFirstSync"
    IS_FORMAT_FSMRUNNING = "isFormatFSMRunning"
    IS_FROM_GLOBAL_POOL = "isFromGlobalPool"
    IS_HA = "isHA"
    IS_HIDDEN = "isHidden"
    IS_IMPLICIT = "isImplicit"
    IS_IMPORTABLE = "isImportable"
    IS_NATIVE = "isNative"
    IS_PINNING_CLEARED = "isPinningCleared"
    IS_PORT_CHANNEL_MEMBER = "isPortChannelMember"
    IS_PRESENT = "isPresent"
    IS_REFERENCE_GLOBAL_POOL = "isReferenceGlobalPool"
    IS_RENAME = "isRename"
    IS_RENAMEABLE = "isRenameable"
    IS_RESOURCE_IMPORTED = "isResourceImported"
    IS_SERVER_POOL_ASSIGNED = "isServerPoolAssigned"
    IS_SERVICE_TEMPLATE = "isServiceTemplate"
    IS_SHARED_IOMODULE = "isSharedIOModule"
    IS_SRC_TEMPLATE = "isSrcTemplate"
    IS_STATIC_ID = "isStaticId"
    IS_STORAGE_CONTROLLER = "isStorageController"
    IS_SUPPORTED = "isSupported"
    IS_SYNC = "isSync"
    IS_SYNC_ALLOWED = "isSyncAllowed"
    IS_SYSTEM = "isSystem"
    IS_USER_ACTIONABLE = "isUserActionable"
    ISCSI_CONFIG_ISSUES = "iscsiConfigIssues"
    ISONAME = "isoname"
    ISSUE = "issue"
    ISSUE_TYPE = "issueType"
    ISSUES = "issues"
    ITEM = "item"
    ITEM_DN = "itemDn"
    ITEM_ERROR_CODE = "itemErrorCode"
    ITEM_ID = "itemId"
    ITEM_NAME = "itemName"
    ITEM_NOTE = "itemNote"
    ITEM_PROTOCOL = "itemProtocol"
    ITEM_REF_DN = "itemRefDn"
    ITEM_REF_ID = "itemRefId"
    ITEM_REF_MODEL = "itemRefModel"
    ITEM_STATUS = "itemStatus"
    ITEM_VENDOR = "itemVendor"
    ITEM_VERSION = "itemVersion"
    JOB = "job"
    JOB_COUNT = "jobCount"
    JUMBO_PACKETS = "jumboPackets"
    JUMBO_PACKETS_DELTA = "jumboPacketsDelta"
    JUMBO_PACKETS_DELTA_AVG = "jumboPacketsDeltaAvg"
    JUMBO_PACKETS_DELTA_MAX = "jumboPacketsDeltaMax"
    JUMBO_PACKETS_DELTA_MIN = "jumboPacketsDeltaMin"
    KERNEL_NAME = "kernelName"
    KERNEL_RELEASE = "kernelRelease"
    KERNEL_VERSION = "kernelVersion"
    KEY = "key"
    KEY_DN = "keyDn"
    KEY_RING = "keyRing"
    KEY_SET = "keySet"
    KEYRING_CERT = "keyringCert"
    KMIP_CERTIFICATE_POLICY_NAME = "kmipCertificatePolicyName"
    KMIP_FAULT = "kmipFault"
    KMIP_FAULT_DESCRIPTION = "kmipFaultDescription"
    KVM_MGMT_POLICY_NAME = "kvmMgmtPolicyName"
    LABEL = "label"
    LACP_POLICY_NAME = "lacpPolicyName"
    LAN_CONN_POLICY_NAME = "lanConnPolicyName"
    LANGUAGE = "language"
    LARGE_RECEIVE = "largeReceive"
    LAST_BACKUP = "lastBackup"
    LAST_DB_STATUS = "lastDbStatus"
    LAST_DEADLINE = "lastDeadline"
    LAST_DOWNLOAD = "lastDownload"
    LAST_ENABLED_TS = "lastEnabledTs"
    LAST_ENTITLEMENT_RENEWED = "lastEntitlementRenewed"
    LAST_ID_CERTIFICATE_RENEWED = "lastIdCertificateRenewed"
    LAST_MODIFIED = "lastModified"
    LAST_NAME = "lastName"
    LAST_OPERATION = "lastOperation"
    LAST_PIN_TIME = "lastPinTime"
    LAST_POLL_TS = "lastPollTs"
    LAST_POLLED_TS = "lastPolledTs"
    LAST_REFRESHED_TS = "lastRefreshedTs"
    LAST_REPORTED_COUNTER = "lastReportedCounter"
    LAST_SNAPSHOT_ID = "lastSnapshotId"
    LAST_SUBSCRIBED_TS = "lastSubscribedTs"
    LAST_TRANSITION = "lastTransition"
    LAST_UPDATE = "lastUpdate"
    LAST_UPDATE_TIME = "lastUpdateTime"
    LATE_COLLISION = "lateCollision"
    LATE_COLLISION_DELTA = "lateCollisionDelta"
    LATE_COLLISION_DELTA_AVG = "lateCollisionDeltaAvg"
    LATE_COLLISION_DELTA_MAX = "lateCollisionDeltaMax"
    LATE_COLLISION_DELTA_MIN = "lateCollisionDeltaMin"
    LATENCY = "latency"
    LATENCY_AVG = "latencyAvg"
    LATENCY_MAX = "latencyMax"
    LATENCY_MIN = "latencyMin"
    LATEST_SEND_TIME = "latestSendTime"
    LATEST_UPDATE_TIME = "latestUpdateTime"
    LC = "lc"
    LC_CTRL_STATE = "lcCtrlState"
    LC_NAME = "lcName"
    LC_TS = "lcTs"
    LEAD_ID_FOR_AUTO_INSTALL = "leadIdForAutoInstall"
    LEADERSHIP = "leadership"
    LEAF_LSP_DN = "leafLspDn"
    LEAF_ORG_DN = "leafOrgDn"
    LEARN_CYCLE_REQUESTED = "learnCycleRequested"
    LEARN_MODE = "learnMode"
    LEARN_REQ_DROP = "learnReqDrop"
    LEARN_REQ_DROP_DELTA = "learnReqDropDelta"
    LEARN_REQ_DROP_DELTA_AVG = "learnReqDropDeltaAvg"
    LEARN_REQ_DROP_DELTA_MAX = "learnReqDropDeltaMax"
    LEARN_REQ_DROP_DELTA_MIN = "learnReqDropDeltaMin"
    LEFT_INLET_TEMP = "leftInletTemp"
    LEFT_INLET_TEMP_AVG = "leftInletTempAvg"
    LEFT_INLET_TEMP_MAX = "leftInletTempMax"
    LEFT_INLET_TEMP_MIN = "leftInletTempMin"
    LEFT_OUTLET_TEMP = "leftOutletTemp"
    LEFT_OUTLET_TEMP_AVG = "leftOutletTempAvg"
    LEFT_OUTLET_TEMP_MAX = "leftOutletTempMax"
    LEFT_OUTLET_TEMP_MIN = "leftOutletTempMin"
    LEGACY_PROP_ID = "legacyPropId"
    LEGACY_PROP_VAL = "legacyPropVal"
    LEGACY_TO_ADVANCED_BOOT_ORDER_UPDATE = "legacyToAdvancedBootOrderUpdate"
    LESS_THAN1024 = "lessThan1024"
    LESS_THAN1024_DELTA = "lessThan1024Delta"
    LESS_THAN1024_DELTA_AVG = "lessThan1024DeltaAvg"
    LESS_THAN1024_DELTA_MAX = "lessThan1024DeltaMax"
    LESS_THAN1024_DELTA_MIN = "lessThan1024DeltaMin"
    LESS_THAN128 = "lessThan128"
    LESS_THAN128_DELTA = "lessThan128Delta"
    LESS_THAN128_DELTA_AVG = "lessThan128DeltaAvg"
    LESS_THAN128_DELTA_MAX = "lessThan128DeltaMax"
    LESS_THAN128_DELTA_MIN = "lessThan128DeltaMin"
    LESS_THAN2048 = "lessThan2048"
    LESS_THAN2048_DELTA = "lessThan2048Delta"
    LESS_THAN2048_DELTA_AVG = "lessThan2048DeltaAvg"
    LESS_THAN2048_DELTA_MAX = "lessThan2048DeltaMax"
    LESS_THAN2048_DELTA_MIN = "lessThan2048DeltaMin"
    LESS_THAN256 = "lessThan256"
    LESS_THAN256_DELTA = "lessThan256Delta"
    LESS_THAN256_DELTA_AVG = "lessThan256DeltaAvg"
    LESS_THAN256_DELTA_MAX = "lessThan256DeltaMax"
    LESS_THAN256_DELTA_MIN = "lessThan256DeltaMin"
    LESS_THAN4096 = "lessThan4096"
    LESS_THAN4096_DELTA = "lessThan4096Delta"
    LESS_THAN4096_DELTA_AVG = "lessThan4096DeltaAvg"
    LESS_THAN4096_DELTA_MAX = "lessThan4096DeltaMax"
    LESS_THAN4096_DELTA_MIN = "lessThan4096DeltaMin"
    LESS_THAN512 = "lessThan512"
    LESS_THAN512_DELTA = "lessThan512Delta"
    LESS_THAN512_DELTA_AVG = "lessThan512DeltaAvg"
    LESS_THAN512_DELTA_MAX = "lessThan512DeltaMax"
    LESS_THAN512_DELTA_MIN = "lessThan512DeltaMin"
    LESS_THAN64 = "lessThan64"
    LESS_THAN64_DELTA = "lessThan64Delta"
    LESS_THAN64_DELTA_AVG = "lessThan64DeltaAvg"
    LESS_THAN64_DELTA_MAX = "lessThan64DeltaMax"
    LESS_THAN64_DELTA_MIN = "lessThan64DeltaMin"
    LESS_THAN8192 = "lessThan8192"
    LESS_THAN8192_DELTA = "lessThan8192Delta"
    LESS_THAN8192_DELTA_AVG = "lessThan8192DeltaAvg"
    LESS_THAN8192_DELTA_MAX = "lessThan8192DeltaMax"
    LESS_THAN8192_DELTA_MIN = "lessThan8192DeltaMin"
    LESS_THAN9216 = "lessThan9216"
    LESS_THAN9216_DELTA = "lessThan9216Delta"
    LESS_THAN9216_DELTA_AVG = "lessThan9216DeltaAvg"
    LESS_THAN9216_DELTA_MAX = "lessThan9216DeltaMax"
    LESS_THAN9216_DELTA_MIN = "lessThan9216DeltaMin"
    LESS_THAN_OR_EQUAL_TO1518 = "lessThanOrEqualTo1518"
    LESS_THAN_OR_EQUAL_TO1518_DELTA = "lessThanOrEqualTo1518Delta"
    LESS_THAN_OR_EQUAL_TO1518_DELTA_AVG = "lessThanOrEqualTo1518DeltaAvg"
    LESS_THAN_OR_EQUAL_TO1518_DELTA_MAX = "lessThanOrEqualTo1518DeltaMax"
    LESS_THAN_OR_EQUAL_TO1518_DELTA_MIN = "lessThanOrEqualTo1518DeltaMin"
    LEVEL = "level"
    LEVEL_FLAG = "levelFlag"
    LIC_GP = "licGP"
    LIC_STATE = "licState"
    LIC_VENDOR = "licVendor"
    LIC_VERSION = "licVersion"
    LICENSE_TECH_SUPPORT_INFO = "licenseTechSupportInfo"
    LINE = "line"
    LINK_AGGREGATION_PREF = "linkAggregationPref"
    LINK_DESCR = "linkDescr"
    LINK_DOWN_TIMEOUT = "linkDownTimeout"
    LINK_FAILURE_COUNT = "linkFailureCount"
    LINK_FAILURE_COUNT_DELTA = "linkFailureCountDelta"
    LINK_FAILURE_COUNT_DELTA_AVG = "linkFailureCountDeltaAvg"
    LINK_FAILURE_COUNT_DELTA_MAX = "linkFailureCountDeltaMax"
    LINK_FAILURE_COUNT_DELTA_MIN = "linkFailureCountDeltaMin"
    LINK_FAILURES = "linkFailures"
    LINK_FAILURES_DELTA = "linkFailuresDelta"
    LINK_FAILURES_DELTA_AVG = "linkFailuresDeltaAvg"
    LINK_FAILURES_DELTA_MAX = "linkFailuresDeltaMax"
    LINK_FAILURES_DELTA_MIN = "linkFailuresDeltaMin"
    LINK_LOCAL = "linkLocal"
    LINK_SPEED = "linkSpeed"
    LINK_STATE = "linkState"
    LINK_STATE_REASON = "linkStateReason"
    LIP_COUNT = "lipCount"
    LIP_COUNT_DELTA = "lipCountDelta"
    LIP_COUNT_DELTA_AVG = "lipCountDeltaAvg"
    LIP_COUNT_DELTA_MAX = "lipCountDeltaMax"
    LIP_COUNT_DELTA_MIN = "lipCountDeltaMin"
    LLDP = "lldp"
    LLDP_MAC = "lldpMac"
    LLDP_RECEIVE = "lldpReceive"
    LLDP_TRANSMIT = "lldpTransmit"
    LOAD = "load"
    LOAD_AVG = "loadAvg"
    LOAD_MAX = "loadMax"
    LOAD_MIN = "loadMin"
    LOCAL = "local"
    LOCAL_DISK_POLICY_NAME = "localDiskPolicyName"
    LOCAL_FILE = "localFile"
    LOCAL_HOST = "localHost"
    LOCAL_ID = "localId"
    LOCAL_PLACEMENT_REF_CNT = "localPlacementRefCnt"
    LOCALE = "locale"
    LOCALES = "locales"
    LOCALITY = "locality"
    LOCATION = "location"
    LOCATION_DN = "locationDn"
    LOCATOR = "locator"
    LOCATOR_LED_OPER_STATE = "locatorLedOperState"
    LOG_DN = "logDn"
    LOGIN_TIME = "loginTime"
    LOOP_COUNT = "loopCount"
    LOSS_OF_SIGNAL_COUNT = "lossOfSignalCount"
    LOSS_OF_SIGNAL_COUNT_DELTA = "lossOfSignalCountDelta"
    LOSS_OF_SIGNAL_COUNT_DELTA_AVG = "lossOfSignalCountDeltaAvg"
    LOSS_OF_SIGNAL_COUNT_DELTA_MAX = "lossOfSignalCountDeltaMax"
    LOSS_OF_SIGNAL_COUNT_DELTA_MIN = "lossOfSignalCountDeltaMin"
    LOSS_OF_SYNC_COUNT = "lossOfSyncCount"
    LOSS_OF_SYNC_COUNT_DELTA = "lossOfSyncCountDelta"
    LOSS_OF_SYNC_COUNT_DELTA_AVG = "lossOfSyncCountDeltaAvg"
    LOSS_OF_SYNC_COUNT_DELTA_MAX = "lossOfSyncCountDeltaMax"
    LOSS_OF_SYNC_COUNT_DELTA_MIN = "lossOfSyncCountDeltaMin"
    LOSS_VISIBILITY_SOURCE = "lossVisibilitySource"
    LOW_SPEED = "lowSpeed"
    LOW_VOLTAGE_MEMORY = "lowVoltageMemory"
    LS_DN = "lsDn"
    LS_GUID = "lsGuid"
    LSP_DN = "lspDn"
    LUN = "lun"
    LUN_BUSY_RETRY_COUNT = "lunBusyRetryCount"
    LUN_CFG_ACTION = "lunCfgAction"
    LUN_COUNT_IN_USE = "lunCountInUse"
    LUN_COUNT_NOT_IN_USE = "lunCountNotInUse"
    LUN_COUNT_ORPHANED = "lunCountOrphaned"
    LUN_DN = "lunDn"
    LUN_ID = "lunId"
    LUN_ITEM_DN = "lunItemDn"
    LUN_ITEM_NAME = "lunItemName"
    LUN_MAP_TYPE = "lunMapType"
    LUN_MASK_ID = "lunMaskId"
    LUN_NAME = "lunName"
    LUN_ORDER = "lunOrder"
    LUN_QUEUE_DEPTH = "lunQueueDepth"
    LUN_REPLICA_COUNT = "lunReplicaCount"
    LUN_SNAPSHOT_COUNT = "lunSnapshotCount"
    LUN_STATUS = "lunStatus"
    LUN_TYPE = "lunType"
    LUNS_PER_TARGET = "lunsPerTarget"
    M_SERIES_BUNDLE_NAME = "mSeriesBundleName"
    M_SERIES_BUNDLE_VERSION = "mSeriesBundleVersion"
    MAC = "mac"
    MAC_ADDR = "macAddr"
    MAC_ADDR_TYPE = "macAddrType"
    MAC_ADDRESS = "macAddress"
    MAC_AGING = "macAging"
    MAC_DISCARDED_PACKETS = "macDiscardedPackets"
    MAC_DISCARDED_PACKETS_DELTA = "macDiscardedPacketsDelta"
    MAC_DISCARDED_PACKETS_DELTA_AVG = "macDiscardedPacketsDeltaAvg"
    MAC_DISCARDED_PACKETS_DELTA_MAX = "macDiscardedPacketsDeltaMax"
    MAC_DISCARDED_PACKETS_DELTA_MIN = "macDiscardedPacketsDeltaMin"
    MAC_OF_SHARED_IOMA = "macOfSharedIOMA"
    MAC_OF_SHARED_IOMB = "macOfSharedIOMB"
    MAC_OFFSET1 = "macOffset1"
    MAC_OFFSET2 = "macOffset2"
    MAC_REGISTER_MODE = "macRegisterMode"
    MAIN_BOARD_OUTLET1 = "mainBoardOutlet1"
    MAIN_BOARD_OUTLET1_AVG = "mainBoardOutlet1Avg"
    MAIN_BOARD_OUTLET1_MAX = "mainBoardOutlet1Max"
    MAIN_BOARD_OUTLET1_MIN = "mainBoardOutlet1Min"
    MAIN_BOARD_OUTLET2 = "mainBoardOutlet2"
    MAIN_BOARD_OUTLET2_AVG = "mainBoardOutlet2Avg"
    MAIN_BOARD_OUTLET2_MAX = "mainBoardOutlet2Max"
    MAIN_BOARD_OUTLET2_MIN = "mainBoardOutlet2Min"
    MAINT_GRP_TAG = "maintGrpTag"
    MAINT_POLICY_NAME = "maintPolicyName"
    MAINT_TAG = "maintTag"
    MAJOR_CNT = "majorCnt"
    MAJOR_OPT_TYPE = "majorOptType"
    MALFORMED_TLPERRORS = "malformedTLPErrors"
    MALFORMED_TLPERRORS_AVG = "malformedTLPErrorsAvg"
    MALFORMED_TLPERRORS_MAX = "malformedTLPErrorsMax"
    MALFORMED_TLPERRORS_MIN = "malformedTLPErrorsMin"
    MALFORMED_TLPERRORS_RUNNING = "malformedTLPErrorsRunning"
    MANAGING_DN = "managingDn"
    MANAGING_INST = "managingInst"
    MANAGING_INSTANCE = "managingInstance"
    MAPPING_NAME = "mappingName"
    MASK = "mask"
    MASTER_SLOT_ID = "masterSlotId"
    MAX = "max"
    MAX_ADDR = "maxAddr"
    MAX_APP_POWER = "maxAppPower"
    MAX_BONDS = "maxBonds"
    MAX_CAP = "maxCap"
    MAX_CAPACITY = "maxCapacity"
    MAX_CORES = "maxCores"
    MAX_DATA_FIELD_SIZE = "maxDataFieldSize"
    MAX_DEADLINE_TIMEOUT = "maxDeadlineTimeout"
    MAX_DERIVABLE_WWPN = "maxDerivableWWPN"
    MAX_DEVICES = "maxDevices"
    MAX_FAIL_REPORT_COUNT = "maxFailReportCount"
    MAX_FILES = "maxFiles"
    MAX_ID = "maxId"
    MAX_LOCAL_DISKS = "maxLocalDisks"
    MAX_PORTS = "maxPorts"
    MAX_PORTS_PER_NODE = "maxPortsPerNode"
    MAX_POST_POWER = "maxPostPower"
    MAX_POWER = "maxPower"
    MAX_PROCS = "maxProcs"
    MAX_RETRY_COUNT = "maxRetryCount"
    MAX_RULE_APPLY_TIMES = "maxRuleApplyTimes"
    MAX_SIZE = "maxSize"
    MAX_SPEED = "maxSpeed"
    MAX_SZ = "maxSz"
    MAX_THREADS = "maxThreads"
    MAX_VER = "maxVer"
    MAX_VIRTUAL_DRIVES_PER_SERVER = "maxVirtualDrivesPerServer"
    MAX_VIRTUAL_ETH_IF_PER_SERVER = "maxVirtualEthIfPerServer"
    MAXIMUM = "maximum"
    MAXIMUM_MR = "maximumMR"
    MAXIMUM_QP = "maximumQP"
    MAXIMUM_RETRY_COUNT = "maximumRetryCount"
    MBPS = "mbps"
    MBPS_AVG = "mbpsAvg"
    MBPS_MAX = "mbpsMax"
    MBPS_MIN = "mbpsMin"
    MCAST_POLICY_DN = "mcastPolicyDn"
    MCAST_POLICY_NAME = "mcastPolicyName"
    MD5_CHECKSUM = "md5Checksum"
    MDF_ID = "mdfId"
    ME4308_SUPPORTED = "me4308Supported"
    MEM_AVAILABLE = "memAvailable"
    MEM_AVAILABLE_AVG = "memAvailableAvg"
    MEM_AVAILABLE_MAX = "memAvailableMax"
    MEM_AVAILABLE_MIN = "memAvailableMin"
    MEM_CACHED = "memCached"
    MEM_CACHED_AVG = "memCachedAvg"
    MEM_CACHED_MAX = "memCachedMax"
    MEM_CACHED_MIN = "memCachedMin"
    MEM_CHUNK_SIZE = "memChunkSize"
    MEM_SIZE = "memSize"
    MEMBER_STATUS = "memberStatus"
    MEMBERSHIP = "membership"
    MEMORY_REGIONS = "memoryRegions"
    MEMORY_SPEED = "memorySpeed"
    MEMORY_USAGE = "memoryUsage"
    MEMORY_USAGE_AVG = "memoryUsageAvg"
    MEMORY_USAGE_MAX = "memoryUsageMax"
    MEMORY_USAGE_MIN = "memoryUsageMin"
    MENLO_ETH_INDEX = "menloEthIndex"
    MENLO_FC_INDEX = "menloFcIndex"
    MENLO_MCPU_INDEX = "menloMcpuIndex"
    MENLO_NET_INDEX = "menloNetIndex"
    MENLO_PORT_INDEX = "menloPortIndex"
    MENLO_QUEUE_COMPONENT = "menloQueueComponent"
    MENLO_QUEUE_INDEX = "menloQueueIndex"
    MESSAGE = "message"
    MESSAGE_SUBTYPE = "messageSubtype"
    MESSAGE_TYPE = "messageType"
    META_TRANS_ID = "metaTransId"
    MEZZ_MAPPING = "mezzMapping"
    MFG_DATE = "mfgDate"
    MFG_ID = "mfgId"
    MFG_MAJOR_REV = "mfgMajorRev"
    MFG_MINOR_REV = "mfgMinorRev"
    MFG_PLATFORM_ID = "mfgPlatformId"
    MFG_TIME = "mfgTime"
    MGMT_ACCESS_POLICY_NAME = "mgmtAccessPolicyName"
    MGMT_FW_POLICY_NAME = "mgmtFwPolicyName"
    MGMT_IF_IP_ADDR = "mgmtIfIpAddr"
    MGMT_IP = "mgmtIp"
    MGMT_IP_ADDR = "mgmtIpAddr"
    MGMT_PLANE_VER = "mgmtPlaneVer"
    MGMT_SERVICES_STATE = "mgmtServicesState"
    MID_TEMP = "midTemp"
    MID_TEMP_AVG = "midTempAvg"
    MID_TEMP_MAX = "midTempMax"
    MID_TEMP_MIN = "midTempMin"
    MIGRATE_STATUS = "migrateStatus"
    MIN = "min"
    MIN_ACTIVE_FAN = "minActiveFan"
    MIN_ADDR = "minAddr"
    MIN_APP_POWER = "minAppPower"
    MIN_BIOS_VERSION = "minBiosVersion"
    MIN_CAP = "minCap"
    MIN_CIMC_VERSION = "minCimcVersion"
    MIN_CORES = "minCores"
    MIN_DRIVE_SIZE = "minDriveSize"
    MIN_ID = "minId"
    MIN_NORM_POST_POWER = "minNormPostPower"
    MIN_POST_POWER = "minPostPower"
    MIN_POWER = "minPower"
    MIN_PROCS = "minProcs"
    MIN_REQ_POWER = "minReqPower"
    MIN_SZ = "minSz"
    MIN_THREADS = "minThreads"
    MIN_VER = "minVer"
    MIN_VERSION = "minVersion"
    MINIMUM_SEND_NOW_INTERVAL_SECONDS = "minimumSendNowIntervalSeconds"
    MINOR_CNT = "minorCnt"
    MINUTE = "minute"
    MIRRORING_INTER_SOCK_ERRORS = "mirroringInterSockErrors"
    MIRRORING_INTER_SOCK_ERRORS_AVG = "mirroringInterSockErrorsAvg"
    MIRRORING_INTER_SOCK_ERRORS_MAX = "mirroringInterSockErrorsMax"
    MIRRORING_INTER_SOCK_ERRORS_MIN = "mirroringInterSockErrorsMin"
    MIRRORING_INTER_SOCK_ERRORS_RUNNING = "mirroringInterSockErrorsRunning"
    MIRRORING_INTRA_SOCK_ERRORS = "mirroringIntraSockErrors"
    MIRRORING_INTRA_SOCK_ERRORS_AVG = "mirroringIntraSockErrorsAvg"
    MIRRORING_INTRA_SOCK_ERRORS_MAX = "mirroringIntraSockErrorsMax"
    MIRRORING_INTRA_SOCK_ERRORS_MIN = "mirroringIntraSockErrorsMin"
    MIRRORING_INTRA_SOCK_ERRORS_RUNNING = "mirroringIntraSockErrorsRunning"
    MISMATCH_ERRORS = "mismatchErrors"
    MISMATCH_ERRORS_AVG = "mismatchErrorsAvg"
    MISMATCH_ERRORS_MAX = "mismatchErrorsMax"
    MISMATCH_ERRORS_MIN = "mismatchErrorsMin"
    MISMATCH_ERRORS_RUNNING = "mismatchErrorsRunning"
    MO_CLASS_ID = "moClassId"
    MO_DN = "moDn"
    MODE = "mode"
    MODE_TIME = "modeTime"
    MODEL = "model"
    MODIFIED = "modified"
    MODULE = "module"
    MODULUS = "modulus"
    MON_TRAF_DIR = "monTrafDir"
    MONITOR_INTERVAL = "monitorInterval"
    MONITOR_MECHANISM = "monitorMechanism"
    MONITOR_STATE = "monitorState"
    MOST_RECENT = "mostRecent"
    MOUNT_PROTOCOL = "mountProtocol"
    MSG_INTERVAL = "msgInterval"
    MTIME = "mtime"
    MTU = "mtu"
    MULTI_COLLISION = "multiCollision"
    MULTI_COLLISION_DELTA = "multiCollisionDelta"
    MULTI_COLLISION_DELTA_AVG = "multiCollisionDeltaAvg"
    MULTI_COLLISION_DELTA_MAX = "multiCollisionDeltaMax"
    MULTI_COLLISION_DELTA_MIN = "multiCollisionDeltaMin"
    MULTI_PORT_CONNECTION_STATUS = "multiPortConnectionStatus"
    MULTI_QUEUE = "multiQueue"
    MULTICAST_HW_HASH = "multicastHwHash"
    MULTICAST_OPTIMIZE = "multicastOptimize"
    MULTICAST_PACKETS = "multicastPackets"
    MULTICAST_PACKETS_DELTA = "multicastPacketsDelta"
    MULTICAST_PACKETS_DELTA_AVG = "multicastPacketsDeltaAvg"
    MULTICAST_PACKETS_DELTA_MAX = "multicastPacketsDeltaMax"
    MULTICAST_PACKETS_DELTA_MIN = "multicastPacketsDeltaMin"
    MULTIPLE = "multiple"
    N_OSCOUNT = "nOSCount"
    N_OSCOUNT_DELTA = "nOSCountDelta"
    N_OSCOUNT_DELTA_AVG = "nOSCountDeltaAvg"
    N_OSCOUNT_DELTA_MAX = "nOSCountDeltaMax"
    N_OSCOUNT_DELTA_MIN = "nOSCountDeltaMin"
    NAME = "name"
    NAMING_PREFIX = "namingPrefix"
    NATIVE_NET = "nativeNet"
    NATIVE_NET_DN = "nativeNetDn"
    NEED_GLOBALIZATION = "needGlobalization"
    NEED_ID_RE_EVALUATE = "needIdReEvaluate"
    NEED_RECOVERY = "needRecovery"
    NET_GROUP_DN = "netGroupDn"
    NETGROUP_NAME = "netgroupName"
    NETWORK_CONFIG_ISSUES = "networkConfigIssues"
    NETWORK_ENDPOINT = "networkEndpoint"
    NEW_CPDN = "newCPDN"
    NEW_FE_TS = "newFeTs"
    NEW_SPDN = "newSPDN"
    NEXT_DEADLINE = "nextDeadline"
    NEXT_IDENT_REQUEST_DN = "nextIdentRequestDn"
    NEXT_LEARN_CYCLE_TS = "nextLearnCycleTs"
    NEXT_REGISTRATION_TIME = "nextRegistrationTime"
    NEXT_REQ_ID = "nextReqId"
    NF_VERSION_LO = "nfVersionLo"
    NIC_DN = "nicDn"
    NLINK = "nlink"
    NO_BREAKDOWN_GREATER_THAN1518 = "noBreakdownGreaterThan1518"
    NO_BREAKDOWN_GREATER_THAN1518_DELTA = "noBreakdownGreaterThan1518Delta"
    NO_BREAKDOWN_GREATER_THAN1518_DELTA_AVG = "noBreakdownGreaterThan1518DeltaAvg"
    NO_BREAKDOWN_GREATER_THAN1518_DELTA_MAX = "noBreakdownGreaterThan1518DeltaMax"
    NO_BREAKDOWN_GREATER_THAN1518_DELTA_MIN = "noBreakdownGreaterThan1518DeltaMin"
    NO_CHANGE_INTERVAL = "noChangeInterval"
    NODE_ADDR = "nodeAddr"
    NODE_WWN = "nodeWwn"
    NON_CR4 = "nonCR4"
    NORMAL_SPEED = "normalSpeed"
    NORMAL_VALUE = "normalValue"
    NORMALIZED_IPV4 = "normalizedIpv4"
    NORMALIZED_IPV6 = "normalizedIpv6"
    NORMALIZED_TIME_COL = "normalizedTimeCol"
    NOT_IN_USE = "notInUse"
    NOTE = "note"
    NOTIFICATION_TYPE = "notificationType"
    NS_SIZE = "nsSize"
    NUM_CERTS = "numCerts"
    NUM_DED_HOT_SPARES = "numDedHotSpares"
    NUM_DRIVES = "numDrives"
    NUM_GLOB_HOT_SPARES = "numGlobHotSpares"
    NUM_OF40_GADAPTORS_WITH_OLD_FW = "numOf40GAdaptorsWithOldFw"
    NUM_OF40_GADAPTORS_WITH_UNKNOWN_FW = "numOf40GAdaptorsWithUnknownFw"
    NUM_OF_ADAPTORS = "numOfAdaptors"
    NUM_OF_ADVANCE_POLICY_CONFLICTS = "numOfAdvancePolicyConflicts"
    NUM_OF_BLADES = "numOfBlades"
    NUM_OF_BLOCKS = "numOfBlocks"
    NUM_OF_CARTRIDGES = "numOfCartridges"
    NUM_OF_CHASSIS = "numOfChassis"
    NUM_OF_CONFLICTS = "numOfConflicts"
    NUM_OF_CONTROLLERS = "numOfControllers"
    NUM_OF_CORES = "numOfCores"
    NUM_OF_CORES_ENABLED = "numOfCoresEnabled"
    NUM_OF_CPUS = "numOfCpus"
    NUM_OF_DCES = "numOfDCEs"
    NUM_OF_ENCLOSURES = "numOfEnclosures"
    NUM_OF_ETH_HOST_IFS = "numOfEthHostIfs"
    NUM_OF_ETH_PORTS = "numOfEthPorts"
    NUM_OF_EXPANSION_MODULES = "numOfExpansionModules"
    NUM_OF_FC_HOST_IFS = "numOfFcHostIfs"
    NUM_OF_FC_PORTS = "numOfFcPorts"
    NUM_OF_FEX = "numOfFex"
    NUM_OF_FIXED_MODULES = "numOfFixedModules"
    NUM_OF_GRAPHICS_CONTROLLERS = "numOfGraphicsControllers"
    NUM_OF_HBAS = "numOfHBAs"
    NUM_OF_MISSING_POLICIES = "numOfMissingPolicies"
    NUM_OF_MISSINGUALIFYING_POLICIES = "numOfMissingualifyingPolicies"
    NUM_OF_NICS = "numOfNICs"
    NUM_OF_NON_BLOCK_CONFLICTS = "numOfNonBlockConflicts"
    NUM_OF_PENDING = "numOfPending"
    NUM_OF_POLICY = "numOfPolicy"
    NUM_OF_POLICY_CONFLICT_RESOLVED = "numOfPolicyConflictResolved"
    NUM_OF_POLICY_CONFLICTS = "numOfPolicyConflicts"
    NUM_OF_POLICY_NO_CONFLICTS = "numOfPolicyNoConflicts"
    NUM_OF_PORTS = "numOfPorts"
    NUM_OF_RACKS = "numOfRacks"
    NUM_OF_SERVER_POOL_AND_ID_CONFLICTS = "numOfServerPoolAndIdConflicts"
    NUM_OF_SERVER_UNITS = "numOfServerUnits"
    NUM_OF_SIMPLE_POLICY_CONFLICTS = "numOfSimplePolicyConflicts"
    NUM_OF_STORAGE_BLADES = "numOfStorageBlades"
    NUM_OF_THREADS = "numOfThreads"
    NUM_OF_UNQUALIFYING_POLICIES = "numOfUnqualifyingPolicies"
    NUM_OF_VLAN_CONFLICT_RESOLVED = "numOfVlanConflictResolved"
    NUM_OF_VLAN_CONFLICTS = "numOfVlanConflicts"
    NUM_OF_VLAN_NO_CONFLICTS = "numOfVlanNoConflicts"
    NUM_OF_VLANS = "numOfVlans"
    NUM_OF_VSAN_CONFLICT_RESOLVED = "numOfVsanConflictResolved"
    NUM_OF_VSAN_CONFLICTS = "numOfVsanConflicts"
    NUM_OF_VSAN_NO_CONFLICTS = "numOfVsanNoConflicts"
    NUM_OF_VSANS = "numOfVsans"
    NUM_OFI_SCSIV_NICS = "numOfiSCSIvNICs"
    NUM_PORTS = "numPorts"
    NUM_RUNNING_INSTANCES = "numRunningInstances"
    NUM_SLOTS = "numSlots"
    NUMBER_OF_ARP_REQUESTS = "numberOfArpRequests"
    NUMBER_OF_BLOCKS = "numberOfBlocks"
    NUMBER_OF_DEPENDENCY = "numberOfDependency"
    NUMBER_OF_FLEX_FLASH_CARDS = "numberOfFlexFlashCards"
    NUMBER_OF_NDISC_REQUESTS = "numberOfNdiscRequests"
    NUMBER_OF_NON_IMPORTABLE = "numberOfNonImportable"
    NUMBER_OF_PING_REQUESTS = "numberOfPingRequests"
    NUMBER_OF_SERVER_UNITS = "numberOfServerUnits"
    NUMBER_OF_SERVICE_PROFILE = "numberOfServiceProfile"
    NUMBER_OF_SERVICE_TEMPLATE = "numberOfServiceTemplate"
    NV_DIMM_HEALTH = "nvDimmHealth"
    NVP = "nvp"
    NW_CTRL_POLICY_NAME = "nwCtrlPolicyName"
    NW_TEMPL_NAME = "nwTemplName"
    OAUTH_CREATE_TS = "oauthCreateTs"
    OAUTH_TOKEN_EXPIRY = "oauthTokenExpiry"
    OAUTH_TOKEN_TYPE = "oauthTokenType"
    OAUTH_TOKEN_VAL = "oauthTokenVal"
    OBJECT_CLASS_NAME = "objectClassName"
    OBJECT_NAME = "objectName"
    OBJECT_TYPE = "objectType"
    OBSERVED_DN = "observedDn"
    OCCUR = "occur"
    OEM_ID = "oemId"
    OEM_NAME = "oemName"
    OEM_PART_NUMBER = "oemPartNumber"
    OFFLOAD_SUPPORT = "offloadSupport"
    OFFLOAD_TYPE = "offloadType"
    OLD_CPDN = "oldCPDN"
    OLD_CENTRALE_MO_DN = "oldCentraleMoDn"
    OLD_CENTRALE_VNET_EP_DN = "oldCentraleVnetEpDn"
    OLD_CERT_CHAIN = "oldCertChain"
    OLD_CHASSIS_DN = "oldChassisDn"
    OLD_PN_DN = "oldPnDn"
    OLD_PROC_DN = "oldProcDn"
    OLD_SPDN = "oldSPDN"
    OLD_STR_TYPE = "oldStrType"
    ON_BEHALF_OF_IDENT = "onBehalfOfIdent"
    ON_BEHALF_OF_TYPE = "onBehalfOfType"
    ON_BOARD_MEMORY_PRESENT = "onBoardMemoryPresent"
    ON_BOARD_MEMORY_SIZE = "onBoardMemorySize"
    OOB_CONTROLLER_ID = "oobControllerId"
    OOB_IF_GW = "oobIfGw"
    OOB_IF_IP = "oobIfIp"
    OOB_IF_MAC = "oobIfMac"
    OOB_IF_MASK = "oobIfMask"
    OOB_INTERFACE_SUPPORTED = "oobInterfaceSupported"
    OP_STATUS = "opStatus"
    OP_TYPE = "opType"
    OPER_ADAPTOR_PROFILE_NAME = "operAdaptorProfileName"
    OPER_ATTR_NAME = "operAttrName"
    OPER_ATTR_VALUE = "operAttrValue"
    OPER_AUTH_PROFILE_NAME = "operAuthProfileName"
    OPER_BIOS_PROFILE_NAME = "operBiosProfileName"
    OPER_BOOT_POLICY_NAME = "operBootPolicyName"
    OPER_BORDER_AGGR_PORT_ID = "operBorderAggrPortId"
    OPER_BORDER_PORT_ID = "operBorderPortId"
    OPER_BORDER_SLOT_ID = "operBorderSlotId"
    OPER_CATEGORY = "operCategory"
    OPER_CDN_NAME = "operCdnName"
    OPER_CDP_LINK_POLICY_NAME = "operCdpLinkPolicyName"
    OPER_CHASSIS_FW_POLICY_NAME = "operChassisFwPolicyName"
    OPER_CODE = "operCode"
    OPER_COMMITTED = "operCommitted"
    OPER_COMPUTE_CONN_POLICY_NAME = "operComputeConnPolicyName"
    OPER_CON_POLICY_NAME = "operConPolicyName"
    OPER_CONFIG_ISSUES = "operConfigIssues"
    OPER_CONN = "operConn"
    OPER_DEVICE_ID = "operDeviceId"
    OPER_DEVICE_PROFILE_REF = "operDeviceProfileRef"
    OPER_DISK_ZONING_POLICY_NAME = "operDiskZoningPolicyName"
    OPER_DN = "operDn"
    OPER_DNLD_STATUS = "operDnldStatus"
    OPER_DOMAIN_DN = "operDomainDn"
    OPER_DOMAIN_GROUP_DN = "operDomainGroupDn"
    OPER_DYNAMIC_CON_POLICY_NAME = "operDynamicConPolicyName"
    OPER_ETH_DN = "operEthDn"
    OPER_ETH_LINK_PROFILE_NAME = "operEthLinkProfileName"
    OPER_EVAC_STATE = "operEvacState"
    OPER_EXT_IPPOOL_NAME = "operExtIPPoolName"
    OPER_FPLOCK_STATE = "operFPLockState"
    OPER_GRAPHICS_CARD_POLICY_NAME = "operGraphicsCardPolicyName"
    OPER_GROUP_DN = "operGroupDn"
    OPER_HOST_FW_POLICY_NAME = "operHostFwPolicyName"
    OPER_HOST_PORT = "operHostPort"
    OPER_HW_CHANGE_DISC_POLICY_NAME = "operHwChangeDiscPolicyName"
    OPER_ID = "operId"
    OPER_IDENT_POOL_NAME = "operIdentPoolName"
    OPER_INBAND_POLICY_NAME = "operInbandPolicyName"
    OPER_INBAND_PROFILE_DN = "operInbandProfileDn"
    OPER_IQN_IDENT_POOL_NAME = "operIqnIdentPoolName"
    OPER_KMIP_CERTIFICATE_POLICY_NAME = "operKmipCertificatePolicyName"
    OPER_KVM_MGMT_POLICY_NAME = "operKvmMgmtPolicyName"
    OPER_LACP_POLICY_NAME = "operLacpPolicyName"
    OPER_LAN_CONN_POLICY_NAME = "operLanConnPolicyName"
    OPER_LOCAL_DISK_POLICY_NAME = "operLocalDiskPolicyName"
    OPER_LUN_ID = "operLunId"
    OPER_MAINT_POLICY_NAME = "operMaintPolicyName"
    OPER_MCAST_POLICY_NAME = "operMcastPolicyName"
    OPER_MGMT_ACCESS_POLICY_NAME = "operMgmtAccessPolicyName"
    OPER_MGMT_FW_POLICY_NAME = "operMgmtFwPolicyName"
    OPER_MIN = "operMin"
    OPER_MOUNT_STATUS = "operMountStatus"
    OPER_NAME = "operName"
    OPER_NET_GROUP_DN = "operNetGroupDn"
    OPER_NET_GROUP_NAME = "operNetGroupName"
    OPER_NET_GROUP_REF_DN = "operNetGroupRefDn"
    OPER_NW_CTRL_POLICY_NAME = "operNwCtrlPolicyName"
    OPER_NW_TEMPL_NAME = "operNwTemplName"
    OPER_ORDER = "operOrder"
    OPER_ORG_DN = "operOrgDn"
    OPER_PEAK = "operPeak"
    OPER_PEER_REDUNDANCY_TEMPL_NAME = "operPeerRedundancyTemplName"
    OPER_PORT = "operPort"
    OPER_PORT_DISC_POLICY_NAME = "operPortDiscPolicyName"
    OPER_PORT_MODE = "operPortMode"
    OPER_POWER = "operPower"
    OPER_POWER_POLICY_NAME = "operPowerPolicyName"
    OPER_POWER_SYNC_POLICY_NAME = "operPowerSyncPolicyName"
    OPER_PRIMARY_VNET_DN = "operPrimaryVnetDn"
    OPER_PRIMARY_VNET_NAME = "operPrimaryVnetName"
    OPER_PRIO = "operPrio"
    OPER_PROF_METHOD = "operProfMethod"
    OPER_PROP_MASK = "operPropMask"
    OPER_PROP_MOD = "operPropMod"
    OPER_PROTOCOL = "operProtocol"
    OPER_PWR_TRANS_SRC = "operPwrTransSrc"
    OPER_QOS_POLICY_NAME = "operQosPolicyName"
    OPER_QOSCLASS_DEFINITION_NAME = "operQosclassDefinitionName"
    OPER_QUALIFIER = "operQualifier"
    OPER_QUALIFIER_REASON = "operQualifierReason"
    OPER_SAN_CONN_POLICY_NAME = "operSanConnPolicyName"
    OPER_SCHED_NAME = "operSchedName"
    OPER_SCHEDULER = "operScheduler"
    OPER_SCRUB_POLICY_NAME = "operScrubPolicyName"
    OPER_SEARCH_FIELD = "operSearchField"
    OPER_SEC_SEARCH_FIELD = "operSecSearchField"
    OPER_SERVICE_PACK_VERSION = "operServicePackVersion"
    OPER_SOL_POLICY_NAME = "operSolPolicyName"
    OPER_SPEED = "operSpeed"
    OPER_SRC_DME = "operSrcDme"
    OPER_SRC_TEMPL_NAME = "operSrcTemplName"
    OPER_STATE = "operState"
    OPER_STATE_ACK = "operStateAck"
    OPER_STATE_DESC = "operStateDesc"
    OPER_STATE_DESCR = "operStateDescr"
    OPER_STATE_QUAL = "operStateQual"
    OPER_STATE_REASON = "operStateReason"
    OPER_STATE_REQUESTOR = "operStateRequestor"
    OPER_STATS_POLICY_NAME = "operStatsPolicyName"
    OPER_STATUS = "operStatus"
    OPER_STORAGE_CONN_POLICY_NAME = "operStorageConnPolicyName"
    OPER_STORAGE_PROFILE_NAME = "operStorageProfileName"
    OPER_SUB_TYPE = "operSubType"
    OPER_SYS_DN = "operSysDn"
    OPER_TEMPLATE_NAME = "operTemplateName"
    OPER_THIRD_SEARCH_FIELD = "operThirdSearchField"
    OPER_TYPE = "operType"
    OPER_UDLD_LINK_POLICY_NAME = "operUdldLinkPolicyName"
    OPER_VCON = "operVcon"
    OPER_VCON_PROFILE_NAME = "operVconProfileName"
    OPER_VERSION = "operVersion"
    OPER_VLAN_NAME = "operVlanName"
    OPER_VMEDIA_POLICY_NAME = "operVmediaPolicyName"
    OPER_VNET_DN = "operVnetDn"
    OPER_VNET_NAME = "operVnetName"
    OPER_VOLUME_NAME = "operVolumeName"
    OPERABILITY = "operability"
    OPERABILITY_QUALIFIER = "operabilityQualifier"
    OPERABILITY_QUALIFIER_REASON = "operabilityQualifierReason"
    OPERATING_MODE = "operatingMode"
    OPERATION = "operation"
    OPERATION_CODE = "operationCode"
    OPERATION_CODE_CLEARANCE = "operationCodeClearance"
    OPERATION_REQUEST = "operationRequest"
    OPERATION_STATE = "operationState"
    OPERATION_STATUS = "operationStatus"
    OPROM_BOOT_STATUS = "opromBootStatus"
    ORDER = "order"
    ORG_CATEGORY = "orgCategory"
    ORG_DN = "orgDn"
    ORG_NAME = "orgName"
    ORG_PERMIT_DN = "orgPermitDn"
    ORG_UNIT_NAME = "orgUnitName"
    ORIG_IQN = "origIqn"
    ORIG_SEVERITY = "origSeverity"
    ORIGIN_LUN = "originLun"
    ORIGINAL_MAC = "originalMac"
    ORIGINAL_NODE_WWN = "originalNodeWwn"
    ORIGINAL_UUID = "originalUuid"
    ORIGINAL_WWN = "originalWwn"
    ORPHANED = "orphaned"
    OS_VENDOR = "osVendor"
    OS_VERSION = "osVersion"
    OUT_DISCARD = "outDiscard"
    OUT_DISCARD_DELTA = "outDiscardDelta"
    OUT_DISCARD_DELTA_AVG = "outDiscardDeltaAvg"
    OUT_DISCARD_DELTA_MAX = "outDiscardDeltaMax"
    OUT_DISCARD_DELTA_MIN = "outDiscardDeltaMin"
    OUT_OF_COMPLIANCE_START_TIME = "outOfComplianceStartTime"
    OUTBAND_MGMT_POOL = "outbandMgmtPool"
    OUTLET1 = "outlet1"
    OUTLET1_AVG = "outlet1Avg"
    OUTLET1_MAX = "outlet1Max"
    OUTLET1_MIN = "outlet1Min"
    OUTLET2 = "outlet2"
    OUTLET2_AVG = "outlet2Avg"
    OUTLET2_MAX = "outlet2Max"
    OUTLET2_MIN = "outlet2Min"
    OUTPUT12V = "output12v"
    OUTPUT12V_AVG = "output12vAvg"
    OUTPUT12V_MAX = "output12vMax"
    OUTPUT12V_MIN = "output12vMin"
    OUTPUT3V3 = "output3v3"
    OUTPUT3V3_AVG = "output3v3Avg"
    OUTPUT3V3_MAX = "output3v3Max"
    OUTPUT3V3_MIN = "output3v3Min"
    OUTPUT_CURRENT = "outputCurrent"
    OUTPUT_CURRENT_AVG = "outputCurrentAvg"
    OUTPUT_CURRENT_MAX = "outputCurrentMax"
    OUTPUT_CURRENT_MIN = "outputCurrentMin"
    OUTPUT_MEGABYTES = "outputMegabytes"
    OUTPUT_MEGABYTES_DELTA = "outputMegabytesDelta"
    OUTPUT_MEGABYTES_DELTA_AVG = "outputMegabytesDeltaAvg"
    OUTPUT_MEGABYTES_DELTA_MAX = "outputMegabytesDeltaMax"
    OUTPUT_MEGABYTES_DELTA_MIN = "outputMegabytesDeltaMin"
    OUTPUT_POWER = "outputPower"
    OUTPUT_POWER_AVG = "outputPowerAvg"
    OUTPUT_POWER_MAX = "outputPowerMax"
    OUTPUT_POWER_MIN = "outputPowerMin"
    OUTPUT_REQUESTS = "outputRequests"
    OUTPUT_REQUESTS_DELTA = "outputRequestsDelta"
    OUTPUT_REQUESTS_DELTA_AVG = "outputRequestsDeltaAvg"
    OUTPUT_REQUESTS_DELTA_MAX = "outputRequestsDeltaMax"
    OUTPUT_REQUESTS_DELTA_MIN = "outputRequestsDeltaMin"
    OUTPUT_STATUS = "outputStatus"
    OUTPUT_VOLTAGE = "outputVoltage"
    OUTPUT_VOLTAGE_AVG = "outputVoltageAvg"
    OUTPUT_VOLTAGE_MAX = "outputVoltageMax"
    OUTPUT_VOLTAGE_MIN = "outputVoltageMin"
    OVER_ALL_STATUS = "overAllStatus"
    OVERALL_PROGRESS = "overallProgress"
    OVERALL_STATUS = "overallStatus"
    OVERLAP_STATE_FOR_A = "overlapStateForA"
    OVERLAP_STATE_FOR_B = "overlapStateForB"
    OVERLAPPING_VLANS = "overlappingVlans"
    OVERLAY = "overlay"
    OVERRIDE_DEFAULT_EXCLUSION = "overrideDefaultExclusion"
    OVERSIZED_BAD_CRC_PACKETS = "oversizedBadCrcPackets"
    OVERSIZED_BAD_CRC_PACKETS_DELTA = "oversizedBadCrcPacketsDelta"
    OVERSIZED_BAD_CRC_PACKETS_DELTA_AVG = "oversizedBadCrcPacketsDeltaAvg"
    OVERSIZED_BAD_CRC_PACKETS_DELTA_MAX = "oversizedBadCrcPacketsDeltaMax"
    OVERSIZED_BAD_CRC_PACKETS_DELTA_MIN = "oversizedBadCrcPacketsDeltaMin"
    OVERSIZED_GOOD_CRC_PACKETS = "oversizedGoodCrcPackets"
    OVERSIZED_GOOD_CRC_PACKETS_DELTA = "oversizedGoodCrcPacketsDelta"
    OVERSIZED_GOOD_CRC_PACKETS_DELTA_AVG = "oversizedGoodCrcPacketsDeltaAvg"
    OVERSIZED_GOOD_CRC_PACKETS_DELTA_MAX = "oversizedGoodCrcPacketsDeltaMax"
    OVERSIZED_GOOD_CRC_PACKETS_DELTA_MIN = "oversizedGoodCrcPacketsDeltaMin"
    OVERSIZED_PACKETS = "oversizedPackets"
    OVERSIZED_PACKETS_DELTA = "oversizedPacketsDelta"
    OVERSIZED_PACKETS_DELTA_AVG = "oversizedPacketsDeltaAvg"
    OVERSIZED_PACKETS_DELTA_MAX = "oversizedPacketsDeltaMax"
    OVERSIZED_PACKETS_DELTA_MIN = "oversizedPacketsDeltaMin"
    OVERWRITE = "overwrite"
    OWNER = "owner"
    OWNER_DN = "ownerDn"
    OWNER_IP = "ownerIp"
    OWNER_IPV4V6_ADDR = "ownerIpv4v6Addr"
    OWNER_NAME = "ownerName"
    OWNER_POLICY = "ownerPolicy"
    OWNER_TYPE = "ownerType"
    OWNERSHIP = "ownership"
    OWNERSHIP_STATE = "ownershipState"
    PACKAGE_VERSION = "packageVersion"
    PACKETS_RX = "packetsRx"
    PACKETS_RX_DELTA = "packetsRxDelta"
    PACKETS_RX_DELTA_AVG = "packetsRxDeltaAvg"
    PACKETS_RX_DELTA_MAX = "packetsRxDeltaMax"
    PACKETS_RX_DELTA_MIN = "packetsRxDeltaMin"
    PACKETS_TX = "packetsTx"
    PACKETS_TX_DELTA = "packetsTxDelta"
    PACKETS_TX_DELTA_AVG = "packetsTxDeltaAvg"
    PACKETS_TX_DELTA_MAX = "packetsTxDeltaMax"
    PACKETS_TX_DELTA_MIN = "packetsTxDeltaMin"
    PAK = "pak"
    PARAM_NAME = "paramName"
    PARENT_ADMIN_STATE = "parentAdminState"
    PARENT_CONTEXT = "parentContext"
    PARENT_DNS = "parentDns"
    PARENT_ID = "parentId"
    PARENT_LUN_NAME = "parentLunName"
    PARENT_ORG_TYPE = "parentOrgType"
    PART_NUMBER = "partNumber"
    PARTITION_COUNT = "partitionCount"
    PARTITION_END = "partitionEnd"
    PARTITION_START = "partitionStart"
    PASSWORD = "password"
    PATH = "path"
    PATTERN = "pattern"
    PAUSE_PACKETS = "pausePackets"
    PAUSE_PACKETS_DELTA = "pausePacketsDelta"
    PAUSE_PACKETS_DELTA_AVG = "pausePacketsDeltaAvg"
    PAUSE_PACKETS_DELTA_MAX = "pausePacketsDeltaMax"
    PAUSE_PACKETS_DELTA_MIN = "pausePacketsDeltaMin"
    PCI_ADDR = "pciAddr"
    PCI_ADDR_LIST = "pciAddrList"
    PCI_FUNC = "pciFunc"
    PCI_SLOT = "pciSlot"
    PCI_SLOT_RAW_NAME = "pciSlotRawName"
    PEER_AGGR_PORT_ID = "peerAggrPortId"
    PEER_CHASSIS_ID = "peerChassisId"
    PEER_COMM_STATUS = "peerCommStatus"
    PEER_DN = "peerDn"
    PEER_ENCAP = "peerEncap"
    PEER_ID = "peerId"
    PEER_PORT_ID = "peerPortId"
    PEER_PRESENCE = "peerPresence"
    PEER_REDUNDANCY_TEMPL_NAME = "peerRedundancyTemplName"
    PEER_SLOT_ID = "peerSlotId"
    PEER_STATUS = "peerStatus"
    PER_DISK_CAP = "perDiskCap"
    PER_PRIORITY_PAUSE_PACKETS = "perPriorityPausePackets"
    PER_PRIORITY_PAUSE_PACKETS_DELTA = "perPriorityPausePacketsDelta"
    PER_PRIORITY_PAUSE_PACKETS_DELTA_AVG = "perPriorityPausePacketsDeltaAvg"
    PER_PRIORITY_PAUSE_PACKETS_DELTA_MAX = "perPriorityPausePacketsDeltaMax"
    PER_PRIORITY_PAUSE_PACKETS_DELTA_MIN = "perPriorityPausePacketsDeltaMin"
    PERCENTAGE = "percentage"
    PERCENTAGE_LIFE_LEFT = "percentageLifeLeft"
    PERCENTAGE_LIFE_LEFT_AVG = "percentageLifeLeftAvg"
    PERCENTAGE_LIFE_LEFT_MAX = "percentageLifeLeftMax"
    PERCENTAGE_LIFE_LEFT_MIN = "percentageLifeLeftMin"
    PERF = "perf"
    PERFORMANCE_LEVEL = "performanceLevel"
    PERS_BIND = "persBind"
    PERS_BIND_CLEAR = "persBindClear"
    PERSIST = "persist"
    PERSISTED_EPFB = "persistedEPFB"
    PF_DN = "pfDn"
    PH_SWITCH_ID = "phSwitchId"
    PHONE = "phone"
    PHY_ID = "phyId"
    PHY_PORT_BITMASK = "phyPortBitmask"
    PHYS_DN = "physDn"
    PHYS_EP_DN = "physEpDn"
    PHYSICAL_BLOCK_SIZE = "physicalBlockSize"
    PHYSICAL_DRIVE_COUNT = "physicalDriveCount"
    PID = "pid"
    PIN_GROUP_NAME = "pinGroupName"
    PIN_TO_GROUP_NAME = "pinToGroupName"
    PINNED_CACHE_STATUS = "pinnedCacheStatus"
    PLACEMENT = "placement"
    PLACEMENT_REF_CNT = "placementRefCnt"
    PN_DN = "pnDn"
    PN_POOL_DN = "pnPoolDn"
    POISONED_TLPERRORS = "poisonedTLPErrors"
    POISONED_TLPERRORS_AVG = "poisonedTLPErrorsAvg"
    POISONED_TLPERRORS_MAX = "poisonedTLPErrorsMax"
    POISONED_TLPERRORS_MIN = "poisonedTLPErrorsMin"
    POISONED_TLPERRORS_RUNNING = "poisonedTLPErrorsRunning"
    POL_DN = "polDn"
    POL_NAME = "polName"
    POLICY_ADMIN_STATE = "policyAdminState"
    POLICY_CLASS_NAME = "policyClassName"
    POLICY_DEST_DN = "policyDestDn"
    POLICY_DN = "policyDn"
    POLICY_LEVEL = "policyLevel"
    POLICY_NAME = "policyName"
    POLICY_OWNER = "policyOwner"
    POLICY_RESOLVE_TYPE = "policyResolveType"
    POLICY_TYPE = "policyType"
    POLL_INTERVAL = "pollInterval"
    POLL_INTERVAL_SECONDS = "pollIntervalSeconds"
    POLLING_INTERVAL = "pollingInterval"
    POLLING_STATE = "pollingState"
    POOL_DN = "poolDn"
    POOL_NAME = "poolName"
    POOL_ORG_DN = "poolOrgDn"
    POOL_TYPE = "poolType"
    POOLABLE_DN = "poolableDn"
    POOLED_ID = "pooledId"
    POOLED_RESOURCES = "pooledResources"
    POP_ERRORS = "popErrors"
    POP_ERRORS_DELTA = "popErrorsDelta"
    POP_ERRORS_DELTA_AVG = "popErrorsDeltaAvg"
    POP_ERRORS_DELTA_MAX = "popErrorsDeltaMax"
    POP_ERRORS_DELTA_MIN = "popErrorsDeltaMin"
    POPULATED = "populated"
    PORT = "port"
    PORT_CAPABILITY = "portCapability"
    PORT_DISC_POLICY_NAME = "portDiscPolicyName"
    PORT_DOWN_IO_RETRY_COUNT = "portDownIoRetryCount"
    PORT_DOWN_TIMEOUT = "portDownTimeout"
    PORT_ID = "portId"
    PORT_MODE = "portMode"
    POST_ACTION = "postAction"
    POWER = "power"
    POWER_AVAIL_STATE = "powerAvailState"
    POWER_AVG = "powerAvg"
    POWER_CYCLE_COUNT = "powerCycleCount"
    POWER_CYCLE_COUNT_AVG = "powerCycleCountAvg"
    POWER_CYCLE_COUNT_MAX = "powerCycleCountMax"
    POWER_CYCLE_COUNT_MIN = "powerCycleCountMin"
    POWER_ENDPOINT = "powerEndpoint"
    POWER_MAX = "powerMax"
    POWER_MIN = "powerMin"
    POWER_ON_DEPLOY = "powerOnDeploy"
    POWER_ON_HOURS = "powerOnHours"
    POWER_ON_HOURS_AVG = "powerOnHoursAvg"
    POWER_ON_HOURS_MAX = "powerOnHoursMax"
    POWER_ON_HOURS_MIN = "powerOnHoursMin"
    POWER_POLICY_NAME = "powerPolicyName"
    POWER_STATE = "powerState"
    POWER_STATE_QUALIFIER = "powerStateQualifier"
    POWER_SYNC_POLICY_NAME = "powerSyncPolicyName"
    POWER_USAGE = "powerUsage"
    PPP_PACKETS = "pppPackets"
    PPP_PACKETS_DELTA = "pppPacketsDelta"
    PPP_PACKETS_DELTA_AVG = "pppPacketsDeltaAvg"
    PPP_PACKETS_DELTA_MAX = "pppPacketsDeltaMax"
    PPP_PACKETS_DELTA_MIN = "pppPacketsDeltaMin"
    PRE_DISCOVERY_POWER = "preDiscoveryPower"
    PREF = "pref"
    PREFERRED_LUN_MASK_ID = "preferredLunMaskId"
    PREFIX = "prefix"
    PRESENCE = "presence"
    PRESERVE_CONFIG = "preserveConfig"
    PRESERVE_POOLED_VALUES = "preservePooledValues"
    PREV_ASSIGNED_TO_DN = "prevAssignedToDn"
    PREV_IDENT_REQUEST_DN = "prevIdentRequestDn"
    PREV_OPER_STATE = "prevOperState"
    PREV_SEVERITY = "prevSeverity"
    PREV_VERSION = "prevVersion"
    PRIM_DNS = "primDns"
    PRIMARY_SERVER = "primaryServer"
    PRIMARY_SLOT_NUMBER = "primarySlotNumber"
    PRIO = "prio"
    PRIORITY = "priority"
    PRIV = "priv"
    PRIV_PWD_SET = "privPwdSet"
    PRIVPWD = "privpwd"
    PROBLEMS = "problems"
    PROC_BREAK = "procBreak"
    PROC_CAP = "procCap"
    PROCESSOR_DN = "processorDn"
    PROCESSOR_NAME = "processorName"
    PROCESSOR_THERMAL_STATE = "processorThermalState"
    PROCESSOR_VERSION = "processorVersion"
    PRODUCT_FAMILY = "productFamily"
    PRODUCT_INSTANCE_NAME = "productInstanceName"
    PRODUCT_VERSION = "productVersion"
    PROF_METHOD = "profMethod"
    PROFILE_DN = "profileDn"
    PROFILE_ID = "profileId"
    PROFILE_NAME = "profileName"
    PROFILE_RUN_TIME = "profileRunTime"
    PROFILE_SCOPE_DN_CNT = "profileScopeDnCnt"
    PROFILE_TYPE = "profileType"
    PROFILED_BOOT = "profiledBoot"
    PROFILED_MAX = "profiledMax"
    PROFILED_MIN = "profiledMin"
    PROFILING = "profiling"
    PROGRESS = "progress"
    PROM_CARD_TYPE = "promCardType"
    PROP_ID = "propId"
    PROP_OID = "propOid"
    PROP_TYPE = "propType"
    PROT = "prot"
    PROT_PEER_ID = "protPeerId"
    PROT_ROLE = "protRole"
    PROT_STATE = "protState"
    PROTECT_CONFIG = "protectConfig"
    PROTECTION = "protection"
    PROTO = "proto"
    PROTOCOL = "protocol"
    PROV_SRV_POLICY_NAME = "provSrvPolicyName"
    PROVIDER_GROUP = "providerGroup"
    PROXY_DN = "proxyDn"
    PROXY_PWD = "proxyPwd"
    PROXY_PWD_SET = "proxyPwdSet"
    PROXY_URL = "proxyUrl"
    PROXY_USER = "proxyUser"
    PSU_CAPACITY = "psuCapacity"
    PSU_CTRLR_INLET1 = "psuCtrlrInlet1"
    PSU_CTRLR_INLET1_AVG = "psuCtrlrInlet1Avg"
    PSU_CTRLR_INLET1_MAX = "psuCtrlrInlet1Max"
    PSU_CTRLR_INLET1_MIN = "psuCtrlrInlet1Min"
    PSU_CTRLR_INLET2 = "psuCtrlrInlet2"
    PSU_CTRLR_INLET2_AVG = "psuCtrlrInlet2Avg"
    PSU_CTRLR_INLET2_MAX = "psuCtrlrInlet2Max"
    PSU_CTRLR_INLET2_MIN = "psuCtrlrInlet2Min"
    PSU_FIRMWARE_VERSION = "psuFirmwareVersion"
    PSU_INPUT_SRC = "psuInputSrc"
    PSU_LINE_MODE = "psuLineMode"
    PSU_STATE = "psuState"
    PSU_TEMP1 = "psuTemp1"
    PSU_TEMP2 = "psuTemp2"
    PSU_TYPE = "psuType"
    PSU_WATTAGE = "psuWattage"
    PUB_NW_DN = "pubNwDn"
    PUB_NW_ID = "pubNwId"
    PUB_NW_NAME = "pubNwName"
    PURGE_WINDOW = "purgeWindow"
    PURPOSE = "purpose"
    PUSH_ERRORS = "pushErrors"
    PUSH_ERRORS_DELTA = "pushErrorsDelta"
    PUSH_ERRORS_DELTA_AVG = "pushErrorsDeltaAvg"
    PUSH_ERRORS_DELTA_MAX = "pushErrorsDeltaMax"
    PUSH_ERRORS_DELTA_MIN = "pushErrorsDeltaMin"
    PWD = "pwd"
    PWD_CHANGE_COUNT = "pwdChangeCount"
    PWD_CHANGE_INTERVAL_BEGIN = "pwdChangeIntervalBegin"
    PWD_CHANGED_DATE = "pwdChangedDate"
    PWD_HISTORY = "pwdHistory"
    PWD_LIFE_TIME = "pwdLifeTime"
    PWD_SET = "pwdSet"
    PWD_STRENGTH_CHECK = "pwdStrengthCheck"
    PWR_CHANGE_SRC = "pwrChangeSrc"
    QOS_CONTROL = "qosControl"
    QOS_POLICY_DN = "qosPolicyDn"
    QOS_POLICY_ID = "qosPolicyId"
    QOS_POLICY_NAME = "qosPolicyName"
    QOSCLASS_DEFINITION_NAME = "qosclassDefinitionName"
    QUALIFIER = "qualifier"
    QUANT = "quant"
    QUERIER_IP_ADDR = "querierIpAddr"
    QUERIER_IP_ADDR_PEER = "querierIpAddrPeer"
    QUERIER_STATE = "querierState"
    QUERY_ID = "queryId"
    QUERY_STATUS = "queryStatus"
    QUEUE_PAIRS = "queuePairs"
    RACK_BUNDLE_NAME = "rackBundleName"
    RACK_BUNDLE_VERSION = "rackBundleVersion"
    RACK_SERVER_ADAPTER_ID = "rackServerAdapterId"
    RACK_SERVER_ID = "rackServerId"
    RACK_VERSION = "rackVersion"
    RAID_BATTERY_OPS = "raidBatteryOps"
    RAID_HEALTH = "raidHealth"
    RAID_LEVEL = "raidLevel"
    RAID_MODE = "raidMode"
    RAID_STATE = "raidState"
    RAID_SUPPORT = "raidSupport"
    RAID_SYNC_SUPPORT = "raidSyncSupport"
    RATE = "rate"
    RAW_SIZE = "rawSize"
    RAW_TYPE_DESC = "rawTypeDesc"
    RCV = "rcv"
    RCV_DELTA = "rcvDelta"
    RCV_DELTA_AVG = "rcvDeltaAvg"
    RCV_DELTA_MAX = "rcvDeltaMax"
    RCV_DELTA_MIN = "rcvDeltaMin"
    RDEV = "rdev"
    REACHABILITY = "reachability"
    READ_ERROR_THRESHOLD = "readErrorThreshold"
    READ_IOERROR_COUNT = "readIOErrorCount"
    READ_IOPS = "readIops"
    READ_IOPS_AVG = "readIopsAvg"
    READ_IOPS_MAX = "readIopsMax"
    READ_IOPS_MIN = "readIopsMin"
    READ_MBPS = "readMbps"
    READ_MBPS_AVG = "readMbpsAvg"
    READ_MBPS_MAX = "readMbpsMax"
    READ_MBPS_MIN = "readMbpsMin"
    READ_POLICY = "readPolicy"
    READ_SPEED = "readSpeed"
    READY = "ready"
    REALLOC = "realloc"
    REALM = "realm"
    REALTIME_RECORDS = "realtimeRecords"
    REAR_TEMP = "rearTemp"
    REAR_TEMP_AVG = "rearTempAvg"
    REAR_TEMP_MAX = "rearTempMax"
    REAR_TEMP_MIN = "rearTempMin"
    REBALANCE = "rebalance"
    REBOOT_ON_UPDATE = "rebootOnUpdate"
    REBOOT_REASON = "rebootReason"
    REBOOT_REQUIRED = "rebootRequired"
    REBUILD_PROGRESS = "rebuildProgress"
    REBUILD_RATE = "rebuildRate"
    RECEIVE_SIDE_SCALING = "receiveSideScaling"
    RECOVERY_ACTION = "recoveryAction"
    RECURSIVE = "recursive"
    RECV_PAUSE = "recvPause"
    RECV_PAUSE_DELTA = "recvPauseDelta"
    RECV_PAUSE_DELTA_AVG = "recvPauseDeltaAvg"
    RECV_PAUSE_DELTA_MAX = "recvPauseDeltaMax"
    RECV_PAUSE_DELTA_MIN = "recvPauseDeltaMin"
    REDIRECT_STATE = "redirectState"
    REDUNDANCY = "redundancy"
    REDUNDANCY_PAIR_TYPE = "redundancyPairType"
    REDUNDANCY_PEER = "redundancyPeer"
    REF_CONVERTED_DN = "refConvertedDn"
    REF_DN = "refDn"
    REF_DN_TYPE = "refDnType"
    REF_ITEM_ID = "refItemId"
    REF_NAME = "refName"
    REF_OBJ_STATUS = "refObjStatus"
    REFRESH = "refresh"
    REFRESH_COUNT = "refreshCount"
    REFRESH_IMMEDIATE_FLAG = "refreshImmediateFlag"
    REFRESH_PERIOD = "refreshPeriod"
    REFRESH_STATE = "refreshState"
    REG_COUNT = "regCount"
    REGEN = "regen"
    REGEX = "regex"
    REGISTER_INITIAL_TIME = "registerInitialTime"
    REGISTER_RENEW_INITIAL_TIME = "registerRenewInitialTime"
    REGISTER_RENEW_NEXT_TIME = "registerRenewNextTime"
    REGISTRATION_EXPIRE_TIME = "registrationExpireTime"
    REGISTRATION_FAILURE_STRING = "registrationFailureString"
    REGISTRATION_STATE = "registrationState"
    REGISTRATION_STATUS = "registrationStatus"
    REGISTRATION_STATUS_STRING = "registrationStatusString"
    RELATIONSHIP = "relationship"
    RELAY_APP_RESPONSE_COUNT = "relayAppResponseCount"
    REMOTE = "remote"
    REMOTE_ADMIN_STATE = "remoteAdminState"
    REMOTE_BACKUP_OPER_STATE = "remoteBackupOperState"
    REMOTE_DIR = "remoteDir"
    REMOTE_EP_REF = "remoteEpRef"
    REMOTE_ERROR_CODE = "remoteErrorCode"
    REMOTE_ERROR_DESCR = "remoteErrorDescr"
    REMOTE_FAIL_OVER_STATE = "remoteFailOverState"
    REMOTE_FILE = "remoteFile"
    REMOTE_FLT_AGGR = "remoteFltAggr"
    REMOTE_HOST = "remoteHost"
    REMOTE_IP_ADDR = "remoteIpAddr"
    REMOTE_IP_ADDRESS = "remoteIpAddress"
    REMOTE_PATH = "remotePath"
    REMOTE_PORT = "remotePort"
    REMOVABLE = "removable"
    RENEW_ENTITLEMENT = "renewEntitlement"
    RENEW_FAILURE_STRING = "renewFailureString"
    RENEW_ID_CERTIFICATE = "renewIdCertificate"
    RENEW_INITIAL_TIME = "renewInitialTime"
    RENEW_NEXT_TIME = "renewNextTime"
    RENEW_STATUS = "renewStatus"
    REPAIR_STATE = "repairState"
    REPLACED_ACQUIRER = "replacedAcquirer"
    REPLICA = "replica"
    REPLICATE_IF_NO_CHILD = "replicateIfNoChild"
    REPLY_TO = "replyTo"
    REPORT_ALL = "reportAll"
    REPORT_COMPLETION_TIME = "reportCompletionTime"
    REPORT_DN = "reportDn"
    REPORT_ERROR_CODE = "reportErrorCode"
    REPORT_GENERATION_STATUS = "reportGenerationStatus"
    REPORT_ID_TOKEN = "reportIdToken"
    REPORT_NAME = "reportName"
    REPORT_START_TIME = "reportStartTime"
    REPORTING_INTERVAL = "reportingInterval"
    REPOSITORY_IP = "repositoryIp"
    REPOSITORY_NAME = "repositoryName"
    REQ = "req"
    REQ_DN = "reqDn"
    REQ_ID = "reqId"
    REQUEST_DN = "requestDn"
    REQUEST_SIZE = "requestSize"
    REQUESTED_TIME = "requestedTime"
    REQUESTOR_OWNERSHIP = "requestorOwnership"
    RES_PROB = "resProb"
    RESELECT_POLICY = "reselectPolicy"
    RESERVED_POWER = "reservedPower"
    RESERVED_POWER_AVG = "reservedPowerAvg"
    RESERVED_POWER_MAX = "reservedPowerMax"
    RESERVED_POWER_MIN = "reservedPowerMin"
    RESET_LOG_CONTROL_DOMAIN = "resetLogControlDomain"
    RESET_LOG_CONTROL_EP = "resetLogControlEp"
    RESET_LOG_CONTROL_MODULE = "resetLogControlModule"
    RESET_ON_ACTIVATE = "resetOnActivate"
    RESET_TRIGGER = "resetTrigger"
    RESETS = "resets"
    RESETS_DELTA = "resetsDelta"
    RESETS_DELTA_AVG = "resetsDeltaAvg"
    RESETS_DELTA_MAX = "resetsDeltaMax"
    RESETS_DELTA_MIN = "resetsDeltaMin"
    RESOLVE_REMOTE = "resolveRemote"
    RESOLVE_TYPE = "resolveType"
    RESOURCE_ALLOCATION_TIMEOUT = "resourceAllocationTimeout"
    RESOURCE_DEST_DN = "resourceDestDn"
    RESOURCE_GROUPS = "resourceGroups"
    RESTARTABLE = "restartable"
    RESTORED_TABS = "restoredTabs"
    RESTRICT_MIGRATION = "restrictMigration"
    RESTRICTED = "restricted"
    RESULT = "result"
    RET_STATUS = "retStatus"
    RETENTION_INTERVAL = "retentionInterval"
    RETRIED = "retried"
    RETRIES = "retries"
    RETRY = "retry"
    RETRY_COUNT = "retryCount"
    RETRY_DELAY_MINUTES = "retryDelayMinutes"
    RETRY_INTERVAL = "retryInterval"
    RETRY_ON_MOUNT_FAIL = "retryOnMountFail"
    REVERT_TIMEOUT = "revertTimeout"
    REVISION = "revision"
    RIGHT_INLET_TEMP = "rightInletTemp"
    RIGHT_INLET_TEMP_AVG = "rightInletTempAvg"
    RIGHT_INLET_TEMP_MAX = "rightInletTempMax"
    RIGHT_INLET_TEMP_MIN = "rightInletTempMin"
    RIGHT_OUTLET_TEMP = "rightOutletTemp"
    RIGHT_OUTLET_TEMP_AVG = "rightOutletTempAvg"
    RIGHT_OUTLET_TEMP_MAX = "rightOutletTempMax"
    RIGHT_OUTLET_TEMP_MIN = "rightOutletTempMin"
    RING_SIZE = "ringSize"
    RMT_DISK_CFG_NAME = "rmtDiskCfgName"
    RMT_ERR_CODE = "rmtErrCode"
    RMT_ERR_DESCR = "rmtErrDescr"
    RMT_RSLT = "rmtRslt"
    RN = "rn"
    ROLE = "role"
    ROOTDN = "rootdn"
    ROTATIONAL_SPEED = "rotationalSpeed"
    RSLT_STATUS = "rsltStatus"
    RULE = "rule"
    RULE_APPLIED_COUNTER = "ruleAppliedCounter"
    RUN_POLICY_NAME = "runPolicyName"
    RUN_POLICY_NAME_OPERATION = "runPolicyNameOperation"
    RX = "rx"
    RX_BAD_FRAMES = "rxBadFrames"
    RX_BAD_FRAMES_DELTA = "rxBadFramesDelta"
    RX_BAD_FRAMES_DELTA_AVG = "rxBadFramesDeltaAvg"
    RX_BAD_FRAMES_DELTA_MAX = "rxBadFramesDeltaMax"
    RX_BAD_FRAMES_DELTA_MIN = "rxBadFramesDeltaMin"
    RX_BYTES = "rxBytes"
    RX_BYTES_DELTA = "rxBytesDelta"
    RX_BYTES_DELTA_AVG = "rxBytesDeltaAvg"
    RX_BYTES_DELTA_MAX = "rxBytesDeltaMax"
    RX_BYTES_DELTA_MIN = "rxBytesDeltaMin"
    RX_DELTA = "rxDelta"
    RX_DELTA_AVG = "rxDeltaAvg"
    RX_DELTA_MAX = "rxDeltaMax"
    RX_DELTA_MIN = "rxDeltaMin"
    RX_DROPPED = "rxDropped"
    RX_DROPPED_DELTA = "rxDroppedDelta"
    RX_DROPPED_DELTA_AVG = "rxDroppedDeltaAvg"
    RX_DROPPED_DELTA_MAX = "rxDroppedDeltaMax"
    RX_DROPPED_DELTA_MIN = "rxDroppedDeltaMin"
    RX_ERRORS = "rxErrors"
    RX_ERRORS_DELTA = "rxErrorsDelta"
    RX_ERRORS_DELTA_AVG = "rxErrorsDeltaAvg"
    RX_ERRORS_DELTA_MAX = "rxErrorsDeltaMax"
    RX_ERRORS_DELTA_MIN = "rxErrorsDeltaMin"
    RX_FRAMES = "rxFrames"
    RX_FRAMES_DELTA = "rxFramesDelta"
    RX_FRAMES_DELTA_AVG = "rxFramesDeltaAvg"
    RX_FRAMES_DELTA_MAX = "rxFramesDeltaMax"
    RX_FRAMES_DELTA_MIN = "rxFramesDeltaMin"
    RX_PACKETS = "rxPackets"
    RX_PACKETS_DELTA = "rxPacketsDelta"
    RX_PACKETS_DELTA_AVG = "rxPacketsDeltaAvg"
    RX_PACKETS_DELTA_MAX = "rxPacketsDeltaMax"
    RX_PACKETS_DELTA_MIN = "rxPacketsDeltaMin"
    RX_PAUSE_CFC = "rxPauseCFC"
    RX_PAUSE_CFCDELTA = "rxPauseCFCDelta"
    RX_PAUSE_CFCDELTA_AVG = "rxPauseCFCDeltaAvg"
    RX_PAUSE_CFCDELTA_MAX = "rxPauseCFCDeltaMax"
    RX_PAUSE_CFCDELTA_MIN = "rxPauseCFCDeltaMin"
    RX_PAUSE_PFC = "rxPausePFC"
    RX_PAUSE_PFCDELTA = "rxPausePFCDelta"
    RX_PAUSE_PFCDELTA_AVG = "rxPausePFCDeltaAvg"
    RX_PAUSE_PFCDELTA_MAX = "rxPausePFCDeltaMax"
    RX_PAUSE_PFCDELTA_MIN = "rxPausePFCDeltaMin"
    SAN_CONN_POLICY_NAME = "sanConnPolicyName"
    SAS_ADDRESS = "sasAddress"
    SAVED_QUERIES = "savedQueries"
    SCALED_MODE = "scaledMode"
    SCALED_WT = "scaledWt"
    SCAN_COMPLETED = "scanCompleted"
    SCAN_ENABLED = "scanEnabled"
    SCHED_DATE = "schedDate"
    SCHED_MODE = "schedMode"
    SCHED_NAME = "schedName"
    SCHED_TYPE = "schedType"
    SCHEDULE = "schedule"
    SCHEDULE_STATUS = "scheduleStatus"
    SCHEDULER = "scheduler"
    SCOPE = "scope"
    SCOPE_DN = "scopeDn"
    SCOPE_STATUS = "scopeStatus"
    SCORE = "score"
    SCRUB = "scrub"
    SCRUB_POLICY_NAME = "scrubPolicyName"
    SCSI_DISK_STATE = "scsiDiskState"
    SEARCH_TYPE = "searchType"
    SEC_DNS = "secDns"
    SECONDARY_KEY = "secondaryKey"
    SECONDARY_SERVER = "secondaryServer"
    SECONDS_SINCE_LAST_RESET = "secondsSinceLastReset"
    SECONDS_SINCE_LAST_RESET_DELTA = "secondsSinceLastResetDelta"
    SECONDS_SINCE_LAST_RESET_DELTA_AVG = "secondsSinceLastResetDeltaAvg"
    SECONDS_SINCE_LAST_RESET_DELTA_MAX = "secondsSinceLastResetDeltaMax"
    SECONDS_SINCE_LAST_RESET_DELTA_MIN = "secondsSinceLastResetDeltaMin"
    SECRET = "secret"
    SECURE_BOOT = "secureBoot"
    SECURITY = "security"
    SECURITY_FLAGS = "securityFlags"
    SECURITY_KEY = "securityKey"
    SEEK_AVERAGE_READ_WRITE = "seekAverageReadWrite"
    SEEK_TRACK_TO_TRACK_READ_WRITE = "seekTrackToTrackReadWrite"
    SEEPROM_OPER_STATE = "seepromOperState"
    SELECT = "select"
    SELF_ENCRYPTING_DRIVE = "selfEncryptingDrive"
    SEND_NOW = "sendNow"
    SEND_NOW_REQUEST = "sendNowRequest"
    SENSITIVITY = "sensitivity"
    SEQ_ID = "seqId"
    SEQ_NUM = "seqNum"
    SEQ_PROTOCOL_ERR_COUNT = "seqProtocolErrCount"
    SEQ_PROTOCOL_ERR_COUNT_DELTA = "seqProtocolErrCountDelta"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_AVG = "seqProtocolErrCountDeltaAvg"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_MAX = "seqProtocolErrCountDeltaMax"
    SEQ_PROTOCOL_ERR_COUNT_DELTA_MIN = "seqProtocolErrCountDeltaMin"
    SERIAL = "serial"
    SERIES = "series"
    SERVER = "server"
    SERVER_CERT = "serverCert"
    SERVER_COMPONENT = "serverComponent"
    SERVER_CONFIG_ISSUES = "serverConfigIssues"
    SERVER_DN = "serverDn"
    SERVER_ID = "serverId"
    SERVER_ID_LIST = "serverIdList"
    SERVER_INSTANCE_ID = "serverInstanceId"
    SERVER_LOCATION_ID = "serverLocationId"
    SERVER_MODEL = "serverModel"
    SERVER_PID = "serverPid"
    SERVER_SIOC_CONNECTIVITY = "serverSiocConnectivity"
    SERVERS_AFFECTED = "serversAffected"
    SERVICE = "service"
    SERVICE_PACK_BUNDLE_NAME = "servicePackBundleName"
    SERVICE_PACK_BUNDLE_VERSION = "servicePackBundleVersion"
    SERVICE_PACK_VERSION = "servicePackVersion"
    SERVICE_PROFILE = "serviceProfile"
    SERVICE_PROFILE_AFFECTED = "serviceProfileAffected"
    SERVICE_PROFILE_DN = "serviceProfileDn"
    SERVICE_PROFILE_LOST_VISIBILITY = "serviceProfileLostVisibility"
    SERVICE_PROFILE_NAME = "serviceProfileName"
    SERVICE_PROFILE_OWNER = "serviceProfileOwner"
    SERVICE_PROFILE_SUSPEND = "serviceProfileSuspend"
    SERVICE_PROFILE_TIMED_OUT = "serviceProfileTimedOut"
    SERVICE_STATE = "serviceState"
    SESSION = "session"
    SESSION_ID = "sessionId"
    SESSION_STATE = "sessionState"
    SESSION_TIMEOUT = "sessionTimeout"
    SESSIONS_PER_USER = "sessionsPerUser"
    SET = "set"
    SETTINGS_MO_RN = "settingsMoRn"
    SEVERITY = "severity"
    SHARE = "share"
    SHARED_FW_MANAGING_INST = "sharedFwManagingInst"
    SHARED_SECRET_PUSH_STATE = "sharedSecretPushState"
    SHARING = "sharing"
    SHOW_AGENT_TECH_SUPPORT = "showAgentTechSupport"
    SHUTDOWN_FAN_REMOVEAL = "shutdownFanRemoveal"
    SIDE = "side"
    SIG = "sig"
    SIGNAL_LOSSES = "signalLosses"
    SIGNAL_LOSSES_DELTA = "signalLossesDelta"
    SIGNAL_LOSSES_DELTA_AVG = "signalLossesDeltaAvg"
    SIGNAL_LOSSES_DELTA_MAX = "signalLossesDeltaMax"
    SIGNAL_LOSSES_DELTA_MIN = "signalLossesDeltaMin"
    SIGNATURE = "signature"
    SIM_COOKIE = "simCookie"
    SIM_ERROR_MSG = "simErrorMsg"
    SIM_FSM_STAGE_NAME = "simFsmStageName"
    SIM_IS_RESPONSED = "simIsResponsed"
    SIM_REQUEST_TIME = "simRequestTime"
    SIM_STATUS = "simStatus"
    SINGLE_COLLISION = "singleCollision"
    SINGLE_COLLISION_DELTA = "singleCollisionDelta"
    SINGLE_COLLISION_DELTA_AVG = "singleCollisionDeltaAvg"
    SINGLE_COLLISION_DELTA_MAX = "singleCollisionDeltaMax"
    SINGLE_COLLISION_DELTA_MIN = "singleCollisionDeltaMin"
    SINGLETON = "singleton"
    SITE = "site"
    SIZE = "size"
    SIZE_LIMIT = "sizeLimit"
    SKIP_POWER_CHECK = "skipPowerCheck"
    SKIP_POWER_DEPLOY_CHECK = "skipPowerDeployCheck"
    SKIP_PROFILING = "skipProfiling"
    SKIP_VALIDATION = "skipValidation"
    SKU = "sku"
    SLAVE_SLOT_ID = "slaveSlotId"
    SLOT_ADMIN_STATE = "slotAdminState"
    SLOT_DN = "slotDn"
    SLOT_ID = "slotId"
    SLOT_NUM = "slotNum"
    SLOT_NUMBER = "slotNumber"
    SMART_ACCOUNT = "smartAccount"
    SMI_LINK_CORR_ERRORS = "smiLinkCorrErrors"
    SMI_LINK_CORR_ERRORS_AVG = "smiLinkCorrErrorsAvg"
    SMI_LINK_CORR_ERRORS_MAX = "smiLinkCorrErrorsMax"
    SMI_LINK_CORR_ERRORS_MIN = "smiLinkCorrErrorsMin"
    SMI_LINK_CORR_ERRORS_RUNNING = "smiLinkCorrErrorsRunning"
    SMI_LINK_UNCORR_ERRORS = "smiLinkUncorrErrors"
    SMI_LINK_UNCORR_ERRORS_AVG = "smiLinkUncorrErrorsAvg"
    SMI_LINK_UNCORR_ERRORS_MAX = "smiLinkUncorrErrorsMax"
    SMI_LINK_UNCORR_ERRORS_MIN = "smiLinkUncorrErrorsMin"
    SMI_LINK_UNCORR_ERRORS_RUNNING = "smiLinkUncorrErrorsRunning"
    SNAP_PERCENT = "snapPercent"
    SNAPSHOT = "snapshot"
    SNAPSHOT_ADMIN_STATE = "snapshotAdminState"
    SND = "snd"
    SNOOPING_STATE = "snoopingState"
    SOAK_INTERVAL = "soakInterval"
    SOAKING_SEVERITY = "soakingSeverity"
    SOCKET_DESIGNATION = "socketDesignation"
    SOFT_SHUTDOWN_TIMER = "softShutdownTimer"
    SOFTWARE_TYPE_ID = "softwareTypeId"
    SOL_POLICY_NAME = "solPolicyName"
    SORT_CLASS = "sortClass"
    SORT_PROP = "sortProp"
    SOURCE = "source"
    SOURCE_ADDR = "sourceAddr"
    SOURCE_CONNECTOR_ID = "sourceConnectorId"
    SOURCE_DME = "sourceDme"
    SOURCE_DN = "sourceDn"
    SOURCE_LUN = "sourceLun"
    SOURCE_MO_DN = "sourceMoDn"
    SOURCE_TYPE = "sourceType"
    SP_DN = "spDn"
    SP_REFRESH = "spRefresh"
    SPAN_ID = "spanId"
    SPARING_ERRORS = "sparingErrors"
    SPARING_ERRORS_AVG = "sparingErrorsAvg"
    SPARING_ERRORS_MAX = "sparingErrorsMax"
    SPARING_ERRORS_MIN = "sparingErrorsMin"
    SPARING_ERRORS_RUNNING = "sparingErrorsRunning"
    SPEED = "speed"
    SPEED_AVG = "speedAvg"
    SPEED_MAX = "speedMax"
    SPEED_MIN = "speedMin"
    SRC_ADDR_FMT = "srcAddrFmt"
    SRC_DME = "srcDme"
    SRC_LUN_ADDR = "srcLunAddr"
    SRC_LUN_DN = "srcLunDn"
    SRC_LUN_NAME = "srcLunName"
    SRC_MO_CLASS_NAME = "srcMoClassName"
    SRC_MO_DN = "srcMoDn"
    SRC_MO_RN = "srcMoRn"
    SRC_POLICY_DN = "srcPolicyDn"
    SRC_TEMPL_NAME = "srcTemplName"
    SRC_TEMPLATE_DN = "srcTemplateDn"
    SSH_AUTH_KEYS_CSUM = "sshAuthKeysCsum"
    SSH_AUTH_KEYS_SIZE = "sshAuthKeysSize"
    SSH_KEY_STATUS = "sshKeyStatus"
    SSH_ROOT_PUB_KEY_CSUM = "sshRootPubKeyCsum"
    SSH_ROOT_PUB_KEY_SIZE = "sshRootPubKeySize"
    STAGE_SIZE = "stageSize"
    STAGE_STATUS = "stageStatus"
    START_DATE = "startDate"
    START_PORT_ID = "startPortId"
    START_REQUEST = "startRequest"
    START_SLOT_NUM = "startSlotNum"
    START_TIME = "startTime"
    START_TS = "startTs"
    START_TS_M = "startTsM"
    STATE = "state"
    STATE_QUAL = "stateQual"
    STATS_CLASS_ID = "statsClassId"
    STATS_POLICY_NAME = "statsPolicyName"
    STATS_REPORTED = "statsReported"
    STATUS = "status"
    STATUS_CHANGE_TS = "statusChangeTs"
    STATUS_DESCR = "statusDescr"
    STATUS_DESCRIPTION = "statusDescription"
    STATUS_REPORT = "statusReport"
    STEPPING = "stepping"
    STORAGE_BUNDLE = "storageBundle"
    STORAGE_BUNDLE_NAME = "storageBundleName"
    STORAGE_BUNDLE_VERSION = "storageBundleVersion"
    STORAGE_CLASS = "storageClass"
    STORAGE_CONFIG_ISSUES = "storageConfigIssues"
    STORAGE_CONN_POLICY_NAME = "storageConnPolicyName"
    STORAGE_DN = "storageDn"
    STORAGE_JBOD_MODE_SUPPORTED = "storageJbodModeSupported"
    STORAGE_PROFILE = "storageProfile"
    STORAGE_PROFILE_NAME = "storageProfileName"
    STORAGE_SCRUB = "storageScrub"
    STORAGE_TYPE = "storageType"
    STR_TYPE = "strType"
    STRIP_SIZE = "stripSize"
    STYLE = "style"
    SUB_DEVICE_ID = "subDeviceId"
    SUB_OEM_ID = "subOemId"
    SUB_VENDOR_ID = "subVendorId"
    SUBDEVICE = "subdevice"
    SUBJ_NAME = "subjName"
    SUBJECT = "subject"
    SUBNET = "subnet"
    SUBSCRIBE_STATUS = "subscribeStatus"
    SUBVENDOR = "subvendor"
    SUCCESS_ACTION = "successAction"
    SUCCESSFULL = "successfull"
    SUFFIX = "suffix"
    SUPPL_ID1 = "supplId1"
    SUPPL_ID2 = "supplId2"
    SUPPL_ID3 = "supplId3"
    SUPPL_ID4 = "supplId4"
    SUPPORTED_ALGORITHM = "supportedAlgorithm"
    SUPPORTED_BY_DEFAULT = "supportedByDefault"
    SUPPORTED_CAPABILITY = "supportedCapability"
    SUPPORTED_STRIP_SIZES = "supportedStripSizes"
    SURPRISE_LINK_DOWN_ERRORS = "surpriseLinkDownErrors"
    SURPRISE_LINK_DOWN_ERRORS_AVG = "surpriseLinkDownErrorsAvg"
    SURPRISE_LINK_DOWN_ERRORS_MAX = "surpriseLinkDownErrorsMax"
    SURPRISE_LINK_DOWN_ERRORS_MIN = "surpriseLinkDownErrorsMin"
    SURPRISE_LINK_DOWN_ERRORS_RUNNING = "surpriseLinkDownErrorsRunning"
    SUSPECT = "suspect"
    SUSPEND_INDIVIDUAL = "suspendIndividual"
    SUSPEND_STATE = "suspendState"
    SVC_REG_IP = "svcRegIP"
    SVC_REG_NAME = "svcRegName"
    SWITCH_ID = "switchId"
    SYMBOL = "symbol"
    SYMBOL_DELTA = "symbolDelta"
    SYMBOL_DELTA_AVG = "symbolDeltaAvg"
    SYMBOL_DELTA_MAX = "symbolDeltaMax"
    SYMBOL_DELTA_MIN = "symbolDeltaMin"
    SYNC_INVENTORY_FROM_SM = "syncInventoryFromSM"
    SYNC_LOSSES = "syncLosses"
    SYNC_LOSSES_DELTA = "syncLossesDelta"
    SYNC_LOSSES_DELTA_AVG = "syncLossesDeltaAvg"
    SYNC_LOSSES_DELTA_MAX = "syncLossesDeltaMax"
    SYNC_LOSSES_DELTA_MIN = "syncLossesDeltaMin"
    SYNC_OPTION = "syncOption"
    SYNC_STATE = "syncState"
    SYNC_STATUS = "syncStatus"
    SYS_CNT = "sysCnt"
    SYS_CONTACT = "sysContact"
    SYS_ID = "sysId"
    SYS_LOCATION = "sysLocation"
    SYS_NAME = "sysName"
    SYSID = "sysid"
    SYSTEM_DEFINED = "systemDefined"
    SYSTEM_ID = "systemId"
    SYSTEM_NAME = "systemName"
    SYSTEM_ORG = "systemOrg"
    SYSTEM_UP_TIME = "systemUpTime"
    TAB_RESTORE_MODE = "tabRestoreMode"
    TAG = "tag"
    TAG_NAME = "tagName"
    TAGGED_OBJECT_DN = "taggedObjectDn"
    TAGS = "tags"
    TARGET = "target"
    TARGET_ATTR = "targetAttr"
    TARGET_BLADE_FIRMWARE_VERSION = "targetBladeFirmwareVersion"
    TARGET_DN = "targetDn"
    TARGET_FIRMWARE = "targetFirmware"
    TARGET_IP1 = "targetIp1"
    TARGET_IP2 = "targetIp2"
    TARGET_IP3 = "targetIp3"
    TARGET_MODULAR_FIRMWARE_VERSION = "targetModularFirmwareVersion"
    TARGET_RACK_FIRMWARE_VERSION = "targetRackFirmwareVersion"
    TARGET_STATUS = "targetStatus"
    TARGET_TOKEN_NAME = "targetTokenName"
    TARGET_TOKEN_VALUE = "targetTokenValue"
    TARGET_UCSFIRMWARE_VERSION = "targetUCSFirmwareVersion"
    TARGETWWPN = "targetwwpn"
    TCP_HASH = "tcpHash"
    TCP_RX_CHECKSUM = "tcpRxChecksum"
    TCP_SEGMENT = "tcpSegment"
    TCP_TIME_STAMP = "tcpTimeStamp"
    TCP_TX_CHECKSUM = "tcpTxChecksum"
    TECHNOLOGY = "technology"
    TEMP = "temp"
    TEMP_AVG = "tempAvg"
    TEMP_MAX = "tempMax"
    TEMP_MIN = "tempMin"
    TEMPERATURE = "temperature"
    TEMPERATURE_AVG = "temperatureAvg"
    TEMPERATURE_MAX = "temperatureMax"
    TEMPERATURE_MIN = "temperatureMin"
    TEMPL_DN = "templDn"
    TEMPL_TYPE = "templType"
    TEMPLATE_NAME = "templateName"
    TEMPLATE_TYPE = "templateType"
    TERM = "term"
    TEST_DEV_CERT_ENABLE = "testDevCertEnable"
    TEST_DN = "testDn"
    TEST_RESET_EVAL = "testResetEval"
    TEST_TIMER_NAME = "testTimerName"
    TEST_TIMER_VALUE = "testTimerValue"
    TEST_TRANSPORT_MODE = "testTransportMode"
    TEST_TRANSPORT_URL = "testTransportUrl"
    TEST_TYPE = "testType"
    TFTP_URL = "tftpURL"
    TFTP_URI = "tftpUri"
    THERMAL = "thermal"
    THERMAL_ENDPOINT = "thermalEndpoint"
    THERMAL_STATE_QUALIFIER = "thermalStateQualifier"
    THREADS = "threads"
    THRESHOLDED = "thresholded"
    TIME = "time"
    TIME_CAP = "timeCap"
    TIME_COLLECTED = "timeCollected"
    TIME_OF_DAY_HOUR = "timeOfDayHour"
    TIME_OF_DAY_MINUTE = "timeOfDayMinute"
    TIME_OF_LAST_ATTEMPT = "timeOfLastAttempt"
    TIME_OF_LAST_SUCCESS = "timeOfLastSuccess"
    TIME_STAMP = "timeStamp"
    TIMEOUT = "timeout"
    TIMESTAMP = "timestamp"
    TIMEZONE = "timezone"
    TITLE = "title"
    TO = "to"
    TOKEN = "token"
    TOKEN_DN = "tokenDn"
    TOKEN_REQUESTOR_DN = "tokenRequestorDn"
    TOO_LONG_RX = "tooLongRx"
    TOO_LONG_RX_DELTA = "tooLongRxDelta"
    TOO_LONG_RX_DELTA_AVG = "tooLongRxDeltaAvg"
    TOO_LONG_RX_DELTA_MAX = "tooLongRxDeltaMax"
    TOO_LONG_RX_DELTA_MIN = "tooLongRxDeltaMin"
    TOO_SHORT_RX = "tooShortRx"
    TOO_SHORT_RX_DELTA = "tooShortRxDelta"
    TOO_SHORT_RX_DELTA_AVG = "tooShortRxDeltaAvg"
    TOO_SHORT_RX_DELTA_MAX = "tooShortRxDeltaMax"
    TOO_SHORT_RX_DELTA_MIN = "tooShortRxDeltaMin"
    TOP_BOTTOM = "topBottom"
    TOTAL = "total"
    TOTAL_AVG = "totalAvg"
    TOTAL_BYTES = "totalBytes"
    TOTAL_BYTES_DELTA = "totalBytesDelta"
    TOTAL_BYTES_DELTA_AVG = "totalBytesDeltaAvg"
    TOTAL_BYTES_DELTA_MAX = "totalBytesDeltaMax"
    TOTAL_BYTES_DELTA_MIN = "totalBytesDeltaMin"
    TOTAL_COMPONENTS = "totalComponents"
    TOTAL_CONFIGURED = "totalConfigured"
    TOTAL_DATA_PROTECTION = "totalDataProtection"
    TOTAL_FAULTS = "totalFaults"
    TOTAL_MAX = "totalMax"
    TOTAL_MEMORY = "totalMemory"
    TOTAL_MIN = "totalMin"
    TOTAL_PACKETS = "totalPackets"
    TOTAL_PACKETS_DELTA = "totalPacketsDelta"
    TOTAL_PACKETS_DELTA_AVG = "totalPacketsDeltaAvg"
    TOTAL_PACKETS_DELTA_MAX = "totalPacketsDeltaMax"
    TOTAL_PACKETS_DELTA_MIN = "totalPacketsDeltaMin"
    TOTAL_PHYSICAL_CNT = "totalPhysicalCnt"
    TOTAL_POWER = "totalPower"
    TOTAL_POWER_AVG = "totalPowerAvg"
    TOTAL_POWER_MAX = "totalPowerMax"
    TOTAL_POWER_MIN = "totalPowerMin"
    TOTAL_QUANT = "totalQuant"
    TOTAL_REQUESTED = "totalRequested"
    TOTAL_SESSIONS = "totalSessions"
    TOTAL_SLOTS = "totalSlots"
    TP = "tp"
    TR_DN = "trDn"
    TR_ID = "trId"
    TRAFFIC_DIRECTION = "trafficDirection"
    TRANSFER_STATE = "transferState"
    TRANSPORT = "transport"
    TRAVERSAL = "traversal"
    TRAY = "tray"
    TRIG = "trig"
    TRIG_FULL_INVENTORY = "trigFullInventory"
    TRIG_TIME = "trigTime"
    TRIGGER_CONFIG = "triggerConfig"
    TRIGGER_CONFIG_STATE = "triggerConfigState"
    TRIGGER_STATE = "triggerState"
    TRIGGER_STATUS = "triggerStatus"
    TRIGGERABLE_DN = "triggerableDn"
    TRUNCATE_OVERRUN = "truncateOverrun"
    TRUNCATE_OVERRUN_DELTA = "truncateOverrunDelta"
    TRUNCATE_OVERRUN_DELTA_AVG = "truncateOverrunDeltaAvg"
    TRUNCATE_OVERRUN_DELTA_MAX = "truncateOverrunDeltaMax"
    TRUNCATE_OVERRUN_DELTA_MIN = "truncateOverrunDeltaMin"
    TRUNCATE_OVERRUN_N0 = "truncateOverrunN0"
    TRUNCATE_OVERRUN_N0_DELTA = "truncateOverrunN0Delta"
    TRUNCATE_OVERRUN_N0_DELTA_AVG = "truncateOverrunN0DeltaAvg"
    TRUNCATE_OVERRUN_N0_DELTA_MAX = "truncateOverrunN0DeltaMax"
    TRUNCATE_OVERRUN_N0_DELTA_MIN = "truncateOverrunN0DeltaMin"
    TRUNCATE_OVERRUN_N1 = "truncateOverrunN1"
    TRUNCATE_OVERRUN_N1_DELTA = "truncateOverrunN1Delta"
    TRUNCATE_OVERRUN_N1_DELTA_AVG = "truncateOverrunN1DeltaAvg"
    TRUNCATE_OVERRUN_N1_DELTA_MAX = "truncateOverrunN1DeltaMax"
    TRUNCATE_OVERRUN_N1_DELTA_MIN = "truncateOverrunN1DeltaMin"
    TS = "ts"
    TS_CREATED = "tsCreated"
    TX = "tx"
    TX_BAD_FRAMES = "txBadFrames"
    TX_BAD_FRAMES_DELTA = "txBadFramesDelta"
    TX_BAD_FRAMES_DELTA_AVG = "txBadFramesDeltaAvg"
    TX_BAD_FRAMES_DELTA_MAX = "txBadFramesDeltaMax"
    TX_BAD_FRAMES_DELTA_MIN = "txBadFramesDeltaMin"
    TX_BYTES = "txBytes"
    TX_BYTES_DELTA = "txBytesDelta"
    TX_BYTES_DELTA_AVG = "txBytesDeltaAvg"
    TX_BYTES_DELTA_MAX = "txBytesDeltaMax"
    TX_BYTES_DELTA_MIN = "txBytesDeltaMin"
    TX_DELTA = "txDelta"
    TX_DELTA_AVG = "txDeltaAvg"
    TX_DELTA_MAX = "txDeltaMax"
    TX_DELTA_MIN = "txDeltaMin"
    TX_DROPPED = "txDropped"
    TX_DROPPED_DELTA = "txDroppedDelta"
    TX_DROPPED_DELTA_AVG = "txDroppedDeltaAvg"
    TX_DROPPED_DELTA_MAX = "txDroppedDeltaMax"
    TX_DROPPED_DELTA_MIN = "txDroppedDeltaMin"
    TX_ERRORS = "txErrors"
    TX_ERRORS_DELTA = "txErrorsDelta"
    TX_ERRORS_DELTA_AVG = "txErrorsDeltaAvg"
    TX_ERRORS_DELTA_MAX = "txErrorsDeltaMax"
    TX_ERRORS_DELTA_MIN = "txErrorsDeltaMin"
    TX_FRAMES = "txFrames"
    TX_FRAMES_DELTA = "txFramesDelta"
    TX_FRAMES_DELTA_AVG = "txFramesDeltaAvg"
    TX_FRAMES_DELTA_MAX = "txFramesDeltaMax"
    TX_FRAMES_DELTA_MIN = "txFramesDeltaMin"
    TX_ID = "txId"
    TX_PACKETS = "txPackets"
    TX_PACKETS_DELTA = "txPacketsDelta"
    TX_PACKETS_DELTA_AVG = "txPacketsDeltaAvg"
    TX_PACKETS_DELTA_MAX = "txPacketsDeltaMax"
    TX_PACKETS_DELTA_MIN = "txPacketsDeltaMin"
    TX_PAUSE_CFC = "txPauseCFC"
    TX_PAUSE_CFCDELTA = "txPauseCFCDelta"
    TX_PAUSE_CFCDELTA_AVG = "txPauseCFCDeltaAvg"
    TX_PAUSE_CFCDELTA_MAX = "txPauseCFCDeltaMax"
    TX_PAUSE_CFCDELTA_MIN = "txPauseCFCDeltaMin"
    TX_PAUSE_PFC = "txPausePFC"
    TX_PAUSE_PFCDELTA = "txPausePFCDelta"
    TX_PAUSE_PFCDELTA_AVG = "txPausePFCDeltaAvg"
    TX_PAUSE_PFCDELTA_MAX = "txPausePFCDeltaMax"
    TX_PAUSE_PFCDELTA_MIN = "txPausePFCDeltaMin"
    TXN_TYPE = "txnType"
    TYPE = "type"
    UC_CENTRAL_CONFIG_ISSUES = "ucCentralConfigIssues"
    UC_CENTRAL_ERRORS = "ucCentralErrors"
    UC_CENTRAL_OVERALL_ISSUES = "ucCentralOverallIssues"
    UC_CENTRAL_WARNINGS = "ucCentralWarnings"
    UCS_DOMAINS_AFFECTED = "ucsDomainsAffected"
    UCS_DOMAINS_ANALYZED = "ucsDomainsAnalyzed"
    UCS_DOMAINS_IN_SUSPEND = "ucsDomainsInSuspend"
    UCS_DOMAINS_LOST_VISIBILITY = "ucsDomainsLostVisibility"
    UCS_DOMAINS_TIMED_OUT = "ucsDomainsTimedOut"
    UCS_FIRMWARE = "ucsFirmware"
    UCS_VERSION = "ucsVersion"
    UCSC_GENERATION = "ucscGeneration"
    UCSC_SRC_MO_DN = "ucscSrcMoDn"
    UCSM_CONFIG_MESSAGE = "ucsmConfigMessage"
    UCSM_DEPLOYMENT_CONFIG_STATE = "ucsmDeploymentConfigState"
    UCSM_ID = "ucsmId"
    UCSM_MO_DN = "ucsmMoDn"
    UCSM_RUNNING_VERSION = "ucsmRunningVersion"
    UCSM_VNET_EP_DN = "ucsmVnetEpDn"
    UDI_HOST_IDENTIFIER = "udiHostIdentifier"
    UDI_IP_ADDRESS = "udiIpAddress"
    UDI_MAC_ADDRESS = "udiMacAddress"
    UDI_PID = "udiPid"
    UDI_SN = "udiSn"
    UDI_SUVI = "udiSuvi"
    UDI_UUID = "udiUuid"
    UDI_VID = "udiVid"
    UDLD_LINK_POLICY_NAME = "udldLinkPolicyName"
    UDLD_OPER_STATE = "udldOperState"
    UI = "ui"
    UI_GROUP_NAME = "uiGroupName"
    UID = "uid"
    UMBILICAL_STATE = "umbilicalState"
    UNCORRECTABLE_ERRORS = "uncorrectableErrors"
    UNCORRECTABLE_ERRORS_DELTA = "uncorrectableErrorsDelta"
    UNCORRECTABLE_ERRORS_DELTA_AVG = "uncorrectableErrorsDeltaAvg"
    UNCORRECTABLE_ERRORS_DELTA_MAX = "uncorrectableErrorsDeltaMax"
    UNCORRECTABLE_ERRORS_DELTA_MIN = "uncorrectableErrorsDeltaMin"
    UNDER_SIZE = "underSize"
    UNDER_SIZE_DELTA = "underSizeDelta"
    UNDER_SIZE_DELTA_AVG = "underSizeDeltaAvg"
    UNDER_SIZE_DELTA_MAX = "underSizeDeltaMax"
    UNDER_SIZE_DELTA_MIN = "underSizeDeltaMin"
    UNDERSIZED_BAD_CRC_PACKETS = "undersizedBadCrcPackets"
    UNDERSIZED_BAD_CRC_PACKETS_DELTA = "undersizedBadCrcPacketsDelta"
    UNDERSIZED_BAD_CRC_PACKETS_DELTA_AVG = "undersizedBadCrcPacketsDeltaAvg"
    UNDERSIZED_BAD_CRC_PACKETS_DELTA_MAX = "undersizedBadCrcPacketsDeltaMax"
    UNDERSIZED_BAD_CRC_PACKETS_DELTA_MIN = "undersizedBadCrcPacketsDeltaMin"
    UNDERSIZED_GOOD_CRC_PACKETS = "undersizedGoodCrcPackets"
    UNDERSIZED_GOOD_CRC_PACKETS_DELTA = "undersizedGoodCrcPacketsDelta"
    UNDERSIZED_GOOD_CRC_PACKETS_DELTA_AVG = "undersizedGoodCrcPacketsDeltaAvg"
    UNDERSIZED_GOOD_CRC_PACKETS_DELTA_MAX = "undersizedGoodCrcPacketsDeltaMax"
    UNDERSIZED_GOOD_CRC_PACKETS_DELTA_MIN = "undersizedGoodCrcPacketsDeltaMin"
    UNEXPECTED_ERRORS = "unexpectedErrors"
    UNEXPECTED_ERRORS_AVG = "unexpectedErrorsAvg"
    UNEXPECTED_ERRORS_MAX = "unexpectedErrorsMax"
    UNEXPECTED_ERRORS_MIN = "unexpectedErrorsMin"
    UNEXPECTED_ERRORS_RUNNING = "unexpectedErrorsRunning"
    UNICAST_PACKETS = "unicastPackets"
    UNICAST_PACKETS_DELTA = "unicastPacketsDelta"
    UNICAST_PACKETS_DELTA_AVG = "unicastPacketsDeltaAvg"
    UNICAST_PACKETS_DELTA_MAX = "unicastPacketsDeltaMax"
    UNICAST_PACKETS_DELTA_MIN = "unicastPacketsDeltaMin"
    UNIFIED_PORT = "unifiedPort"
    UNITS = "units"
    UNPLANNED_SHUTDOWN = "unplannedShutdown"
    UNREGISTRATION_STATE = "unregistrationState"
    UNSUPPORTED_REQUEST_ERRORS = "unsupportedRequestErrors"
    UNSUPPORTED_REQUEST_ERRORS_AVG = "unsupportedRequestErrorsAvg"
    UNSUPPORTED_REQUEST_ERRORS_MAX = "unsupportedRequestErrorsMax"
    UNSUPPORTED_REQUEST_ERRORS_MIN = "unsupportedRequestErrorsMin"
    UNSUPPORTED_REQUEST_ERRORS_RUNNING = "unsupportedRequestErrorsRunning"
    UPDATE = "update"
    UPDATE_IDM = "updateIdm"
    UPDATE_ORDER = "updateOrder"
    UPDATE_TIME = "updateTime"
    UPDATE_TRIGGER = "updateTrigger"
    UPGRADE_SCENARIO = "upgradeScenario"
    UPGRADE_STATUS = "upgradeStatus"
    UPLINK_FAIL_ACTION = "uplinkFailAction"
    UPLINK_STATE = "uplinkState"
    UPLINK_STATE_REASON = "uplinkStateReason"
    UPLINK_TRUNKING = "uplinkTrunking"
    UPTIME = "uptime"
    UPTIME_DISR = "uptimeDisr"
    URGENCY = "urgency"
    URI = "uri"
    URL = "url"
    USAGE = "usage"
    USE_AES = "useAes"
    USE_FOR_FW_DLD = "useForFwDld"
    USE_FOR_HCL_DLD = "useForHclDld"
    USE_JBOD_DISKS = "useJbodDisks"
    USE_REMAINING_DISKS = "useRemainingDisks"
    USED = "used"
    USED_QUANT = "usedQuant"
    USED_SIZE = "usedSize"
    USER = "user"
    USER_ACTION = "userAction"
    USER_ID = "userId"
    USER_INPUT_NAME = "userInputName"
    USER_NAME = "userName"
    USER_NAME_OPER_ATTR = "userNameOperAttr"
    USER_RECOVERY_OPERATION = "userRecoveryOperation"
    USERNAME = "username"
    USING_QUALIFIED_POOL = "usingQualifiedPool"
    USNIC_COUNT = "usnicCount"
    USR_LBL = "usrLbl"
    UUID = "uuid"
    UUID_IDENTITY_STATE = "uuidIdentityState"
    UUID_SUFFIX = "uuidSuffix"
    V1 = "v1"
    V2 = "v2"
    V3_PRIVILEGE = "v3Privilege"
    V4_ASSIGNED = "v4Assigned"
    V4_SIZE = "v4Size"
    V6_ASSIGNED = "v6Assigned"
    V6_SIZE = "v6Size"
    V_STATUS = "vStatus"
    VALIDATE_MSG = "validateMsg"
    VALIDATE_STATUS = "validateStatus"
    VALIDITY = "validity"
    VALUE = "value"
    VAR_TYPE = "varType"
    VARIANT_TYPE = "variantType"
    VC_DN = "vcDn"
    VCON_PROFILE_NAME = "vconProfileName"
    VD_DN = "vdDn"
    VENDOR = "vendor"
    VENDOR_DAEMON_PATH = "vendorDaemonPath"
    VENDOR_EQUIPMENT_TYPE = "vendorEquipmentType"
    VENDOR_ID = "vendorId"
    VENDOR_UUID = "vendorUuid"
    VERSION = "version"
    VERSION_HOLDER = "versionHolder"
    VERSION_HOLDER_FLAG = "versionHolderFlag"
    VERSION_MISMATCH = "versionMismatch"
    VIC_TEMP = "vicTemp"
    VIC_TEMP_AVG = "vicTempAvg"
    VIC_TEMP_MAX = "vicTempMax"
    VIC_TEMP_MIN = "vicTempMin"
    VID = "vid"
    VIF_ID = "vifId"
    VIRTUAL_ACCOUNT = "virtualAccount"
    VIRTUAL_DISK_ID = "virtualDiskId"
    VIRTUAL_DRIVE_COUNT = "virtualDriveCount"
    VIRTUAL_DRIVE_OPS = "virtualDriveOps"
    VIRTUALIZATION_PREFERENCE = "virtualizationPreference"
    VIRTUALIZED_CESUPPORTED = "virtualizedCESupported"
    VISIBILITY = "visibility"
    VISIBLE = "visible"
    VLAN_COMPRESSION = "vlanCompression"
    VLAN_DN = "vlanDn"
    VLAN_FOR_BOOT = "vlanForBoot"
    VLAN_GRP_REQUEST_COMPUTE_TIME = "vlanGrpRequestComputeTime"
    VLAN_ID = "vlanId"
    VLAN_NAME = "vlanName"
    VLAN_PACKETS = "vlanPackets"
    VLAN_PACKETS_DELTA = "vlanPacketsDelta"
    VLAN_PACKETS_DELTA_AVG = "vlanPacketsDeltaAvg"
    VLAN_PACKETS_DELTA_MAX = "vlanPacketsDeltaMax"
    VLAN_PACKETS_DELTA_MIN = "vlanPacketsDeltaMin"
    VLAN_STATUS = "vlanStatus"
    VLAN_SWITCH_ID = "vlanSwitchId"
    VLAN_TYPE = "vlanType"
    VMEDIA_POLICY_NAME = "vmediaPolicyName"
    VMMQ_SUB_VNICS = "vmmqSubVnics"
    VMND_GUID = "vmndGuid"
    VMND_NAME = "vmndName"
    VMQ_COUNT = "vmqCount"
    VNET = "vnet"
    VNET_ID = "vnetId"
    VNIC = "vnic"
    VNIC_CONFIG_ISSUES = "vnicConfigIssues"
    VNIC_DEF_TYPE = "vnicDefType"
    VNIC_DN = "vnicDn"
    VNIC_NAME = "vnicName"
    VOLTAGE = "voltage"
    VOLTAGE_AVG = "voltageAvg"
    VOLTAGE_MAX = "voltageMax"
    VOLTAGE_MIN = "voltageMin"
    VOLUME_DN = "volumeDn"
    VOLUME_NAME = "volumeName"
    VOLUME_POOL_NAME = "volumePoolName"
    VP_ACPI10_SUPPORT = "vpACPI10Support"
    VP_ASPMSUPPORT = "vpASPMSupport"
    VP_ADJACENT_CACHE_LINE_PREFETCHER = "vpAdjacentCacheLinePrefetcher"
    VP_ALL_USBDEVICES = "vpAllUSBDevices"
    VP_ALTITUDE = "vpAltitude"
    VP_ASSERT_NMION_PERR = "vpAssertNMIOnPERR"
    VP_ASSERT_NMION_SERR = "vpAssertNMIOnSERR"
    VP_BAUD_RATE = "vpBaudRate"
    VP_BOOT_OPTION_RETRY = "vpBootOptionRetry"
    VP_CDNCONTROL = "vpCDNControl"
    VP_CPUHARDWARE_POWER_MANAGEMENT = "vpCPUHardwarePowerManagement"
    VP_CPUPERFORMANCE = "vpCPUPerformance"
    VP_CPUPOWER_MANAGEMENT = "vpCPUPowerManagement"
    VP_CHANNEL_INTERLEAVING = "vpChannelInterleaving"
    VP_COM_SPCR_ENABLE = "vpComSpcrEnable"
    VP_CONSOLE_REDIRECTION = "vpConsoleRedirection"
    VP_CORE_MULTI_PROCESSING = "vpCoreMultiProcessing"
    VP_DCUIPPREFETCHER = "vpDCUIPPrefetcher"
    VP_DCUSTREAMER_PREFETCH = "vpDCUStreamerPrefetch"
    VP_DDR3_VOLTAGE_SELECTION = "vpDDR3VoltageSelection"
    VP_DRAMCLOCK_THROTTLING = "vpDRAMClockThrottling"
    VP_DEMAND_SCRUB = "vpDemandScrub"
    VP_DIRECT_CACHE_ACCESS = "vpDirectCacheAccess"
    VP_DRAM_REFRESH_RATE = "vpDramRefreshRate"
    VP_ENERGY_PERFORMANCE = "vpEnergyPerformance"
    VP_ENHANCED_INTEL_SPEED_STEP_TECH = "vpEnhancedIntelSpeedStepTech"
    VP_ENHANCED_POWER_CAPPING = "vpEnhancedPowerCapping"
    VP_EXECUTE_DISABLE_BIT = "vpExecuteDisableBit"
    VP_FRB2_TIMER = "vpFRB2Timer"
    VP_FLOW_CONTROL = "vpFlowControl"
    VP_FREQUENCY_FLOOR_OVERRIDE = "vpFrequencyFloorOverride"
    VP_FRONT_PANEL_LOCKOUT = "vpFrontPanelLockout"
    VP_HARDWARE_PREFETCHER = "vpHardwarePrefetcher"
    VP_IOEMEZZ1_OPTION_ROM = "vpIOEMezz1OptionROM"
    VP_IOENVME1_OPTION_ROM = "vpIOENVMe1OptionROM"
    VP_IOENVME2_OPTION_ROM = "vpIOENVMe2OptionROM"
    VP_IOESLOT1_OPTION_ROM = "vpIOESlot1OptionROM"
    VP_IOESLOT2_OPTION_ROM = "vpIOESlot2OptionROM"
    VP_INTEGRATED_GRAPHICS = "vpIntegratedGraphics"
    VP_INTEGRATED_GRAPHICS_APERTURE_SIZE = "vpIntegratedGraphicsApertureSize"
    VP_INTEL_HYPER_THREADING_TECH = "vpIntelHyperThreadingTech"
    VP_INTEL_TRUSTED_EXECUTION_TECHNOLOGY_SUPPORT = "vpIntelTrustedExecutionTechnologySupport"
    VP_INTEL_TURBO_BOOST_TECH = "vpIntelTurboBoostTech"
    VP_INTEL_VTDATSSUPPORT = "vpIntelVTDATSSupport"
    VP_INTEL_VTDCOHERENCY_SUPPORT = "vpIntelVTDCoherencySupport"
    VP_INTEL_VTDINTERRUPT_REMAPPING = "vpIntelVTDInterruptRemapping"
    VP_INTEL_VTDPASS_THROUGH_DMASUPPORT = "vpIntelVTDPassThroughDMASupport"
    VP_INTEL_VTFOR_DIRECTED_IO = "vpIntelVTForDirectedIO"
    VP_INTEL_VIRTUALIZATION_TECHNOLOGY = "vpIntelVirtualizationTechnology"
    VP_LEGACY_OSREDIRECTION = "vpLegacyOSRedirection"
    VP_LEGACY_USBSUPPORT = "vpLegacyUSBSupport"
    VP_LOAD = "vpLoad"
    VP_LOCAL_X2_APIC = "vpLocalX2Apic"
    VP_LV_DDRMODE = "vpLvDDRMode"
    VP_MAKE_DEVICE_NON_BOOTABLE = "vpMakeDeviceNonBootable"
    VP_MAXIMUM_MEMORY_BELOW4_GB = "vpMaximumMemoryBelow4GB"
    VP_MEMORY_INTERLEAVING = "vpMemoryInterleaving"
    VP_MEMORY_MAPPED_IOABOVE4_GB = "vpMemoryMappedIOAbove4GB"
    VP_MIRRORING_MODE = "vpMirroringMode"
    VP_NUMAOPTIMIZED = "vpNUMAOptimized"
    VP_OSBOOT_WATCHDOG_TIMER = "vpOSBootWatchdogTimer"
    VP_OSBOOT_WATCHDOG_TIMER_POLICY = "vpOSBootWatchdogTimerPolicy"
    VP_OSBOOT_WATCHDOG_TIMER_TIMEOUT = "vpOSBootWatchdogTimerTimeout"
    VP_ONBOARD_GRAPHICS = "vpOnboardGraphics"
    VP_ONBOARD_SATACONTROLLER = "vpOnboardSATAController"
    VP_ONBOARD_SCUSTORAGE_SUPPORT = "vpOnboardSCUStorageSupport"
    VP_PCIROMCLP = "vpPCIROMCLP"
    VP_PCIE10_GLOM2_LINK = "vpPCIe10GLOM2Link"
    VP_PCIE_SLOT10_LINK_SPEED = "vpPCIeSlot10LinkSpeed"
    VP_PCIE_SLOT1_LINK_SPEED = "vpPCIeSlot1LinkSpeed"
    VP_PCIE_SLOT2_LINK_SPEED = "vpPCIeSlot2LinkSpeed"
    VP_PCIE_SLOT3_LINK_SPEED = "vpPCIeSlot3LinkSpeed"
    VP_PCIE_SLOT4_LINK_SPEED = "vpPCIeSlot4LinkSpeed"
    VP_PCIE_SLOT5_LINK_SPEED = "vpPCIeSlot5LinkSpeed"
    VP_PCIE_SLOT6_LINK_SPEED = "vpPCIeSlot6LinkSpeed"
    VP_PCIE_SLOT7_LINK_SPEED = "vpPCIeSlot7LinkSpeed"
    VP_PCIE_SLOT8_LINK_SPEED = "vpPCIeSlot8LinkSpeed"
    VP_PCIE_SLOT9_LINK_SPEED = "vpPCIeSlot9LinkSpeed"
    VP_PCIE_SLOT_HBAOPTION_ROM = "vpPCIeSlotHBAOptionROM"
    VP_PCIE_SLOT_MLOMOPTION_ROM = "vpPCIeSlotMLOMOptionROM"
    VP_PCIE_SLOT_N1_OPTION_ROM = "vpPCIeSlotN1OptionROM"
    VP_PCIE_SLOT_N2_OPTION_ROM = "vpPCIeSlotN2OptionROM"
    VP_PCIE_SLOT_SASOPTION_ROM = "vpPCIeSlotSASOptionROM"
    VP_POSTERROR_PAUSE = "vpPOSTErrorPause"
    VP_PSTATECOORDINATION = "vpPSTATECoordination"
    VP_PACKAGE_CSTATE_LIMIT = "vpPackageCStateLimit"
    VP_PATROL_SCRUB = "vpPatrolScrub"
    VP_PORT6064_EMULATION = "vpPort6064Emulation"
    VP_POWER_TECHNOLOGY = "vpPowerTechnology"
    VP_PROCESSOR_C1_E = "vpProcessorC1E"
    VP_PROCESSOR_C3_REPORT = "vpProcessorC3Report"
    VP_PROCESSOR_C6_REPORT = "vpProcessorC6Report"
    VP_PROCESSOR_C7_REPORT = "vpProcessorC7Report"
    VP_PROCESSOR_CMCI = "vpProcessorCMCI"
    VP_PROCESSOR_CSTATE = "vpProcessorCState"
    VP_PROCESSOR_MTRR = "vpProcessorMtrr"
    VP_PUTTY_KEY_PAD = "vpPuttyKeyPad"
    VP_PWR_PERF_TUNING = "vpPwrPerfTuning"
    VP_QPILINK_FREQUENCY_SELECT = "vpQPILinkFrequencySelect"
    VP_QPISNOOP_MODE = "vpQPISnoopMode"
    VP_QUIET_BOOT = "vpQuietBoot"
    VP_RANK_INTERLEAVING = "vpRankInterleaving"
    VP_REDIRECTION_AFTER_POST = "vpRedirectionAfterPOST"
    VP_RESUME_ON_ACPOWER_LOSS = "vpResumeOnACPowerLoss"
    VP_SASRAID = "vpSASRAID"
    VP_SASRAIDMODULE = "vpSASRAIDModule"
    VP_SATAMODE = "vpSATAMode"
    VP_SBMEZZ1_OPTION_ROM = "vpSBMezz1OptionROM"
    VP_SBNVME1_OPTION_ROM = "vpSBNVMe1OptionROM"
    VP_SIOC1_OPTION_ROM = "vpSIOC1OptionROM"
    VP_SIOC2_OPTION_ROM = "vpSIOC2OptionROM"
    VP_SELECT_MEMORY_RASCONFIGURATION = "vpSelectMemoryRASConfiguration"
    VP_SERIAL_PORT_AENABLE = "vpSerialPortAEnable"
    VP_SLOT10_STATE = "vpSlot10State"
    VP_SLOT1_STATE = "vpSlot1State"
    VP_SLOT2_STATE = "vpSlot2State"
    VP_SLOT3_STATE = "vpSlot3State"
    VP_SLOT4_STATE = "vpSlot4State"
    VP_SLOT5_STATE = "vpSlot5State"
    VP_SLOT6_STATE = "vpSlot6State"
    VP_SLOT7_STATE = "vpSlot7State"
    VP_SLOT8_STATE = "vpSlot8State"
    VP_SLOT9_STATE = "vpSlot9State"
    VP_SLOT_MEZZ_STATE = "vpSlotMezzState"
    VP_SPARING_MODE = "vpSparingMode"
    VP_SRIOV = "vpSriov"
    VP_STATE = "vpState"
    VP_TPMPENDING_OPERATION = "vpTPMPendingOperation"
    VP_TPMSUPPORT = "vpTPMSupport"
    VP_TERMINAL_TYPE = "vpTerminalType"
    VP_TRUSTED_PLATFORM_MODULE_SUPPORT = "vpTrustedPlatformModuleSupport"
    VP_UCSMBOOT_ORDER_RULE = "vpUCSMBootOrderRule"
    VP_UEFIBOOT_MODE = "vpUEFIBootMode"
    VP_UEFIOSUSE_LEGACY_VIDEO = "vpUEFIOSUseLegacyVideo"
    VP_USBFRONT_PANEL_LOCK = "vpUSBFrontPanelLock"
    VP_USBIDLE_POWER_OPTIMIZING = "vpUSBIdlePowerOptimizing"
    VP_USBPORT_FRONT = "vpUSBPortFront"
    VP_USBPORT_INTERNAL = "vpUSBPortInternal"
    VP_USBPORT_KVM = "vpUSBPortKVM"
    VP_USBPORT_REAR = "vpUSBPortRear"
    VP_USBPORT_SDCARD = "vpUSBPortSDCard"
    VP_USBPORT_VMEDIA = "vpUSBPortVMedia"
    VP_VGAPRIORITY = "vpVGAPriority"
    VP_WORKLOAD_CONFIGURATION = "vpWorkloadConfiguration"
    VP_XHCIMODE = "vpXHCIMode"
    VSAN_ID = "vsanId"
    VSAN_NAME = "vsanName"
    WARNING_CNT = "warningCnt"
    WARNINGS = "warnings"
    WEAR_PERCENTAGE = "wearPercentage"
    WEAR_PERCENTAGE_AVG = "wearPercentageAvg"
    WEAR_PERCENTAGE_MAX = "wearPercentageMax"
    WEAR_PERCENTAGE_MIN = "wearPercentageMin"
    WEAR_STATUS_IN_DAYS = "wearStatusInDays"
    WEAR_STATUS_IN_DAYS_AVG = "wearStatusInDaysAvg"
    WEAR_STATUS_IN_DAYS_MAX = "wearStatusInDaysMax"
    WEAR_STATUS_IN_DAYS_MIN = "wearStatusInDaysMin"
    WEEKLY_RECORDS = "weeklyRecords"
    WEIGHT = "weight"
    WELCOME_WIDGET_DISABLED = "welcomeWidgetDisabled"
    WIDTH = "width"
    WINDOW_DN = "windowDn"
    WINDOW_SIZE = "windowSize"
    WRITE_CACHE_POLICY = "writeCachePolicy"
    WRITE_ENABLE = "writeEnable"
    WRITE_ERROR_THRESHOLD = "writeErrorThreshold"
    WRITE_IOERROR_COUNT = "writeIOErrorCount"
    WRITE_IOPS = "writeIops"
    WRITE_IOPS_AVG = "writeIopsAvg"
    WRITE_IOPS_MAX = "writeIopsMax"
    WRITE_IOPS_MIN = "writeIopsMin"
    WRITE_MBPS = "writeMbps"
    WRITE_MBPS_AVG = "writeMbpsAvg"
    WRITE_MBPS_MAX = "writeMbpsMax"
    WRITE_MBPS_MIN = "writeMbpsMin"
    WRITE_MODE = "writeMode"
    WWN = "wwn"
    WWPN = "wwpn"
    XCVR_TYPE = "xcvrType"
    XMIT = "xmit"
    XMIT_DELTA = "xmitDelta"
    XMIT_DELTA_AVG = "xmitDeltaAvg"
    XMIT_DELTA_MAX = "xmitDeltaMax"
    XMIT_DELTA_MIN = "xmitDeltaMin"
    XMIT_PAUSE = "xmitPause"
    XMIT_PAUSE_DELTA = "xmitPauseDelta"
    XMIT_PAUSE_DELTA_AVG = "xmitPauseDeltaAvg"
    XMIT_PAUSE_DELTA_MAX = "xmitPauseDeltaMax"
    XMIT_PAUSE_DELTA_MIN = "xmitPauseDeltaMin"
    XTYPE = "xtype"
    ZONE_NAME = "zoneName"
    ZONING_STATE = "zoningState"
    ZONING_TYPE = "zoningType"

class Status:
    CREATED = "created"
    DELETED = "deleted"
    MODIFIED = "modified"
    REMOVED = "removed"

